MUNICIPIOS = [
    "RS/Cai\u00e7ara",
    "BA/Ibitiara",
    "RJ/Santo Ant\u00f4nio de P\u00e1dua",
    "SC/Iraceminha",
    "PR/Cianorte",
    "RJ/Iguaba Grande",
    "MT/Nova Maring\u00e1",
    "PB/Itatuba",
    "SP/Santa Salete",
    "MG/Nova Era",
    "PR/S\u00e3o Jo\u00e3o do Iva\u00ed",
    "PR/Mandirituba",
    "MG/Aimor\u00e9s",
    "BA/Xique-Xique",
    "PR/Toledo",
    "ES/Serra",
    "PB/Umbuzeiro",
    "RS/Candiota",
    "PR/Cafel\u00e2ndia",
    "PE/Brejinho",
    "BA/Serrinha",
    "MG/Lamim",
    "RS/Santa B\u00e1rbara do Sul",
    "ES/Itagua\u00e7u",
    "MG/Curvelo",
    "RS/Tucunduva",
    "PA/Rondon do Par\u00e1",
    "SC/Pomerode",
    "SP/Ipigu\u00e1",
    "SP/Sandovalina",
    "MS/Douradina",
    "PR/Quatigu\u00e1",
    "PE/Carna\u00edba",
    "PI/Naz\u00e1ria",
    "PI/Lagoa do S\u00edtio",
    "PE/Ilha de Itamarac\u00e1",
    "TO/Formoso do Araguaia",
    "MG/Santa Rita de Ibitipoca",
    "PE/Olinda",
    "GO/Apor\u00e9",
    "PE/Gl\u00f3ria do Goit\u00e1",
    "MA/Amarante do Maranh\u00e3o",
    "TO/Fortaleza do Taboc\u00e3o",
    "AM/Eirunep\u00e9",
    "MA/Cedral",
    "PR/Reserva do Igua\u00e7u",
    "TO/Almas",
    "PE/Bezerros",
    "GO/S\u00e3o Lu\u00eds de Montes Belos",
    "MG/Carmo de Minas",
    "PI/Sim\u00f5es",
    "AM/Borba",
    "SC/Atalanta",
    "SP/Jaborandi",
    "SP/Divinol\u00e2ndia",
    "RS/Cerro Branco",
    "PE/Igarassu",
    "GO/Colinas do Sul",
    "MG/Caet\u00e9",
    "PR/Ipiranga",
    "RS/Roca Sales",
    "SP/Guara\u00e7a\u00ed",
    "PR/Doutor Ulysses",
    "RS/Salvador do Sul",
    "SP/Pindamonhangaba",
    "SC/Balne\u00e1rio Gaivota",
    "MG/Bias Fortes",
    "BA/Barra do Rocha",
    "BA/Nilo Pe\u00e7anha",
    "MS/Tr\u00eas Lagoas",
    "SP/Mar\u00edlia",
    "AL/Quebrangulo",
    "MS/Bataypor\u00e3",
    "PE/Ara\u00e7oiaba",
    "MA/Lago Verde",
    "SP/Nova Alian\u00e7a",
    "MG/Carmo do Cajuru",
    "PI/Beneditinos",
    "PA/Marapanim",
    "RS/Formigueiro",
    "MG/Cascalho Rico",
    "ES/Irupi",
    "PR/Jardim Alegre",
    "MT/Ribeir\u00e3ozinho",
    "CE/Farias Brito",
    "RS/Coxilha",
    "RR/Caracara\u00ed",
    "RS/Cotipor\u00e3",
    "SP/Ilha Comprida",
    "SC/Gaspar",
    "BA/Cura\u00e7\u00e1",
    "RN/Riacho de Santana",
    "MG/Pimenta",
    "SP/Pariquera-A\u00e7u",
    "SC/S\u00e3o Miguel do Oeste",
    "SP/Regin\u00f3polis",
    "PI/Coivaras",
    "BA/Jita\u00fana",
    "PA/Ipixuna do Par\u00e1",
    "MT/Jaciara",
    "AL/Po\u00e7o das Trincheiras",
    "SP/Cajati",
    "MG/Virg\u00ednia",
    "TO/Porto Nacional",
    "SP/S\u00e3o Sim\u00e3o",
    "SC/Xaxim",
    "CE/Martin\u00f3pole",
    "TO/Sampaio",
    "MG/Claro dos Po\u00e7\u00f5es",
    "SP/\u00c1guas de Lind\u00f3ia",
    "BA/Morro do Chap\u00e9u",
    "SC/Lontras",
    "PR/Irati",
    "SP/Cabre\u00fava",
    "TO/Combinado",
    "MG/Rochedo de Minas",
    "GO/Mairipotaba",
    "BA/Cara\u00edbas",
    "PI/S\u00e3o Jos\u00e9 do Peixe",
    "RS/Faxinalzinho",
    "SP/Piraju",
    "PB/Lucena",
    "BA/Santo Ant\u00f4nio de Jesus",
    "SP/Santo Ant\u00f4nio do Jardim",
    "MG/S\u00e3o Francisco do Gl\u00f3ria",
    "BA/Concei\u00e7\u00e3o da Feira",
    "BA/Pojuca",
    "SP/Taquaritinga",
    "AL/Junqueiro",
    "PI/Coronel Jos\u00e9 Dias",
    "SP/Platina",
    "PR/Capit\u00e3o Le\u00f4nidas Marques",
    "MG/Campos Altos",
    "RN/Cerro Cor\u00e1",
    "BA/Uau\u00e1",
    "MG/Aricanduva",
    "SC/S\u00e3o Jo\u00e3o do Sul",
    "RS/Jacuizinho",
    "PR/Tunas do Paran\u00e1",
    "RS/Bom Retiro do Sul",
    "MG/Conselheiro Pena",
    "SC/Jos\u00e9 Boiteux",
    "PB/Pocinhos",
    "SP/Cotia",
    "MA/Santa Luzia do Paru\u00e1",
    "RN/Lajes",
    "SP/Riol\u00e2ndia",
    "SP/Pracinha",
    "MG/Frei Inoc\u00eancio",
    "MG/Brasil\u00e2ndia de Minas",
    "MG/Divin\u00f3polis",
    "SP/Meridiano",
    "RN/Cara\u00fabas",
    "PR/Tr\u00eas Barras do Paran\u00e1",
    "PI/Alegrete do Piau\u00ed",
    "BA/Lamar\u00e3o",
    "MG/Santa Maria de Itabira",
    "SP/Cordeir\u00f3polis",
    "MG/Capit\u00e3o Andrade",
    "PR/En\u00e9as Marques",
    "MA/Bacurituba",
    "BA/Feira da Mata",
    "GO/Ca\u00e7u",
    "TO/Santa Maria do Tocantins",
    "RS/Sentinela do Sul",
    "CE/Juc\u00e1s",
    "GO/Abadia de Goi\u00e1s",
    "MG/Ita\u00fa de Minas",
    "MG/Guidoval",
    "SC/Balne\u00e1rio Barra do Sul",
    "PB/Capim",
    "PI/Bet\u00e2nia do Piau\u00ed",
    "MT/Nova Nazar\u00e9",
    "MG/Cris\u00f3lita",
    "MG/Piedade dos Gerais",
    "RS/Barra Funda",
    "MG/Itacarambi",
    "MG/Jo\u00e3o Pinheiro",
    "ES/S\u00e3o Jos\u00e9 do Cal\u00e7ado",
    "PI/Marcos Parente",
    "SE/Cumbe",
    "MG/Itapagipe",
    "MA/Governador Archer",
    "AM/Manaus",
    "PB/Ara\u00e7agi",
    "CE/Uruburetama",
    "RS/Il\u00f3polis",
    "PE/S\u00e3o Jos\u00e9 do Egito",
    "MG/Nova M\u00f3dica",
    "SP/Riversul",
    "MG/Rio Pomba",
    "SP/Natividade da Serra",
    "SP/Quat\u00e1",
    "RS/Arvorezinha",
    "MT/Cocalinho",
    "BA/Almadina",
    "RN/Pend\u00eancias",
    "MA/Trizidela do Vale",
    "PE/Vertente do L\u00e9rio",
    "CE/Itapi\u00fana",
    "MG/Mesquita",
    "GO/Taquaral de Goi\u00e1s",
    "BA/Tremedal",
    "PB/Brejo dos Santos",
    "PR/Guaira\u00e7\u00e1",
    "RS/Porto Vera Cruz",
    "BA/Mucuri",
    "MG/Dom Joaquim",
    "PB/Desterro",
    "MT/Alto Boa Vista",
    "PR/Arapongas",
    "PR/Terra Boa",
    "RS/Lagoa Bonita do Sul",
    "PA/Abel Figueiredo",
    "BA/Muritiba",
    "MG/Nanuque",
    "MA/Tufil\u00e2ndia",
    "MG/Durand\u00e9",
    "BA/Euclides da Cunha",
    "SP/Tatu\u00ed",
    "PI/Capit\u00e3o de Campos",
    "MA/Santa In\u00eas",
    "RS/Feliz",
    "PR/Iguara\u00e7u",
    "RO/S\u00e3o Miguel do Guapor\u00e9",
    "BA/Caatiba",
    "RS/Cap\u00e3o do Cip\u00f3",
    "PI/Bom Jesus",
    "MG/Astolfo Dutra",
    "MG/Dores do Indai\u00e1",
    "AL/Coit\u00e9 do N\u00f3ia",
    "CE/Itapipoca",
    "RN/Cai\u00e7ara do Norte",
    "PR/Santa Cruz de Monte Castelo",
    "PB/Bel\u00e9m",
    "BA/Tanque Novo",
    "MS/Vicentina",
    "MA/Samba\u00edba",
    "MG/Mathias Lobato",
    "ES/Jaguar\u00e9",
    "SE/Po\u00e7o Verde",
    "PR/Santa Maria do Oeste",
    "MG/Divis\u00f3polis",
    "MS/Aparecida do Taboado",
    "MA/Penalva",
    "MS/Jate\u00ed",
    "SC/Zort\u00e9a",
    "MG/Paiva",
    "MG/Santa B\u00e1rbara do Monte Verde",
    "SP/Pederneiras",
    "MG/Santo Ant\u00f4nio do Retiro",
    "MG/Capelinha",
    "ES/Vargem Alta",
    "PB/Jo\u00e3o Pessoa",
    "PB/Pedro R\u00e9gis",
    "MT/Nova Mutum",
    "PR/Japur\u00e1",
    "RN/Cruzeta",
    "RS/Vespasiano Corr\u00eaa",
    "SP/Duartina",
    "MG/Monsenhor Paulo",
    "SC/S\u00e3o Jo\u00e3o Batista",
    "PI/Amarante",
    "MT/Nova Ubirat\u00e3",
    "MG/Dion\u00edsio",
    "RS/Itacurubi",
    "BA/Brej\u00f5es",
    "GO/Piren\u00f3polis",
    "MG/Campo Belo",
    "CE/Itarema",
    "RS/Entre Rios do Sul",
    "SP/Parapu\u00e3",
    "MA/Ribamar Fiquene",
    "SC/Santo Amaro da Imperatriz",
    "CE/Aratuba",
    "BA/Ant\u00f4nio Gon\u00e7alves",
    "MG/Cajuri",
    "RO/Candeias do Jamari",
    "SE/Pedrinhas",
    "AL/Teot\u00f4nio Vilela",
    "MT/Ponte Branca",
    "GO/Rian\u00e1polis",
    "SP/Tapira\u00ed",
    "MG/Pomp\u00e9u",
    "RN/Lucr\u00e9cia",
    "RS/Chuvisca",
    "CE/Jaguaribara",
    "SC/Sang\u00e3o",
    "SP/Canitar",
    "GO/Matrinch\u00e3",
    "GO/Damian\u00f3polis",
    "BA/Rafael Jambeiro",
    "MT/Rondol\u00e2ndia",
    "RN/Lagoa Salgada",
    "PA/Marituba",
    "MG/Nova Bel\u00e9m",
    "PB/S\u00e3o Jos\u00e9 da Lagoa Tapada",
    "SP/Nova Guataporanga",
    "RN/Monte das Gameleiras",
    "GO/C\u00f3rrego do Ouro",
    "TO/Alvorada",
    "PB/Vieir\u00f3polis",
    "PB/Marca\u00e7\u00e3o",
    "BA/Buritirama",
    "TO/Palmas",
    "GO/Jandaia",
    "SC/Imbituba",
    "RS/Mampituba",
    "GO/Paranaiguara",
    "AM/Itamarati",
    "PB/Salgadinho",
    "BA/Saubara",
    "SP/Dolcin\u00f3polis",
    "SC/Varge\u00e3o",
    "AL/Mata Grande",
    "SP/Ribeir\u00e3o Branco",
    "PI/An\u00edsio de Abreu",
    "TO/Aurora do Tocantins",
    "BA/Formosa do Rio Preto",
    "GO/Caldazinha",
    "PR/Juranda",
    "MA/Arame",
    "RR/Bonfim",
    "RS/Itatiba do Sul",
    "BA/Rio de Contas",
    "MG/Cambuquira",
    "MT/Pontal do Araguaia",
    "BA/Monte Santo",
    "AP/Tartarugalzinho",
    "SP/Carapicu\u00edba",
    "PE/Ipojuca",
    "MA/Itapecuru Mirim",
    "MG/S\u00e3o Miguel do Anta",
    "BA/Porto Seguro",
    "RJ/Cantagalo",
    "MG/Raposos",
    "RS/Eug\u00eanio de Castro",
    "RN/Severiano Melo",
    "MS/Juti",
    "CE/Quixel\u00f4",
    "SP/Pedro de Toledo",
    "MA/Duque Bacelar",
    "MG/Paraopeba",
    "SC/Santa Cec\u00edlia",
    "MG/Pedra do Indai\u00e1",
    "BA/Heli\u00f3polis",
    "TO/Lajeado",
    "RS/Ametista do Sul",
    "MS/Mundo Novo",
    "RN/Carna\u00faba dos Dantas",
    "PI/Elesb\u00e3o Veloso",
    "PE/Ibirajuba",
    "BA/Guaratinga",
    "PI/Uru\u00e7u\u00ed",
    "RO/Mirante da Serra",
    "SP/Santa Isabel",
    "SP/Bom Jesus dos Perd\u00f5es",
    "SP/Canan\u00e9ia",
    "MT/Novo S\u00e3o Joaquim",
    "RS/Vista Alegre",
    "AL/Santana do Ipanema",
    "PR/Ourizona",
    "ES/Nova Ven\u00e9cia",
    "MA/Lajeado Novo",
    "PA/Curu\u00e1",
    "RS/Santa Tereza",
    "MG/Moeda",
    "SC/Otac\u00edlio Costa",
    "SC/S\u00e3o Jos\u00e9",
    "MT/Santo Ant\u00f4nio do Leverger",
    "BA/Ipia\u00fa",
    "RS/Capela de Santana",
    "MG/C\u00f4nego Marinho",
    "PI/Lagoa do Piau\u00ed",
    "SP/S\u00e3o Jos\u00e9 do Barreiro",
    "MG/Capit\u00e3o En\u00e9as",
    "SP/Vargem",
    "MG/Santana de Pirapama",
    "SP/Jandira",
    "SP/Guarulhos",
    "PI/Luzil\u00e2ndia",
    "MG/Pedra do Anta",
    "SP/Santa Rita do Passa Quatro",
    "PR/Cruzeiro do Igua\u00e7u",
    "MG/Congonhas do Norte",
    "RN/Itaj\u00e1",
    "GO/Ouro Verde de Goi\u00e1s",
    "AP/Oiapoque",
    "MG/Entre Folhas",
    "SC/Tubar\u00e3o",
    "MG/Machado",
    "PR/Guaraque\u00e7aba",
    "PE/Frei Miguelinho",
    "PB/Pitimbu",
    "MG/Bandeira do Sul",
    "PI/Aroeiras do Itaim",
    "RN/Currais Novos",
    "MG/Prata",
    "MG/Rio Parana\u00edba",
    "RS/Bossoroca",
    "MT/Nova Bandeirantes",
    "MT/Quer\u00eancia",
    "PR/Tapira",
    "SP/Cajamar",
    "MG/Cruz\u00edlia",
    "MG/Fruta de Leite",
    "ES/Cachoeiro de Itapemirim",
    "RN/Lagoa d'Anta",
    "MG/Morro do Pilar",
    "CE/Tamboril",
    "AL/Pilar",
    "SC/Capivari de Baixo",
    "PE/Mirandiba",
    "RS/Putinga",
    "GO/Tr\u00eas Ranchos",
    "MG/Itinga",
    "RN/Caic\u00f3",
    "RJ/Nova Igua\u00e7u",
    "BA/Mutu\u00edpe",
    "BA/Teodoro Sampaio",
    "MG/Jequeri",
    "MG/Piranguinho",
    "PR/S\u00e3o Jo\u00e3o",
    "MG/Desterro de Entre Rios",
    "PB/Cacimbas",
    "AL/Coqueiro Seco",
    "PR/Alto Para\u00edso",
    "PI/Patos do Piau\u00ed",
    "ES/Marata\u00edzes",
    "SP/\u00c1guas de S\u00e3o Pedro",
    "MA/S\u00e3o Jos\u00e9 de Ribamar",
    "SP/Balbinos",
    "SP/Mira Estrela",
    "BA/Itagi",
    "PB/Araruna",
    "BA/Carinhanha",
    "MA/Miranda do Norte",
    "BA/Barro Alto",
    "SC/Santa Terezinha do Progresso",
    "ES/Itapemirim",
    "SE/Pedra Mole",
    "ES/Viana",
    "RS/Arroio do Tigre",
    "PR/Santa In\u00eas",
    "PI/S\u00e3o Miguel do Tapuio",
    "SC/Araquari",
    "MG/Rio Pardo de Minas",
    "GO/Terez\u00f3polis de Goi\u00e1s",
    "SE/S\u00e3o Miguel do Aleixo",
    "RJ/Santa Maria Madalena",
    "AM/Barcelos",
    "RS/Colinas",
    "TO/F\u00e1tima",
    "RJ/Para\u00edba do Sul",
    "PE/S\u00e3o Vicente Ferrer",
    "GO/Nova Igua\u00e7u de Goi\u00e1s",
    "PE/Iguaracy",
    "PA/Tail\u00e2ndia",
    "PR/Icara\u00edma",
    "PB/Monteiro",
    "BA/Feira de Santana",
    "MG/Paulistas",
    "PA/Quatipuru",
    "SP/Cerqueira C\u00e9sar",
    "BA/Muqu\u00e9m de S\u00e3o Francisco",
    "RS/Augusto Pestana",
    "AM/Itapiranga",
    "PE/Jaboat\u00e3o dos Guararapes",
    "PA/Itupiranga",
    "RN/Po\u00e7o Branco",
    "TO/Recursol\u00e2ndia",
    "RJ/Engenheiro Paulo de Frontin",
    "SC/Brun\u00f3polis",
    "RS/Cir\u00edaco",
    "MG/Leopoldina",
    "RJ/Itaperuna",
    "CE/Nova Russas",
    "PE/Tacaratu",
    "GO/Campo Alegre de Goi\u00e1s",
    "PE/Gameleira",
    "MG/Francisco Dumont",
    "AL/Paulo Jacinto",
    "GO/Cabeceiras",
    "RO/Machadinho D'Oeste",
    "MG/Ipaba",
    "MA/Jatob\u00e1",
    "RS/Bozano",
    "ES/Colatina",
    "PI/Capit\u00e3o Gerv\u00e1sio Oliveira",
    "PI/Inhuma",
    "SC/Canelinha",
    "GO/Goi\u00e2nia",
    "MG/Lontra",
    "AP/Cutias",
    "PI/Itain\u00f3polis",
    "PR/Medianeira",
    "PR/Peabiru",
    "BA/Coribe",
    "SP/Jarinu",
    "MG/Monte Azul",
    "RS/Iju\u00ed",
    "PI/Cabeceiras do Piau\u00ed",
    "PR/Jataizinho",
    "SC/S\u00e3o Bonif\u00e1cio",
    "RN/Almino Afonso",
    "RJ/Concei\u00e7\u00e3o de Macabu",
    "RN/Touros",
    "GO/Piracanjuba",
    "RN/A\u00e7u",
    "SC/Passos Maia",
    "SP/Dumont",
    "MG/Maria da F\u00e9",
    "TO/Barra do Ouro",
    "SE/Ros\u00e1rio do Catete",
    "RS/Sete de Setembro",
    "PR/Mariluz",
    "MG/Bonito de Minas",
    "PE/Altinho",
    "MS/Figueir\u00e3o",
    "MS/Inoc\u00eancia",
    "SC/Balne\u00e1rio Pi\u00e7arras",
    "MG/Carm\u00f3polis de Minas",
    "PE/Gravat\u00e1",
    "SC/Quilombo",
    "MG/Resplendor",
    "MA/Caxias",
    "MG/S\u00e3o Jo\u00e3o Evangelista",
    "GO/Edealina",
    "MA/Tut\u00f3ia",
    "MG/Olhos-d'\u00c1gua",
    "MG/S\u00e3o Joaquim de Bicas",
    "SC/Belmonte",
    "MS/Laguna Carap\u00e3",
    "PB/Prata",
    "PR/Tijucas do Sul",
    "SC/Papanduva",
    "RO/Jaru",
    "MG/Serra do Salitre",
    "MA/Brejo",
    "RS/Barra do Quara\u00ed",
    "SP/Jos\u00e9 Bonif\u00e1cio",
    "SC/\u00c1guas Mornas",
    "RS/Fazenda Vilanova",
    "BA/V\u00e1rzea do Po\u00e7o",
    "MA/Cajapi\u00f3",
    "SC/Morro Grande",
    "SC/Balne\u00e1rio Cambori\u00fa",
    "PR/Iracema do Oeste",
    "PB/Po\u00e7o de Jos\u00e9 de Moura",
    "MG/Cachoeira Dourada",
    "RJ/Belford Roxo",
    "RS/S\u00e3o Domingos do Sul",
    "ES/Alegre",
    "BA/Cocos",
    "BA/Campo Alegre de Lourdes",
    "MG/Wenceslau Braz",
    "SP/Conchal",
    "BA/Can\u00e1polis",
    "MG/Patis",
    "PE/Abreu e Lima",
    "RS/Brochier",
    "BA/Mascote",
    "SP/S\u00e3o Vicente",
    "GO/Itaguari",
    "SC/Vargem",
    "SP/Reden\u00e7\u00e3o da Serra",
    "GO/Palestina de Goi\u00e1s",
    "PI/Massap\u00ea do Piau\u00ed",
    "PE/Carpina",
    "RS/Jaguari",
    "SP/Itatiba",
    "MA/Santo Ant\u00f4nio dos Lopes",
    "BA/Ipecaet\u00e1",
    "PE/Verdejante",
    "MG/Vieiras",
    "MG/Verdel\u00e2ndia",
    "GO/Lagoa Santa",
    "MT/Jangada",
    "MG/Ibi\u00e1",
    "RS/Acegu\u00e1",
    "BA/Candeal",
    "MG/Sobr\u00e1lia",
    "RS/Alegria",
    "MT/Canabrava do Norte",
    "PB/Pianc\u00f3",
    "MG/Perdizes",
    "PE/Correntes",
    "RN/Ouro Branco",
    "RS/J\u00f3ia",
    "RS/Lavras do Sul",
    "MG/Alfenas",
    "SC/Ararangu\u00e1",
    "BA/Queimadas",
    "CE/Reriutaba",
    "BA/Santa Teresinha",
    "SP/Ipu\u00e3",
    "RO/Urup\u00e1",
    "MG/Ilic\u00ednea",
    "PR/Pranchita",
    "SP/B\u00e1lsamo",
    "SP/Salto",
    "SC/Cambori\u00fa",
    "PR/Corn\u00e9lio Proc\u00f3pio",
    "SC/Nova Itaberaba",
    "CE/Piquet Carneiro",
    "SC/Cap\u00e3o Alto",
    "SE/S\u00e3o Crist\u00f3v\u00e3o",
    "RO/Chupinguaia",
    "MS/Para\u00edso das \u00c1guas",
    "RS/S\u00e3o Vicente do Sul",
    "SE/Capela",
    "SP/Tarum\u00e3",
    "TO/Arraias",
    "MS/Terenos",
    "MG/S\u00e3o Jos\u00e9 do Alegre",
    "RS/Ernestina",
    "MT/Sorriso",
    "PA/Curion\u00f3polis",
    "SC/Ponte Alta",
    "PB/Juripiranga",
    "PE/Lagoa do Carro",
    "PB/Aroeiras",
    "GO/Caldas Novas",
    "BA/Livramento de Nossa Senhora",
    "MG/Santo Ant\u00f4nio do Grama",
    "SC/Itapema",
    "PA/Monte Alegre",
    "PR/Chopinzinho",
    "ES/\u00c1gua Doce do Norte",
    "MT/Cotrigua\u00e7u",
    "MG/Dores de Guanh\u00e3es",
    "MT/Vila Rica",
    "MS/Iguatemi",
    "SP/Ilha Solteira",
    "PI/Uni\u00e3o",
    "CE/Caridade",
    "AL/Matriz de Camaragibe",
    "RN/S\u00e3o Gon\u00e7alo do Amarante",
    "BA/Apuarema",
    "RN/Pedra Grande",
    "SP/Rifaina",
    "RS/Cerro Largo",
    "CE/Potengi",
    "BA/Pinda\u00ed",
    "SE/Est\u00e2ncia",
    "SP/Elisi\u00e1rio",
    "MG/Matozinhos",
    "GO/Guap\u00f3",
    "RJ/Guapimirim",
    "SP/Suzano",
    "MA/Cidel\u00e2ndia",
    "PR/Cafeara",
    "MG/Santa B\u00e1rbara do Tug\u00fario",
    "AM/Careiro",
    "MG/S\u00e3o Sebasti\u00e3o do Anta",
    "SC/Treviso",
    "AC/Epitaciol\u00e2ndia",
    "BA/Jequi\u00e9",
    "MT/Curvel\u00e2ndia",
    "TO/Baba\u00e7ul\u00e2ndia",
    "MT/Vale de S\u00e3o Domingos",
    "SC/Urupema",
    "PE/Exu",
    "RN/Bara\u00fana",
    "TO/Juarina",
    "SP/Avanhandava",
    "RJ/S\u00e3o Sebasti\u00e3o do Alto",
    "RN/Maxaranguape",
    "PR/Barra do Jacar\u00e9",
    "RJ/Nova Friburgo",
    "PA/Cachoeira do Piri\u00e1",
    "PE/Feira Nova",
    "MG/\u00c1gua Boa",
    "MA/Nova Iorque",
    "RS/S\u00e3o Gabriel",
    "BA/Contendas do Sincor\u00e1",
    "PI/Piripiri",
    "MG/Rio Piracicaba",
    "SE/Divina Pastora",
    "RJ/Porci\u00fancula",
    "SC/Xavantina",
    "MG/Santa Rita do Sapuca\u00ed",
    "SP/Santa Rita d'Oeste",
    "MG/Santana da Vargem",
    "PR/Campina Grande do Sul",
    "MG/Concei\u00e7\u00e3o de Ipanema",
    "PE/Riacho das Almas",
    "TO/Mateiros",
    "GO/Montes Claros de Goi\u00e1s",
    "AL/Cacimbinhas",
    "RS/Mato Castelhano",
    "BA/Iui\u00fa",
    "MG/Parais\u00f3polis",
    "SP/S\u00e3o Sebasti\u00e3o da Grama",
    "RN/Vi\u00e7osa",
    "AP/Pedra Branca do Amapari",
    "RS/Igrejinha",
    "MS/Taquarussu",
    "ES/Dores do Rio Preto",
    "TO/Marian\u00f3polis do Tocantins",
    "MG/Marilac",
    "RS/Cara\u00e1",
    "PA/Conc\u00f3rdia do Par\u00e1",
    "SP/Santa Mercedes",
    "PE/Caet\u00e9s",
    "PA/Salin\u00f3polis",
    "SP/Gavi\u00e3o Peixoto",
    "SP/Paranapu\u00e3",
    "SC/Lages",
    "MG/Prudente de Morais",
    "MT/Nova Cana\u00e3 do Norte",
    "RJ/Rio das Flores",
    "BA/Gentio do Ouro",
    "RN/Olho-d'\u00c1gua do Borges",
    "BA/Baixa Grande",
    "PA/M\u00e3e do Rio",
    "SP/Nova Campina",
    "RS/Porto Lucena",
    "BA/Ibipeba",
    "PR/Planalto",
    "RJ/Tangu\u00e1",
    "BA/Piritiba",
    "SC/Cunhata\u00ed",
    "PB/Catingueira",
    "RS/Sagrada Fam\u00edlia",
    "PI/Juazeiro do Piau\u00ed",
    "SP/Apia\u00ed",
    "PR/Porecatu",
    "AL/S\u00e3o Br\u00e1s",
    "PI/S\u00e3o F\u00e9lix do Piau\u00ed",
    "SC/Florian\u00f3polis",
    "RS/Alpestre",
    "SC/Canoinhas",
    "MG/Oriz\u00e2nia",
    "MG/Arax\u00e1",
    "GO/S\u00e3o Domingos",
    "PE/Alian\u00e7a",
    "SP/Morro Agudo",
    "MG/Quartel Geral",
    "SP/Ouroeste",
    "AC/Acrel\u00e2ndia",
    "MA/Pinheiro",
    "RS/Mato Leit\u00e3o",
    "AL/Ouro Branco",
    "PR/Paranagu\u00e1",
    "MA/Lago do Junco",
    "RO/Rio Crespo",
    "CE/Acara\u00fa",
    "GO/Posse",
    "MG/Pequi",
    "BA/S\u00e3o F\u00e9lix",
    "RR/Iracema",
    "AL/Capela",
    "MS/Navira\u00ed",
    "AL/Rio Largo",
    "MG/Guaxup\u00e9",
    "SP/Murutinga do Sul",
    "SC/Santa Terezinha",
    "SP/Getulina",
    "PE/Agrestina",
    "SC/Major Vieira",
    "MT/Lambari D'Oeste",
    "SC/Princesa",
    "MA/Araioses",
    "MG/S\u00e3o Jos\u00e9 do Goiabal",
    "PR/Ura\u00ed",
    "SP/Mirassol\u00e2ndia",
    "SP/Campina do Monte Alegre",
    "RS/S\u00e3o Jos\u00e9 do Norte",
    "BA/Igapor\u00e3",
    "PB/S\u00e3o Jo\u00e3o do Tigre",
    "MA/Carolina",
    "MG/Ara\u00fajos",
    "AC/Tarauac\u00e1",
    "RS/Ant\u00f4nio Prado",
    "MG/Caratinga",
    "BA/Quixabeira",
    "RS/Rio Grande",
    "MA/Aldeias Altas",
    "BA/Castro Alves",
    "MG/Claraval",
    "PR/Tibagi",
    "SC/Ouro Verde",
    "SP/S\u00e3o Paulo",
    "SC/Matos Costa",
    "PR/Cidade Ga\u00facha",
    "MG/Santana do Riacho",
    "MG/Carangola",
    "SE/Maruim",
    "PR/Paranapoema",
    "ES/Montanha",
    "MG/Cruzeiro da Fortaleza",
    "MG/Novo Cruzeiro",
    "RS/Gramado dos Loureiros",
    "CE/Itatira",
    "MT/Santa Carmem",
    "RN/Tangar\u00e1",
    "MA/Afonso Cunha",
    "BA/Nova Ibi\u00e1",
    "CE/Maracana\u00fa",
    "MA/Paraibano",
    "RS/S\u00e9rio",
    "BA/Santan\u00f3polis",
    "MT/Aren\u00e1polis",
    "SP/Pereira Barreto",
    "PI/Agricol\u00e2ndia",
    "MG/Santa F\u00e9 de Minas",
    "MA/Altamira do Maranh\u00e3o",
    "AL/Pindoba",
    "PR/Lidian\u00f3polis",
    "PE/Serrita",
    "PR/Marialva",
    "PA/Santa Maria do Par\u00e1",
    "MG/Andradas",
    "GO/An\u00e1polis",
    "PE/Macaparana",
    "SP/Paulic\u00e9ia",
    "PA/Altamira",
    "MA/Lagoa do Mato",
    "PA/Terra Alta",
    "SP/Joan\u00f3polis",
    "PB/Alhandra",
    "PB/Riacho dos Cavalos",
    "RS/Sarandi",
    "MS/Bandeirantes",
    "BA/Itabuna",
    "BA/C\u00edcero Dantas",
    "GO/Diorama",
    "AC/Porto Acre",
    "MG/Brumadinho",
    "MG/Carmo do Parana\u00edba",
    "RN/Felipe Guerra",
    "SC/Nova Trento",
    "PB/S\u00e3o Jos\u00e9 de Princesa",
    "BA/Tabocas do Brejo Velho",
    "PR/Serran\u00f3polis do Igua\u00e7u",
    "SP/Ouro Verde",
    "RS/Tr\u00eas Cachoeiras",
    "BA/Jaborandi",
    "PR/Capanema",
    "MA/Palmeir\u00e2ndia",
    "AC/Rio Branco",
    "PB/Areia",
    "MG/Abre Campo",
    "MG/Rubelita",
    "SC/Lacerd\u00f3polis",
    "CE/Croat\u00e1",
    "PR/Colombo",
    "AM/Novo Air\u00e3o",
    "RN/Parnamirim",
    "MG/Itamogi",
    "SC/Paial",
    "RN/Ipueira",
    "CE/Senador Pompeu",
    "SP/Nhandeara",
    "MG/Ninheira",
    "PR/General Carneiro",
    "CE/Chaval",
    "RS/Tupanciret\u00e3",
    "RS/Quinze de Novembro",
    "SP/Jambeiro",
    "RS/Viam\u00e3o",
    "RN/Taboleiro Grande",
    "MG/S\u00e3o Tiago",
    "MG/Formiga",
    "PA/Aveiro",
    "SC/Rio dos Cedros",
    "SP/Cruzeiro",
    "CE/Groa\u00edras",
    "SP/Indiapor\u00e3",
    "BA/Olindina",
    "CE/Pedra Branca",
    "ES/Afonso Cl\u00e1udio",
    "MG/Rio Vermelho",
    "RS/Quara\u00ed",
    "RS/Passa Sete",
    "PR/Nova Am\u00e9rica da Colina",
    "PR/Araruna",
    "CE/Baixio",
    "MG/Couto de Magalh\u00e3es de Minas",
    "PI/Santo In\u00e1cio do Piau\u00ed",
    "PR/Nova Londrina",
    "RJ/Itatiaia",
    "MA/Alto Alegre do Maranh\u00e3o",
    "PB/Riacho de Santo Ant\u00f4nio",
    "AM/Codaj\u00e1s",
    "RN/Santa Maria",
    "GO/Araguapaz",
    "PB/Fagundes",
    "MA/Urbano Santos",
    "CE/Alc\u00e2ntaras",
    "MG/Indian\u00f3polis",
    "MG/Santa Cruz de Salinas",
    "PI/Rio Grande do Piau\u00ed",
    "PE/Manari",
    "SC/Luzerna",
    "RS/Vale Real",
    "PR/Pinhal\u00e3o",
    "RS/Forquetinha",
    "SP/Jales",
    "MG/Capim Branco",
    "GO/Goianira",
    "MA/Itinga do Maranh\u00e3o",
    "CE/Ararend\u00e1",
    "CE/Acarape",
    "RS/Dom Pedro de Alc\u00e2ntara",
    "PR/S\u00e3o Jorge do Iva\u00ed",
    "SC/Herval d'Oeste",
    "MG/Orat\u00f3rios",
    "MG/S\u00e3o Gon\u00e7alo do Rio Preto",
    "PA/Rio Maria",
    "MG/Taiobeiras",
    "SP/Piacatu",
    "MA/Gon\u00e7alves Dias",
    "RN/V\u00e1rzea",
    "MS/Japor\u00e3",
    "MG/Planura",
    "SC/Romel\u00e2ndia",
    "SP/Valpara\u00edso",
    "MG/Po\u00e7os de Caldas",
    "RO/S\u00e3o Felipe D'Oeste",
    "GO/Cocalzinho de Goi\u00e1s",
    "SC/Ponte Serrada",
    "BA/Buerarema",
    "RS/Eldorado do Sul",
    "PR/Quitandinha",
    "DF/Bras\u00edlia",
    "PB/Quixaba",
    "SP/Mococa",
    "CE/Amontada",
    "RS/Vista Ga\u00facha",
    "SP/Pedrinhas Paulista",
    "TO/Concei\u00e7\u00e3o do Tocantins",
    "BA/Medeiros Neto",
    "AM/Manicor\u00e9",
    "BA/Amargosa",
    "GO/S\u00edtio d'Abadia",
    "SP/Santa Gertrudes",
    "SP/Paulo de Faria",
    "PE/Sirinha\u00e9m",
    "SP/Amparo",
    "MG/Santa Maria do Salto",
    "TO/Campos Lindos",
    "MG/Piedade de Ponte Nova",
    "MG/Ouro Preto",
    "RS/Rio dos \u00cdndios",
    "MG/Rio Doce",
    "MG/Naque",
    "BA/Barro Preto",
    "BA/Bonito",
    "MA/Mirinzal",
    "MA/Maraca\u00e7um\u00e9",
    "PR/Jaboti",
    "PI/Demerval Lob\u00e3o",
    "MG/Madre de Deus de Minas",
    "CE/Mira\u00edma",
    "RS/Liberato Salzano",
    "RS/Vera Cruz",
    "SP/Porto Ferreira",
    "MG/Presidente Kubitschek",
    "SC/Sider\u00f3polis",
    "CE/V\u00e1rzea Alegre",
    "PR/Tomazina",
    "MT/S\u00e3o Jos\u00e9 dos Quatro Marcos",
    "MG/Monte Carmelo",
    "SC/Novo Horizonte",
    "GO/Rubiataba",
    "BA/S\u00e3o Gon\u00e7alo dos Campos",
    "MG/Ladainha",
    "RS/Nova Palma",
    "MA/Sucupira do Norte",
    "PA/Pau D'Arco",
    "PA/Medicil\u00e2ndia",
    "BA/Utinga",
    "AL/Carneiros",
    "MA/Timon",
    "AC/Assis Brasil",
    "MG/Mamonas",
    "MG/Conquista",
    "BA/Ibipitanga",
    "AL/Igreja Nova",
    "MG/Pedralva",
    "MG/Papagaios",
    "SP/Limeira",
    "MA/Peritor\u00f3",
    "BA/Retirol\u00e2ndia",
    "PR/Boa Esperan\u00e7a",
    "SP/Taia\u00e7u",
    "PR/Uni\u00e3o da Vit\u00f3ria",
    "PE/Cedro",
    "MG/Bom Jesus da Penha",
    "RS/Mariano Moro",
    "MG/Bom Despacho",
    "RN/Jardim de Angicos",
    "RS/Alto Alegre",
    "MT/Bom Jesus do Araguaia",
    "BA/Vit\u00f3ria da Conquista",
    "RS/Prot\u00e1sio Alves",
    "ES/Venda Nova do Imigrante",
    "MS/Caarap\u00f3",
    "SP/Urup\u00eas",
    "PI/Lagoa de S\u00e3o Francisco",
    "AL/Joaquim Gomes",
    "MG/Ver\u00edssimo",
    "BA/Boa Vista do Tupim",
    "PR/Altamira do Paran\u00e1",
    "MG/Bom Jardim de Minas",
    "MG/Joaquim Fel\u00edcio",
    "PB/Sert\u00e3ozinho",
    "AL/Bel\u00e9m",
    "RS/S\u00e3o Francisco de Paula",
    "SP/Pitangueiras",
    "MA/Itaipava do Graja\u00fa",
    "SP/Mes\u00f3polis",
    "MG/Ros\u00e1rio da Limeira",
    "BA/Lic\u00ednio de Almeida",
    "PE/Itacuruba",
    "PR/Antonina",
    "SP/Dracena",
    "SC/Santa Rosa do Sul",
    "PR/Almirante Tamandar\u00e9",
    "BA/Itaju do Col\u00f4nia",
    "MG/S\u00e3o Jo\u00e3o do Manteninha",
    "PB/Cachoeira dos \u00cdndios",
    "TO/Pugmil",
    "BA/Ibirapu\u00e3",
    "SP/Bauru",
    "PA/Magalh\u00e3es Barata",
    "MA/Buritirana",
    "SP/Ibirarema",
    "RS/Vit\u00f3ria das Miss\u00f5es",
    "PR/Nossa Senhora das Gra\u00e7as",
    "RJ/Sumidouro",
    "MA/Paulino Neves",
    "SE/Carm\u00f3polis",
    "RS/Port\u00e3o",
    "MG/Divino das Laranjeiras",
    "MS/Bonito",
    "RN/Upanema",
    "MS/\u00c1gua Clara",
    "PI/Sebasti\u00e3o Leal",
    "SP/Ibir\u00e1",
    "RS/Charqueadas",
    "RJ/Cambuci",
    "MG/Jos\u00e9 Raydan",
    "CE/Apuiar\u00e9s",
    "PR/Pira\u00ed do Sul",
    "AM/S\u00e3o Gabriel da Cachoeira",
    "RS/Canudos do Vale",
    "RO/Alto Alegre dos Parecis",
    "RO/Buritis",
    "SC/Urubici",
    "BA/Janda\u00edra",
    "SP/Populina",
    "RS/Itati",
    "GO/Ouvidor",
    "PI/Ilha Grande",
    "MG/Botumirim",
    "RS/Ajuricaba",
    "PI/Piracuruca",
    "MG/Eugen\u00f3polis",
    "MA/Pio XII",
    "MG/S\u00e3o Br\u00e1s do Sua\u00e7u\u00ed",
    "MG/Baldim",
    "RS/Porto Xavier",
    "PE/Bet\u00e2nia",
    "PE/Passira",
    "RN/Portalegre",
    "TO/Bernardo Say\u00e3o",
    "AM/Santo Ant\u00f4nio do I\u00e7\u00e1",
    "RR/Amajari",
    "MG/Acaiaca",
    "PA/Santar\u00e9m",
    "PI/Santa Cruz dos Milagres",
    "MG/Te\u00f3filo Otoni",
    "RS/Guapor\u00e9",
    "PR/Fazenda Rio Grande",
    "SP/Orl\u00e2ndia",
    "MG/Pira\u00faba",
    "RN/S\u00e3o Francisco do Oeste",
    "RS/Santana da Boa Vista",
    "MS/Cassil\u00e2ndia",
    "SC/Governador Celso Ramos",
    "PR/Ponta Grossa",
    "SE/Gararu",
    "MT/Novo Horizonte do Norte",
    "MG/Itaguara",
    "PI/Francin\u00f3polis",
    "MG/Ant\u00f4nio Dias",
    "MG/Araponga",
    "PI/Caxing\u00f3",
    "SC/Sul Brasil",
    "PI/Queimada Nova",
    "MG/Dom Silv\u00e9rio",
    "PB/Cai\u00e7ara",
    "GO/Mara Rosa",
    "SC/Bra\u00e7o do Trombudo",
    "MS/Bela Vista",
    "SP/Silveiras",
    "MG/Itamarati de Minas",
    "MG/Ibiti\u00fara de Minas",
    "RS/Arroio dos Ratos",
    "BA/Baian\u00f3polis",
    "MG/Alto Rio Doce",
    "MG/Lumin\u00e1rias",
    "MG/Porteirinha",
    "MG/Dores\u00f3polis",
    "MG/Mira\u00ed",
    "PR/Rancho Alegre",
    "SP/Rafard",
    "MG/Jacutinga",
    "BA/Len\u00e7\u00f3is",
    "PI/Cocal dos Alves",
    "RJ/Arma\u00e7\u00e3o dos B\u00fazios",
    "BA/Uba\u00edra",
    "MG/Espinosa",
    "SP/Oriente",
    "SP/Novo Horizonte",
    "SP/Guar\u00e1",
    "PI/Lu\u00eds Correia",
    "MG/\u00c1guas Vermelhas",
    "BA/S\u00e3o Domingos",
    "MG/Arapor\u00e3",
    "RJ/Porto Real",
    "PR/Porto Barreiro",
    "PI/Alagoinha do Piau\u00ed",
    "MS/Gl\u00f3ria de Dourados",
    "MG/Caiana",
    "MT/Ribeir\u00e3o Cascalheira",
    "MG/Vargem Grande do Rio Pardo",
    "BA/Conde\u00faba",
    "MG/Ipanema",
    "RS/Jaquirana",
    "GO/Bela Vista de Goi\u00e1s",
    "GO/Itapirapu\u00e3",
    "PE/Lagoa Grande",
    "PR/Guarania\u00e7u",
    "RN/Flor\u00e2nia",
    "RJ/Teres\u00f3polis",
    "RN/Encanto",
    "RS/Nova Ara\u00e7\u00e1",
    "CE/S\u00e3o Jo\u00e3o do Jaguaribe",
    "RS/Pelotas",
    "PR/Marilena",
    "MT/Sinop",
    "PB/S\u00e3o Bentinho",
    "RS/Selbach",
    "SP/Glic\u00e9rio",
    "MG/Chapada Ga\u00facha",
    "RN/Rafael Godeiro",
    "PI/Eliseu Martins",
    "MG/Monjolos",
    "PE/Caruaru",
    "BA/Ribeir\u00e3o do Largo",
    "PB/S\u00e3o Vicente do Serid\u00f3",
    "BA/Souto Soares",
    "TO/Para\u00edso do Tocantins",
    "MG/S\u00e3o Gon\u00e7alo do Abaet\u00e9",
    "SP/Mirand\u00f3polis",
    "RO/Teixeir\u00f3polis",
    "BA/Santa Rita de C\u00e1ssia",
    "BA/Ipupiara",
    "SP/Motuca",
    "RS/Bom Princ\u00edpio",
    "RN/Tenente Laurentino Cruz",
    "MA/Boa Vista do Gurupi",
    "SE/Riachuelo",
    "RS/Arambar\u00e9",
    "SP/Nova Luzit\u00e2nia",
    "RJ/Trajano de Moraes",
    "RN/Mossor\u00f3",
    "ES/Iconha",
    "PA/Marab\u00e1",
    "MT/Novo Mundo",
    "SP/Guapiara",
    "RS/Vila Flores",
    "SP/S\u00e3o Roque",
    "RS/S\u00e3o Jos\u00e9 do Sul",
    "PI/Bonfim do Piau\u00ed",
    "MT/Reserva do Caba\u00e7al",
    "MA/Barreirinhas",
    "MA/Bernardo do Mearim",
    "SP/Borborema",
    "MG/Pedro Teixeira",
    "BA/Cacul\u00e9",
    "MG/Serra da Saudade",
    "PE/Paudalho",
    "PB/S\u00e3o Sebasti\u00e3o de Lagoa de Ro\u00e7a",
    "RS/Condor",
    "GO/Cavalcante",
    "PR/Mato Rico",
    "TO/Colinas do Tocantins",
    "PB/Joca Claudino",
    "ES/Rio Novo do Sul",
    "BA/Cabaceiras do Paragua\u00e7u",
    "SP/Queluz",
    "MG/Francisco S\u00e1",
    "MG/Senador Firmino",
    "RS/Tr\u00eas Arroios",
    "PI/Ribeiro Gon\u00e7alves",
    "RJ/Miracema",
    "SP/Tanabi",
    "RS/Esteio",
    "SP/Areias",
    "RS/Dois Irm\u00e3os",
    "PA/Chaves",
    "SC/Petrol\u00e2ndia",
    "SC/Itaja\u00ed",
    "RJ/Varre-Sai",
    "PR/Assa\u00ed",
    "BA/Acajutiba",
    "BA/C\u00e2ndido Sales",
    "SC/S\u00e3o Louren\u00e7o do Oeste",
    "GO/Cidade Ocidental",
    "SC/Pinheiro Preto",
    "SP/Ribeir\u00e3o Corrente",
    "MG/S\u00e3o Geraldo do Baixio",
    "PR/Abati\u00e1",
    "SP/Rinc\u00e3o",
    "RS/Vanini",
    "SP/Orindi\u00fava",
    "CE/Santana do Cariri",
    "RS/Nicolau Vergueiro",
    "BA/Aba\u00edra",
    "RS/Dona Francisca",
    "PR/S\u00e3o Jos\u00e9 da Boa Vista",
    "PB/Caturit\u00e9",
    "PR/Ibaiti",
    "ES/Santa Maria de Jetib\u00e1",
    "AM/Nhamund\u00e1",
    "MG/Muria\u00e9",
    "MT/Alto Paraguai",
    "RJ/Petr\u00f3polis",
    "PI/S\u00e3o Jo\u00e3o da Canabrava",
    "MG/Alpin\u00f3polis",
    "BA/Canudos",
    "MG/Jana\u00faba",
    "SP/Capivari",
    "RS/Maquin\u00e9",
    "RN/Serra do Mel",
    "SP/Floreal",
    "SP/Timburi",
    "GO/Iaciara",
    "BA/Serra Preta",
    "PB/Serra Grande",
    "MS/Sidrol\u00e2ndia",
    "PA/Brejo Grande do Araguaia",
    "RJ/Volta Redonda",
    "RO/Ji-Paran\u00e1",
    "MG/Al\u00e9m Para\u00edba",
    "GO/Santa Rita do Araguaia",
    "GO/Novo Gama",
    "BA/Botupor\u00e3",
    "PA/Camet\u00e1",
    "MG/Serran\u00f3polis de Minas",
    "SC/Meleiro",
    "PI/Canto do Buriti",
    "CE/Pacoti",
    "CE/Tabuleiro do Norte",
    "PE/Bodoc\u00f3",
    "PE/Bel\u00e9m de Maria",
    "SP/Potim",
    "SC/Cocal do Sul",
    "PR/Cambar\u00e1",
    "GO/Palmelo",
    "TO/Brejinho de Nazar\u00e9",
    "RS/Tenente Portela",
    "RS/Boqueir\u00e3o do Le\u00e3o",
    "ES/\u00c1guia Branca",
    "CE/Ipaumirim",
    "BA/Boninal",
    "PB/Pirpirituba",
    "MG/Cara\u00ed",
    "SP/Jaci",
    "SP/Santa F\u00e9 do Sul",
    "MG/Santa Rita de Jacutinga",
    "MA/S\u00e3o Domingos do Azeit\u00e3o",
    "GO/Buriti Alegre",
    "GO/Faina",
    "TO/Barrol\u00e2ndia",
    "PR/Pitanga",
    "MG/Santana de Cataguases",
    "AM/Amatur\u00e1",
    "MG/Bugre",
    "BA/Presidente J\u00e2nio Quadros",
    "BA/Barra da Estiva",
    "RS/Aratiba",
    "BA/S\u00e3o Desid\u00e9rio",
    "PR/Quer\u00eancia do Norte",
    "MT/S\u00e3o F\u00e9lix do Araguaia",
    "RS/Taba\u00ed",
    "GO/Ivol\u00e2ndia",
    "AL/Batalha",
    "MT/Uni\u00e3o do Sul",
    "RN/Montanhas",
    "PI/Paje\u00fa do Piau\u00ed",
    "MG/Santa B\u00e1rbara do Leste",
    "AL/Estrela de Alagoas",
    "SP/Esp\u00edrito Santo do Turvo",
    "BA/Mairi",
    "MT/Denise",
    "RJ/Saquarema",
    "SE/Santana do S\u00e3o Francisco",
    "MG/Corinto",
    "PR/Palmital",
    "PB/Sousa",
    "SP/Pedreira",
    "MA/Igarap\u00e9 do Meio",
    "MT/Barra do Gar\u00e7as",
    "PR/Morretes",
    "SC/Painel",
    "RN/Jucurutu",
    "RS/Sobradinho",
    "MG/Cuparaque",
    "PI/Monsenhor Hip\u00f3lito",
    "PI/Jardim do Mulato",
    "MG/Santana do Para\u00edso",
    "PB/Zabel\u00ea",
    "RN/Coronel Ezequiel",
    "CE/Jaguaruana",
    "PR/Inaj\u00e1",
    "MT/Vila Bela da Sant\u00edssima Trindade",
    "AP/Serra do Navio",
    "BA/Entre Rios",
    "TO/Angico",
    "PR/C\u00e2ndido de Abreu",
    "PR/Rondon",
    "TO/Rio dos Bois",
    "MG/Pedrin\u00f3polis",
    "MG/Natal\u00e2ndia",
    "BA/Cravol\u00e2ndia",
    "SC/Anita Garibaldi",
    "MS/Anauril\u00e2ndia",
    "CE/Ibicuitinga",
    "PI/Concei\u00e7\u00e3o do Canind\u00e9",
    "ES/Jer\u00f4nimo Monteiro",
    "SP/Jeriquara",
    "RS/Dom Feliciano",
    "SP/Pilar do Sul",
    "BA/Firmino Alves",
    "SP/Monte Mor",
    "TO/Cariri do Tocantins",
    "RN/Riacho da Cruz",
    "BA/Brejol\u00e2ndia",
    "CE/Paraipaba",
    "TO/Nova Olinda",
    "PI/Sebasti\u00e3o Barros",
    "PI/Flores do Piau\u00ed",
    "RN/Jardim de Piranhas",
    "CE/Iracema",
    "MG/Congonhas",
    "RS/Arroio do Sal",
    "SP/Ibitinga",
    "RJ/Cachoeiras de Macacu",
    "RS/Dois Lajeados",
    "SP/Pontal",
    "MG/Piedade de Caratinga",
    "GO/Para\u00fana",
    "PB/Junco do Serid\u00f3",
    "GO/Santa Helena de Goi\u00e1s",
    "SP/Avar\u00e9",
    "SP/Ilhabela",
    "BA/Itacar\u00e9",
    "MS/Dois Irm\u00e3os do Buriti",
    "BA/Santa Luzia",
    "CE/Palhano",
    "TO/Bom Jesus do Tocantins",
    "TO/Pium",
    "PR/Espig\u00e3o Alto do Igua\u00e7u",
    "MG/Manga",
    "MA/Bacabeira",
    "CE/Brejo Santo",
    "SP/Ribeir\u00e3o Grande",
    "CE/Porteiras",
    "MG/Cantagalo",
    "SP/Vinhedo",
    "TO/Dian\u00f3polis",
    "MG/Andrel\u00e2ndia",
    "RR/Pacaraima",
    "RJ/Areal",
    "MG/Tr\u00eas Pontas",
    "PI/Col\u00f4nia do Piau\u00ed",
    "MT/Rondon\u00f3polis",
    "MA/Mirador",
    "SC/S\u00e3o Carlos",
    "PI/Dom Expedito Lopes",
    "BA/Angical",
    "MG/Inga\u00ed",
    "SP/Araras",
    "MA/Vila Nova dos Mart\u00edrios",
    "MT/S\u00e3o Jos\u00e9 do Povo",
    "GO/Goian\u00e1polis",
    "SC/Luiz Alves",
    "MG/Ewbank da C\u00e2mara",
    "PI/Santo Ant\u00f4nio de Lisboa",
    "PR/Flora\u00ed",
    "TO/Silvan\u00f3polis",
    "MG/Juruaia",
    "SP/Elias Fausto",
    "AM/Silves",
    "SE/Nossa Senhora do Socorro",
    "CE/Massap\u00ea",
    "MG/Santa Rita de Caldas",
    "SE/Sim\u00e3o Dias",
    "SP/Agua\u00ed",
    "TO/Ponte Alta do Bom Jesus",
    "BA/Ubat\u00e3",
    "MA/Centro Novo do Maranh\u00e3o",
    "RN/Extremoz",
    "BA/Presidente Dutra",
    "SP/Emba\u00faba",
    "PI/Floriano",
    "BA/Coaraci",
    "SC/Irine\u00f3polis",
    "PR/In\u00e1cio Martins",
    "MG/Vespasiano",
    "PB/Bernardino Batista",
    "RS/Herval",
    "SP/Tejup\u00e1",
    "CE/Madalena",
    "PA/Faro",
    "BA/Paripiranga",
    "RS/Pouso Novo",
    "GO/Alto Horizonte",
    "RS/Sert\u00e3o Santana",
    "MG/S\u00e3o Jo\u00e3o das Miss\u00f5es",
    "RS/Rio Pardo",
    "SP/S\u00e3o Jos\u00e9 da Bela Vista",
    "BA/Concei\u00e7\u00e3o do Almeida",
    "SC/\u00c1guas de Chapec\u00f3",
    "BA/Bom Jesus da Lapa",
    "SP/Santa Ad\u00e9lia",
    "SE/Nossa Senhora da Gl\u00f3ria",
    "GO/Nova Crix\u00e1s",
    "MG/Florestal",
    "MG/Dom Vi\u00e7oso",
    "MG/Passa Tempo",
    "GO/Niquel\u00e2ndia",
    "PR/Londrina",
    "ES/Aracruz",
    "MG/S\u00e3o Francisco de Paula",
    "GO/Cachoeira Alta",
    "BA/Banza\u00ea",
    "PA/Barcarena",
    "RS/Garibaldi",
    "PA/Jacareacanga",
    "SC/Ibicar\u00e9",
    "PB/Cuitegi",
    "MT/Campos de J\u00falio",
    "PR/Cand\u00f3i",
    "BA/Catol\u00e2ndia",
    "MG/Cora\u00e7\u00e3o de Jesus",
    "MA/Campestre do Maranh\u00e3o",
    "CE/Pentecoste",
    "MG/Malacacheta",
    "PB/Pedra Branca",
    "PR/Ortigueira",
    "SP/Adolfo",
    "BA/Mortugaba",
    "MS/Caracol",
    "SC/Serra Alta",
    "PR/Siqueira Campos",
    "SP/Palmital",
    "MG/Serra dos Aimor\u00e9s",
    "RN/Macau",
    "RS/S\u00e3o Martinho",
    "MA/S\u00e3o Raimundo do Doca Bezerra",
    "RS/Relvado",
    "CE/Milagres",
    "MG/Itapecerica",
    "PA/Tracuateua",
    "AL/\u00c1gua Branca",
    "SP/Turmalina",
    "RS/Glorinha",
    "SP/Lins",
    "PB/Santa Luzia",
    "RS/Dezesseis de Novembro",
    "TO/Ponte Alta do Tocantins",
    "MG/S\u00e3o Geraldo",
    "SC/Arvoredo",
    "PE/Cabrob\u00f3",
    "SP/Francisco Morato",
    "SP/Monte Alto",
    "MG/Ant\u00f4nio Carlos",
    "PB/Monte Horebe",
    "MA/Cachoeira Grande",
    "RS/Nova Ramada",
    "PI/Dom Inoc\u00eancio",
    "SP/Aparecida",
    "PE/Panelas",
    "RS/S\u00e3o Pedro do Buti\u00e1",
    "RN/Venha-Ver",
    "MA/Senador La Rocque",
    "CE/Hidrol\u00e2ndia",
    "GO/S\u00e3o Patr\u00edcio",
    "MA/S\u00edtio Novo",
    "SP/Presidente Epit\u00e1cio",
    "TO/Palmeir\u00f3polis",
    "PI/Monte Alegre do Piau\u00ed",
    "SP/Sarapu\u00ed",
    "ES/Presidente Kennedy",
    "MG/Cristais",
    "AC/M\u00e2ncio Lima",
    "MG/S\u00e3o Gon\u00e7alo do Rio Abaixo",
    "AL/Belo Monte",
    "TO/Chapada da Natividade",
    "PI/Caldeir\u00e3o Grande do Piau\u00ed",
    "PR/Imba\u00fa",
    "RS/Manoel Viana",
    "SP/Sert\u00e3ozinho",
    "MG/Pedras de Maria da Cruz",
    "BA/Macarani",
    "PE/Ingazeira",
    "GO/Fazenda Nova",
    "RN/Riachuelo",
    "MG/S\u00e3o Gon\u00e7alo do Sapuca\u00ed",
    "PR/Santa M\u00f4nica",
    "SC/Monte Castelo",
    "RS/Ibia\u00e7\u00e1",
    "SP/Itaber\u00e1",
    "MG/Itumirim",
    "MG/Alagoa",
    "PR/Manoel Ribas",
    "MG/Santa Helena de Minas",
    "MA/Vit\u00f3ria do Mearim",
    "PI/S\u00e3o Francisco do Piau\u00ed",
    "PA/Novo Progresso",
    "BA/Casa Nova",
    "AM/Mau\u00e9s",
    "SP/S\u00e3o Louren\u00e7o da Serra",
    "RJ/Niter\u00f3i",
    "PR/Rio Bonito do Igua\u00e7u",
    "SC/Abelardo Luz",
    "PB/Pombal",
    "ES/Rio Bananal",
    "RS/Itaara",
    "PR/Quinta do Sol",
    "PA/Breves",
    "SP/Santa Cruz das Palmeiras",
    "BA/Itua\u00e7u",
    "RS/Porto Mau\u00e1",
    "PB/Cajazeiras",
    "RS/Sede Nova",
    "AL/Col\u00f4nia Leopoldina",
    "SP/Ol\u00edmpia",
    "MG/Diogo de Vasconcelos",
    "SP/Pontalinda",
    "PB/Ing\u00e1",
    "TO/Pau D'Arco",
    "RS/Unistalda",
    "SP/Caraguatatuba",
    "RS/S\u00e3o Pedro da Serra",
    "MG/Rio Novo",
    "PR/Mari\u00f3polis",
    "PR/Goioer\u00ea",
    "SP/Itirapina",
    "BA/Itapetinga",
    "RN/Pedro Velho",
    "PR/Saudade do Igua\u00e7u",
    "RN/Grossos",
    "PI/Olho D'\u00c1gua do Piau\u00ed",
    "GO/Jata\u00ed",
    "SP/Am\u00e9rico de Campos",
    "MS/S\u00e3o Gabriel do Oeste",
    "RN/Taipu",
    "GO/Auril\u00e2ndia",
    "RS/Cacequi",
    "TO/Santa Terezinha do Tocantins",
    "MG/Central de Minas",
    "RN/Senador Georgino Avelino",
    "RJ/Duas Barras",
    "SP/Alto Alegre",
    "RJ/Queimados",
    "BA/Boa Nova",
    "PE/Timba\u00faba",
    "GO/Santo Ant\u00f4nio da Barra",
    "PB/Nazarezinho",
    "MA/S\u00e3o Pedro dos Crentes",
    "BA/Am\u00e9rica Dourada",
    "BA/Ibitit\u00e1",
    "RS/Vacaria",
    "RS/Para\u00edso do Sul",
    "PI/Cajueiro da Praia",
    "MS/Bataguassu",
    "BA/Gandu",
    "PA/Terra Santa",
    "MT/Pocon\u00e9",
    "SE/Canind\u00e9 de S\u00e3o Francisco",
    "SP/Santa Clara d'Oeste",
    "GO/Hidrol\u00e2ndia",
    "RS/Minas do Le\u00e3o",
    "BA/Alcoba\u00e7a",
    "MA/S\u00e3o Jo\u00e3o dos Patos",
    "TO/Rio da Concei\u00e7\u00e3o",
    "RS/Harmonia",
    "SP/Angatuba",
    "MG/S\u00e3o Jo\u00e3o Batista do Gl\u00f3ria",
    "AL/Campo Grande",
    "MS/Maracaju",
    "MG/Minas Novas",
    "MG/Coronel Fabriciano",
    "MA/Colinas",
    "PR/Francisco Alves",
    "SP/C\u00e2ndido Rodrigues",
    "AM/Nova Olinda do Norte",
    "TO/Axix\u00e1 do Tocantins",
    "CE/Ipaporanga",
    "GO/Jaragu\u00e1",
    "PE/Brejo da Madre de Deus",
    "MG/Sabar\u00e1",
    "PI/Francisco Macedo",
    "GO/Itaj\u00e1",
    "GO/Piranhas",
    "MG/Bueno Brand\u00e3o",
    "GO/Teresina de Goi\u00e1s",
    "SP/S\u00e3o Miguel Arcanjo",
    "RS/Cangu\u00e7u",
    "MG/S\u00e3o Jo\u00e3o do Pacu\u00ed",
    "SP/Bento de Abreu",
    "MA/Po\u00e7\u00e3o de Pedras",
    "PE/Solid\u00e3o",
    "MT/Campo Verde",
    "PE/Po\u00e7\u00e3o",
    "RS/Entre-Iju\u00eds",
    "SP/Marab\u00e1 Paulista",
    "MG/Capara\u00f3",
    "MA/Paulo Ramos",
    "CE/Umari",
    "CE/Novo Oriente",
    "PE/Condado",
    "AL/Barra de S\u00e3o Miguel",
    "MA/Graja\u00fa",
    "CE/Beberibe",
    "SP/Alambari",
    "PB/Tavares",
    "MG/Pirajuba",
    "RN/Ba\u00eda Formosa",
    "BA/Itiru\u00e7u",
    "PI/Palmeira do Piau\u00ed",
    "RS/Marcelino Ramos",
    "RS/Estrela",
    "MT/Nova Ol\u00edmpia",
    "RS/Barros Cassal",
    "RS/Nonoai",
    "MG/Bonfin\u00f3polis de Minas",
    "MA/Anapurus",
    "RS/Canoas",
    "RS/Nova P\u00e1dua",
    "SP/Manduri",
    "MG/On\u00e7a de Pitangui",
    "SP/Arape\u00ed",
    "MG/S\u00e3o Jo\u00e3o da Lagoa",
    "SP/Paragua\u00e7u Paulista",
    "MG/Presidente Oleg\u00e1rio",
    "SC/Tun\u00e1polis",
    "RS/Santo \u00c2ngelo",
    "ES/S\u00e3o Gabriel da Palha",
    "RS/Sinimbu",
    "RS/Tapejara",
    "BA/Nazar\u00e9",
    "SP/Presidente Bernardes",
    "MG/Monte Si\u00e3o",
    "RS/Nova Roma do Sul",
    "MA/Centro do Guilherme",
    "ES/Gua\u00e7u\u00ed",
    "TO/Novo Alegre",
    "TO/Wanderl\u00e2ndia",
    "GO/Rialma",
    "SP/Mari\u00e1polis",
    "PE/Quixaba",
    "PI/Morro do Chap\u00e9u do Piau\u00ed",
    "MG/Rio Preto",
    "PB/Lagoa de Dentro",
    "SC/Api\u00fana",
    "RS/\u00c1urea",
    "PA/Sapucaia",
    "RN/S\u00e3o Jos\u00e9 do Campestre",
    "RS/Santo Ant\u00f4nio da Patrulha",
    "AL/Macei\u00f3",
    "SP/Guai\u00e7ara",
    "MG/Santo Ant\u00f4nio do Rio Abaixo",
    "SP/Bananal",
    "RS/Tr\u00eas Forquilhas",
    "SP/Assis",
    "MG/Matip\u00f3",
    "MA/Morros",
    "MG/Concei\u00e7\u00e3o da Aparecida",
    "SP/Nova Odessa",
    "ES/Pinheiros",
    "SP/Cunha",
    "PI/S\u00e3o Gon\u00e7alo do Piau\u00ed",
    "GO/Adel\u00e2ndia",
    "ES/Linhares",
    "RS/Campo Bom",
    "MT/Poxor\u00e9u",
    "SC/Planalto Alegre",
    "AL/Canapi",
    "PE/Ibimirim",
    "SP/Pindorama",
    "SC/S\u00e3o Joaquim",
    "GO/Americano do Brasil",
    "PR/Renascen\u00e7a",
    "PR/Campina da Lagoa",
    "RS/Quevedos",
    "SC/Ant\u00f4nio Carlos",
    "SP/Ariranha",
    "SP/Aparecida d'Oeste",
    "PR/F\u00eanix",
    "BA/Po\u00e7\u00f5es",
    "PE/Afr\u00e2nio",
    "RS/Tr\u00eas de Maio",
    "ES/Sooretama",
    "PR/Virmond",
    "RS/Victor Graeff",
    "SE/Aracaju",
    "SC/Caibi",
    "CE/Juazeiro do Norte",
    "BA/Uiba\u00ed",
    "MG/Serra Azul de Minas",
    "BA/Igrapi\u00fana",
    "SE/Riach\u00e3o do Dantas",
    "PR/Moreira Sales",
    "PI/S\u00e3o Jo\u00e3o da Fronteira",
    "SP/Barra do Chap\u00e9u",
    "TO/Sucupira",
    "SC/Leoberto Leal",
    "MT/Nova Santa Helena",
    "BA/Valen\u00e7a",
    "PR/Maria Helena",
    "RS/Monte Alegre dos Campos",
    "PB/Borborema",
    "BA/Serrol\u00e2ndia",
    "PB/Bara\u00fana",
    "GO/Israel\u00e2ndia",
    "RN/Galinhos",
    "SP/Ibi\u00fana",
    "PR/Bela Vista da Caroba",
    "PE/Sanhar\u00f3",
    "MA/Montes Altos",
    "CE/Itapaj\u00e9",
    "MG/Japonvar",
    "MT/S\u00e3o Pedro da Cipa",
    "AM/Urucar\u00e1",
    "SP/Nazar\u00e9 Paulista",
    "SC/Passo de Torres",
    "SP/S\u00e3o Bernardo do Campo",
    "MG/Baependi",
    "GO/Morro Agudo de Goi\u00e1s",
    "PI/Jurema",
    "SE/Pirambu",
    "SC/Ilhota",
    "PR/Ros\u00e1rio do Iva\u00ed",
    "GO/Jes\u00fapolis",
    "MT/Gl\u00f3ria D'Oeste",
    "BA/Pil\u00e3o Arcado",
    "RN/Equador",
    "RN/Areia Branca",
    "RS/Fontoura Xavier",
    "RS/Estrela Velha",
    "AM/Fonte Boa",
    "SP/Guaraci",
    "SP/General Salgado",
    "PR/S\u00e3o Pedro do Paran\u00e1",
    "RS/Bom Jesus",
    "SC/Cerro Negro",
    "SP/Jardin\u00f3polis",
    "PI/Landri Sales",
    "PB/Gurj\u00e3o",
    "RS/Tiradentes do Sul",
    "PR/Terra Rica",
    "SP/Santos",
    "PR/Nova Aurora",
    "RR/Mucaja\u00ed",
    "BA/Lafaiete Coutinho",
    "MG/Lima Duarte",
    "PI/S\u00e3o Miguel do Fidalgo",
    "AL/Palestina",
    "MS/Corumb\u00e1",
    "RJ/Paracambi",
    "SC/S\u00e3o Miguel da Boa Vista",
    "MG/Uberl\u00e2ndia",
    "MG/Cedro do Abaet\u00e9",
    "RS/Ip\u00ea",
    "MG/Itapeva",
    "MT/Campin\u00e1polis",
    "BA/Sapea\u00e7u",
    "PE/Sert\u00e2nia",
    "MA/Formosa da Serra Negra",
    "PE/Petrolina",
    "MG/Carea\u00e7u",
    "SE/Malhador",
    "MG/Itajub\u00e1",
    "SC/Corup\u00e1",
    "AM/Mara\u00e3",
    "MG/Patroc\u00ednio",
    "MA/Araguan\u00e3",
    "MG/Monte Belo",
    "MG/Santana do Manhua\u00e7u",
    "AL/Minador do Negr\u00e3o",
    "ES/Ibatiba",
    "GO/Mina\u00e7u",
    "RN/S\u00e3o Bento do Norte",
    "SP/Taquariva\u00ed",
    "BA/Umburanas",
    "MG/Jequitinhonha",
    "MG/Santa Vit\u00f3ria",
    "MG/Silvian\u00f3polis",
    "PB/Jacara\u00fa",
    "MG/Carmo do Rio Claro",
    "SC/Pouso Redondo",
    "AL/Maribondo",
    "SC/Barra Bonita",
    "BA/Itaberaba",
    "TO/Duer\u00e9",
    "PR/Maring\u00e1",
    "SP/Pereiras",
    "BA/Candeias",
    "PR/Santo In\u00e1cio",
    "BA/Piat\u00e3",
    "PR/Jardim Olinda",
    "MG/Comendador Gomes",
    "PR/Lobato",
    "MG/S\u00e3o Tom\u00e1s de Aquino",
    "AL/Branquinha",
    "PI/Jacobina do Piau\u00ed",
    "CE/Solon\u00f3pole",
    "SP/Piquerobi",
    "SP/Iaras",
    "GO/Bon\u00f3polis",
    "TO/Goianorte",
    "RN/S\u00e3o Jos\u00e9 do Serid\u00f3",
    "BA/Vereda",
    "MG/Piau",
    "CE/Paramoti",
    "RS/Coronel Pilar",
    "MA/Porto Franco",
    "PI/S\u00e3o Jo\u00e3o do Arraial",
    "SP/Quadra",
    "AM/Presidente Figueiredo",
    "BA/S\u00edtio do Mato",
    "PR/Nova Cantu",
    "BA/Tucano",
    "MG/Ribeir\u00e3o Vermelho",
    "CE/Antonina do Norte",
    "MG/Romaria",
    "MG/Campestre",
    "MG/Campan\u00e1rio",
    "MG/Santa Efig\u00eania de Minas",
    "MT/Santa Terezinha",
    "PB/Serra da Raiz",
    "PA/Capanema",
    "RO/Cerejeiras",
    "SP/Rubin\u00e9ia",
    "PI/Madeiro",
    "SC/S\u00e3o Jos\u00e9 do Cedro",
    "PB/Concei\u00e7\u00e3o",
    "GO/Chapad\u00e3o do C\u00e9u",
    "MT/Mirassol d'Oeste",
    "BA/Dias d'\u00c1vila",
    "BA/Laje",
    "SP/Andradina",
    "RS/Get\u00falio Vargas",
    "PR/Boa Vista da Aparecida",
    "SP/Gar\u00e7a",
    "SE/Ribeir\u00f3polis",
    "PE/Cust\u00f3dia",
    "AM/Barreirinha",
    "PA/Vigia",
    "PA/Viseu",
    "PB/Mataraca",
    "MG/Ituiutaba",
    "MG/Casa Grande",
    "MG/Santa Juliana",
    "MA/C\u00e2ndido Mendes",
    "RN/Santana do Matos",
    "GO/Urua\u00e7u",
    "SC/Lajeado Grande",
    "BA/Central",
    "PE/Araripina",
    "PA/Pacaj\u00e1",
    "BA/Ituber\u00e1",
    "MG/Albertina",
    "RN/Porto do Mangue",
    "AL/Olho d'\u00c1gua Grande",
    "CE/Tau\u00e1",
    "MG/V\u00e1rzea da Palma",
    "PA/S\u00e3o Miguel do Guam\u00e1",
    "SP/Paul\u00ednia",
    "SP/Monte Apraz\u00edvel",
    "AL/Igaci",
    "GO/Aragar\u00e7as",
    "TO/Tupirama",
    "GO/S\u00e3o Francisco de Goi\u00e1s",
    "PB/Santa In\u00eas",
    "SC/Pedras Grandes",
    "RJ/Rio das Ostras",
    "MG/Teixeiras",
    "RS/General C\u00e2mara",
    "GO/Acre\u00fana",
    "RS/Campestre da Serra",
    "TO/Pindorama do Tocantins",
    "PB/Boqueir\u00e3o",
    "PB/Cajazeirinhas",
    "RS/Espumoso",
    "MG/Piumhi",
    "PR/S\u00e3o Jos\u00e9 dos Pinhais",
    "SP/C\u00e1ssia dos Coqueiros",
    "PB/Boa Vista",
    "PR/S\u00e3o Jer\u00f4nimo da Serra",
    "RS/Taquara",
    "MG/Pe\u00e7anha",
    "SP/Conchas",
    "MA/Bom Jesus das Selvas",
    "SC/Presidente Get\u00falio",
    "TO/Taguatinga",
    "PE/Rio Formoso",
    "PR/Prudent\u00f3polis",
    "MS/Rio Negro",
    "RS/Ven\u00e2ncio Aires",
    "RS/Westf\u00e1lia",
    "PI/Brasileira",
    "BA/Ant\u00f4nio Cardoso",
    "MG/Coronel Murta",
    "MT/Paranatinga",
    "BA/Cordeiros",
    "AL/Coruripe",
    "RS/Barrac\u00e3o",
    "PR/Indian\u00f3polis",
    "RJ/Pinheiral",
    "RS/S\u00e3o Sep\u00e9",
    "GO/Davin\u00f3polis",
    "AC/Xapuri",
    "SC/Formosa do Sul",
    "RJ/Mangaratiba",
    "RS/S\u00e3o Jo\u00e3o da Urtiga",
    "MG/S\u00e3o Jo\u00e3o do Para\u00edso",
    "CE/Cruz",
    "AL/Paripueira",
    "CE/Baturit\u00e9",
    "MG/Oliveira Fortes",
    "RS/Para\u00ed",
    "MT/Carlinda",
    "MG/Coroaci",
    "RN/Guamar\u00e9",
    "PI/Santana do Piau\u00ed",
    "BA/Catu",
    "RS/Santa Maria",
    "GO/Naz\u00e1rio",
    "PA/Augusto Corr\u00eaa",
    "RJ/Paraty",
    "MG/Confins",
    "MG/Divino",
    "MT/\u00c1gua Boa",
    "AM/Juta\u00ed",
    "CE/Quiterian\u00f3polis",
    "RS/Cacique Doble",
    "GO/Gouvel\u00e2ndia",
    "MG/Pedra Dourada",
    "RN/Ja\u00e7an\u00e3",
    "SP/Ribeir\u00e3o Pires",
    "MT/Apiac\u00e1s",
    "CE/Cedro",
    "PB/Cabaceiras",
    "SC/Para\u00edso",
    "GO/Aragoi\u00e2nia",
    "MG/Marmel\u00f3polis",
    "CE/Quixad\u00e1",
    "RS/Monte Belo do Sul",
    "SP/Cubat\u00e3o",
    "AM/Careiro da V\u00e1rzea",
    "SE/Ilha das Flores",
    "PR/S\u00e3o Mateus do Sul",
    "MA/Icatu",
    "GO/Indiara",
    "RJ/Paty do Alferes",
    "SP/Mairinque",
    "BA/Juazeiro",
    "PB/S\u00e3o Jos\u00e9 dos Cordeiros",
    "PI/S\u00e3o Jo\u00e3o do Piau\u00ed",
    "BA/Santa B\u00e1rbara",
    "RS/Santa Cec\u00edlia do Sul",
    "RJ/Bom Jesus do Itabapoana",
    "AL/Jequi\u00e1 da Praia",
    "MG/S\u00e3o Jos\u00e9 do Jacuri",
    "MG/Itabira",
    "MG/Salto da Divisa",
    "AC/Sena Madureira",
    "MG/Santana do Deserto",
    "MG/Lagoa da Prata",
    "PI/S\u00e3o Juli\u00e3o",
    "GO/Doverl\u00e2ndia",
    "BA/Aramari",
    "MA/Pedreiras",
    "MG/Extrema",
    "RS/Palmares do Sul",
    "MG/Dores de Campos",
    "PR/Ouro Verde do Oeste",
    "MT/Dom Aquino",
    "PR/Hon\u00f3rio Serpa",
    "SP/V\u00e1rzea Paulista",
    "RN/Cai\u00e7ara do Rio do Vento",
    "MT/Juara",
    "RS/S\u00e3o Martinho da Serra",
    "RJ/Rio Bonito",
    "RJ/Mesquita",
    "PB/Mato Grosso",
    "SC/Doutor Pedrinho",
    "SP/Indiana",
    "PE/Ch\u00e3 Grande",
    "MG/S\u00e3o Jo\u00e3o da Mata",
    "BA/Conde",
    "PB/Serraria",
    "MG/Liberdade",
    "PI/Buriti dos Lopes",
    "MS/Pedro Gomes",
    "SP/Santana de Parna\u00edba",
    "MG/Vargem Bonita",
    "RS/S\u00e3o Jo\u00e3o do Pol\u00easine",
    "SP/Cachoeira Paulista",
    "CE/Potiretama",
    "RS/Campina das Miss\u00f5es",
    "SC/Garuva",
    "PB/S\u00e3o Sebasti\u00e3o do Umbuzeiro",
    "MG/S\u00e3o Roque de Minas",
    "CE/Momba\u00e7a",
    "CE/Fortaleza",
    "GO/Ipiranga de Goi\u00e1s",
    "ES/Muniz Freire",
    "MG/Manhumirim",
    "PI/Paulistana",
    "GO/Brazabrantes",
    "BA/Ponto Novo",
    "PB/Jeric\u00f3",
    "BA/Jacobina",
    "PR/Tamboara",
    "PI/Campo Largo do Piau\u00ed",
    "CE/Sobral",
    "PR/Paula Freitas",
    "MS/Costa Rica",
    "MG/Dom Cavati",
    "RN/Lagoa Nova",
    "SP/Uchoa",
    "RS/S\u00e3o Pedro das Miss\u00f5es",
    "PA/Eldorado do Caraj\u00e1s",
    "SP/Ara\u00e7ariguama",
    "MG/Machacalis",
    "PR/Matinhos",
    "RJ/Bom Jardim",
    "BA/Belo Campo",
    "RS/Araric\u00e1",
    "BA/Varzedo",
    "CE/Limoeiro do Norte",
    "MG/Materl\u00e2ndia",
    "RS/Progresso",
    "BA/Correntina",
    "MT/Juscimeira",
    "BA/Pira\u00ed do Norte",
    "AL/Barra de Santo Ant\u00f4nio",
    "AM/Tabatinga",
    "CE/Tarrafas",
    "PI/Sigefredo Pacheco",
    "SP/Hortol\u00e2ndia",
    "MG/Goiabeira",
    "PE/Jata\u00faba",
    "GO/Catal\u00e3o",
    "MA/S\u00e3o Jo\u00e3o Batista",
    "BA/Teofil\u00e2ndia",
    "MG/S\u00e3o Sebasti\u00e3o da Bela Vista",
    "RS/Carlos Barbosa",
    "SP/Bebedouro",
    "MA/S\u00e3o Benedito do Rio Preto",
    "AL/Traipu",
    "SP/Guaimb\u00ea",
    "PA/Breu Branco",
    "PA/Igarap\u00e9-A\u00e7u",
    "RS/Erval Grande",
    "RS/Cachoeira do Sul",
    "RS/S\u00e3o Pedro do Sul",
    "PR/Wenceslau Braz",
    "SP/Bar\u00e3o de Antonina",
    "AL/Palmeira dos \u00cdndios",
    "SP/Pirangi",
    "MA/Tuntum",
    "GO/Santo Ant\u00f4nio do Descoberto",
    "BA/Ibiassuc\u00ea",
    "MG/Pirangu\u00e7u",
    "PR/Anahy",
    "MA/Santa Luzia",
    "GO/Ed\u00e9ia",
    "MG/Delta",
    "MG/Ibituruna",
    "MG/Camanducaia",
    "MG/Palm\u00f3polis",
    "RJ/Campos dos Goytacazes",
    "SC/Tangar\u00e1",
    "SP/Birigui",
    "MG/Resende Costa",
    "PB/S\u00e3o Miguel de Taipu",
    "RS/S\u00e3o Miguel das Miss\u00f5es",
    "PE/Angelim",
    "RJ/Araruama",
    "TO/Taipas do Tocantins",
    "RJ/Cordeiro",
    "GO/Santa Isabel",
    "SP/Patroc\u00ednio Paulista",
    "MG/Tiradentes",
    "PR/Sapopema",
    "MA/Porto Rico do Maranh\u00e3o",
    "BA/Tanquinho",
    "RS/Sapucaia do Sul",
    "RO/Colorado do Oeste",
    "PI/Oeiras",
    "ES/Marechal Floriano",
    "PR/Balsa Nova",
    "SC/Ponte Alta do Norte",
    "RS/Hulha Negra",
    "MA/Amap\u00e1 do Maranh\u00e3o",
    "PI/Santa Luz",
    "RS/S\u00e3o Jos\u00e9 do Hort\u00eancio",
    "PA/Bannach",
    "MT/Feliz Natal",
    "MG/S\u00e3o Jos\u00e9 do Divino",
    "TO/Lagoa da Confus\u00e3o",
    "SC/Guaraciaba",
    "BA/Sim\u00f5es Filho",
    "SP/Tagua\u00ed",
    "MG/Inimutaba",
    "MG/Ira\u00ed de Minas",
    "GO/Alto Para\u00edso de Goi\u00e1s",
    "MG/Buritis",
    "CE/Catarina",
    "RS/Esmeralda",
    "BA/Cris\u00f3polis",
    "PI/Vera Mendes",
    "GO/S\u00e3o Miguel do Passa Quatro",
    "CE/Cascavel",
    "PR/Cerro Azul",
    "PR/Calif\u00f3rnia",
    "RS/S\u00e3o Valentim",
    "MG/Uba\u00ed",
    "SP/Bady Bassitt",
    "MG/Descoberto",
    "PB/Cara\u00fabas",
    "PI/Cristino Castro",
    "BA/Vera Cruz",
    "AC/Pl\u00e1cido de Castro",
    "RJ/Itagua\u00ed",
    "AM/Envira",
    "MG/Ponto Chique",
    "PR/Cafezal do Sul",
    "GO/Campestre de Goi\u00e1s",
    "RS/Pinhal da Serra",
    "PI/Francisco Ayres",
    "SP/Ara\u00e7oiaba da Serra",
    "AL/Girau do Ponciano",
    "PR/S\u00e3o Pedro do Igua\u00e7u",
    "MG/Patos de Minas",
    "PI/Santo Ant\u00f4nio dos Milagres",
    "MA/Bom Lugar",
    "MG/Catas Altas",
    "AC/Cruzeiro do Sul",
    "BA/Santo Est\u00eav\u00e3o",
    "AM/Atalaia do Norte",
    "MA/S\u00e3o Domingos do Maranh\u00e3o",
    "RS/Santa Clara do Sul",
    "SC/Bom Jesus do Oeste",
    "RS/Nova Santa Rita",
    "TO/Guara\u00ed",
    "SP/Narandiba",
    "SP/Cabr\u00e1lia Paulista",
    "PB/V\u00e1rzea",
    "MG/Rubim",
    "RR/S\u00e3o Luiz",
    "MA/Matinha",
    "RN/Rio do Fogo",
    "RS/Saldanha Marinho",
    "RJ/Cabo Frio",
    "RS/Tio Hugo",
    "SP/Esp\u00edrito Santo do Pinhal",
    "BA/Candiba",
    "MG/S\u00e3o Rom\u00e3o",
    "PR/Alvorada do Sul",
    "GO/Santa Tereza de Goi\u00e1s",
    "PA/Gurup\u00e1",
    "MT/Porto Estrela",
    "PE/Santa Cruz",
    "PI/Wall Ferraz",
    "AL/S\u00e3o Jos\u00e9 da Tapera",
    "MS/Nioaque",
    "MG/Biquinhas",
    "SC/Treze de Maio",
    "RS/Bar\u00e3o do Triunfo",
    "MG/Tapira",
    "MG/Itaip\u00e9",
    "GO/Marzag\u00e3o",
    "MG/Jacu\u00ed",
    "SC/Coronel Freitas",
    "GO/Mineiros",
    "SP/Fernand\u00f3polis",
    "RS/Morro Redondo",
    "GO/Heitora\u00ed",
    "SP/Iracem\u00e1polis",
    "RS/Almirante Tamandar\u00e9 do Sul",
    "TO/Palmeiras do Tocantins",
    "MG/Palma",
    "SP/Caiabu",
    "MG/Raul Soares",
    "TO/Santa Tereza do Tocantins",
    "AM/Itacoatiara",
    "RS/Arroio do Meio",
    "MA/Z\u00e9 Doca",
    "SC/\u00c1guas Frias",
    "TO/Luzin\u00f3polis",
    "SP/Araraquara",
    "SC/Itai\u00f3polis",
    "SP/Guararapes",
    "SP/Nova Granada",
    "PE/Quipap\u00e1",
    "GO/Buriti de Goi\u00e1s",
    "MG/Buritizeiro",
    "SC/Joinville",
    "SC/Faxinal dos Guedes",
    "CE/Ocara",
    "PI/Lagoa Alegre",
    "PA/Colares",
    "BA/Barrocas",
    "PB/S\u00e3o Jos\u00e9 de Caiana",
    "PE/Ipubi",
    "BA/Wagner",
    "MG/Engenheiro Navarro",
    "PR/S\u00e3o Jo\u00e3o do Caiu\u00e1",
    "RS/Santiago",
    "SP/Campo Limpo Paulista",
    "RS/Montauri",
    "CE/Miss\u00e3o Velha",
    "PE/S\u00e3o Louren\u00e7o da Mata",
    "SC/Agron\u00f4mica",
    "RN/S\u00e3o Miguel do Gostoso",
    "PI/Miguel Alves",
    "RS/S\u00e3o Sebasti\u00e3o do Ca\u00ed",
    "TO/Crix\u00e1s do Tocantins",
    "RS/Erebango",
    "RO/S\u00e3o Francisco do Guapor\u00e9",
    "PR/Floresta",
    "RJ/S\u00e3o Jo\u00e3o de Meriti",
    "SP/Ubarana",
    "RS/Barra do Guarita",
    "MA/Apicum-A\u00e7u",
    "MG/Paracatu",
    "GO/Mauril\u00e2ndia",
    "RS/Faxinal do Soturno",
    "BA/Biritinga",
    "MA/S\u00e3o Lu\u00eds Gonzaga do Maranh\u00e3o",
    "MT/Canarana",
    "MA/Davin\u00f3polis",
    "PB/M\u00e3e d'\u00c1gua",
    "TO/Miranorte",
    "PA/Brasil Novo",
    "PE/Santa Terezinha",
    "BA/Governador Mangabeira",
    "PR/Ita\u00fana do Sul",
    "MT/Acorizal",
    "PR/Tamarana",
    "AC/Feij\u00f3",
    "BA/Belmonte",
    "GO/Bom Jardim de Goi\u00e1s",
    "PB/Arara",
    "SC/Correia Pinto",
    "RN/Augusto Severo",
    "PI/Lagoinha do Piau\u00ed",
    "MG/Leandro Ferreira",
    "AL/Murici",
    "TO/Lavandeira",
    "MA/Passagem Franca",
    "SP/Ava\u00ed",
    "PB/Barra de S\u00e3o Miguel",
    "MG/Cabeceira Grande",
    "SP/Lagoinha",
    "SC/Garopaba",
    "TO/Santa F\u00e9 do Araguaia",
    "GO/Cachoeira de Goi\u00e1s",
    "PI/Palmeirais",
    "PB/Santana de Mangueira",
    "SC/Brusque",
    "MG/C\u00f3rrego Novo",
    "SP/Anhembi",
    "AL/Piranhas",
    "PB/Boa Ventura",
    "MT/Itanhang\u00e1",
    "MS/Rochedo",
    "GO/Avelin\u00f3polis",
    "PR/Vera Cruz do Oeste",
    "BA/Lu\u00eds Eduardo Magalh\u00e3es",
    "SP/Tamba\u00fa",
    "MG/Arcos",
    "MG/Itambacuri",
    "GO/Montividiu do Norte",
    "MA/Junco do Maranh\u00e3o",
    "RS/Mostardas",
    "PR/Uniflor",
    "MA/Fortaleza dos Nogueiras",
    "SP/Santo Andr\u00e9",
    "MS/Nova Alvorada do Sul",
    "MG/Passa Quatro",
    "SP/Dobrada",
    "PB/Congo",
    "MG/Rio Casca",
    "AP/Porto Grande",
    "SE/Feira Nova",
    "SP/\u00c1lvares Machado",
    "RS/Dom Pedrito",
    "BA/Ipir\u00e1",
    "MA/Riach\u00e3o",
    "PI/Bela Vista do Piau\u00ed",
    "CE/Carnaubal",
    "SP/Ibat\u00e9",
    "PR/Nova Alian\u00e7a do Iva\u00ed",
    "GO/Sanclerl\u00e2ndia",
    "RS/Cerro Grande",
    "MG/Paineiras",
    "TO/S\u00e3o Val\u00e9rio",
    "MS/Guia Lopes da Laguna",
    "MG/El\u00f3i Mendes",
    "PB/Itapororoca",
    "MG/Laranjal",
    "BA/Lauro de Freitas",
    "MG/Presidente Bernardes",
    "TO/Pedro Afonso",
    "MG/Delfin\u00f3polis",
    "MS/Jardim",
    "PA/Prainha",
    "ES/Barra de S\u00e3o Francisco",
    "SP/Batatais",
    "MG/Nova Ponte",
    "PR/Mangueirinha",
    "AM/S\u00e3o Sebasti\u00e3o do Uatum\u00e3",
    "TO/Esperantina",
    "BA/Nova F\u00e1tima",
    "RS/Santo Expedito do Sul",
    "BA/Maragogipe",
    "PE/Palmeirina",
    "PR/Ribeir\u00e3o do Pinhal",
    "CE/Eus\u00e9bio",
    "PE/Santa Cruz do Capibaribe",
    "RS/Tr\u00eas Passos",
    "BA/Wenceslau Guimar\u00e3es",
    "RS/Vista Alegre do Prata",
    "MS/Coronel Sapucaia",
    "RS/Ira\u00ed",
    "MG/Datas",
    "RS/S\u00e3o Jorge",
    "RN/Martins",
    "PI/V\u00e1rzea Branca",
    "MG/Alto Jequitib\u00e1",
    "PR/C\u00e9u Azul",
    "PA/Ouril\u00e2ndia do Norte",
    "PE/Primavera",
    "PR/Santa Cec\u00edlia do Pav\u00e3o",
    "MG/Munhoz",
    "PI/Campo Maior",
    "GO/S\u00e3o Sim\u00e3o",
    "PR/Joaquim T\u00e1vora",
    "PR/Adrian\u00f3polis",
    "SP/Vargem Grande do Sul",
    "PR/Bom Jesus do Sul",
    "RS/Pantano Grande",
    "MG/Lagoa Formosa",
    "SC/Galv\u00e3o",
    "MS/Santa Rita do Pardo",
    "PA/Goian\u00e9sia do Par\u00e1",
    "GO/Palmin\u00f3polis",
    "TO/S\u00edtio Novo do Tocantins",
    "SC/Chapad\u00e3o do Lageado",
    "RJ/Italva",
    "SP/Corumbata\u00ed",
    "PI/Guadalupe",
    "RS/Lindolfo Collor",
    "MG/Sabin\u00f3polis",
    "MG/Campo Florido",
    "MT/Confresa",
    "SP/Luc\u00e9lia",
    "RN/Doutor Severiano",
    "SC/Bigua\u00e7u",
    "PI/Jatob\u00e1 do Piau\u00ed",
    "RO/Seringueiras",
    "SE/Siriri",
    "MA/Dom Pedro",
    "RS/Barra do Ribeiro",
    "AL/Cra\u00edbas",
    "MG/Bicas",
    "MG/Bom Jesus do Galho",
    "AM/Uarini",
    "SP/Lu\u00eds Ant\u00f4nio",
    "MG/Monte Formoso",
    "MG/Cataguases",
    "BA/Santa Cruz Cabr\u00e1lia",
    "MG/Lavras",
    "RS/Chapada",
    "TO/Nazar\u00e9",
    "MG/Botelhos",
    "RS/Ibirapuit\u00e3",
    "SE/Nossa Senhora Aparecida",
    "MG/Leme do Prado",
    "MA/Turia\u00e7u",
    "SP/Potirendaba",
    "SP/Clementina",
    "MG/Reduto",
    "MG/Alfredo Vasconcelos",
    "CE/Jaguaribe",
    "SP/S\u00e3o Jos\u00e9 dos Campos",
    "MG/Sarzedo",
    "BA/Lagoa Real",
    "MT/Nobres",
    "PI/Barreiras do Piau\u00ed",
    "BA/Ibirapitanga",
    "MG/Itamb\u00e9 do Mato Dentro",
    "MG/Nepomuceno",
    "PI/Milton Brand\u00e3o",
    "MG/Santo Ant\u00f4nio do Aventureiro",
    "RO/Vale do Para\u00edso",
    "MA/S\u00e3o Vicente Ferrer",
    "SC/Cordilheira Alta",
    "MS/Brasil\u00e2ndia",
    "MG/Inconfidentes",
    "SC/S\u00e3o Cristov\u00e3o do Sul",
    "RS/Tramanda\u00ed",
    "GO/Jovi\u00e2nia",
    "PB/Santa Helena",
    "PB/Itaporanga",
    "MG/Santa Rosa da Serra",
    "RN/Jandu\u00eds",
    "TO/Piraqu\u00ea",
    "TO/Lizarda",
    "PI/Valen\u00e7a do Piau\u00ed",
    "PR/Camb\u00e9",
    "MT/Ipiranga do Norte",
    "PB/Bananeiras",
    "RS/Erval Seco",
    "BA/El\u00edsio Medrado",
    "SP/Brodowski",
    "MG/Monte Santo de Minas",
    "BA/Paulo Afonso",
    "AL/Limoeiro de Anadia",
    "SP/Coroados",
    "RN/Jardim do Serid\u00f3",
    "GO/Petrolina de Goi\u00e1s",
    "BA/Guajeru",
    "RN/Marcelino Vieira",
    "ES/Guarapari",
    "RO/Espig\u00e3o D'Oeste",
    "MA/Presidente Juscelino",
    "SC/Jardin\u00f3polis",
    "PI/Caracol",
    "CE/Pindoretama",
    "SP/Uni\u00e3o Paulista",
    "RS/S\u00e3o Valentim do Sul",
    "MG/Consola\u00e7\u00e3o",
    "RN/Jo\u00e3o Dias",
    "BA/Caravelas",
    "RN/Carnaubais",
    "MS/Paranhos",
    "BA/Sento S\u00e9",
    "RS/Gentil",
    "MS/Novo Horizonte do Sul",
    "PI/Buriti dos Montes",
    "PI/S\u00e3o Luis do Piau\u00ed",
    "PR/Florest\u00f3polis",
    "MT/Araputanga",
    "RR/Normandia",
    "SC/Capinzal",
    "SP/Tabo\u00e3o da Serra",
    "PI/S\u00e3o Pedro do Piau\u00ed",
    "SC/Abdon Batista",
    "RN/Bento Fernandes",
    "MG/S\u00e3o Jos\u00e9 da Varginha",
    "MG/Alvorada de Minas",
    "MG/Tarumirim",
    "TO/S\u00e3o Salvador do Tocantins",
    "SC/Alto Bela Vista",
    "SP/Barrinha",
    "SP/Jaboticabal",
    "SP/Martin\u00f3polis",
    "PR/Para\u00edso do Norte",
    "MG/Coqueiral",
    "BA/Crist\u00f3polis",
    "MG/Jeceaba",
    "SP/Bastos",
    "SC/Ca\u00e7ador",
    "BA/Jaguaquara",
    "MG/Aiuruoca",
    "GO/Itumbiara",
    "MA/Presidente Sarney",
    "PI/Castelo do Piau\u00ed",
    "AL/Japaratinga",
    "MT/General Carneiro",
    "SE/Pinh\u00e3o",
    "MG/Jampruca",
    "RO/Nova Mamor\u00e9",
    "TO/S\u00e3o Bento do Tocantins",
    "PA/\u00d3bidos",
    "SC/Rio do Sul",
    "PI/Bertol\u00ednia",
    "PE/Alagoinha",
    "PI/Nossa Senhora dos Rem\u00e9dios",
    "PR/S\u00e3o Jorge do Patroc\u00ednio",
    "PA/Moju",
    "BA/S\u00e3o Gabriel",
    "TO/Aparecida do Rio Negro",
    "PI/Barro Duro",
    "RN/Vera Cruz",
    "PR/Roncador",
    "SP/Pirapora do Bom Jesus",
    "AL/Jacar\u00e9 dos Homens",
    "MA/Coelho Neto",
    "SP/Sales",
    "SP/Santa Branca",
    "PB/Rem\u00edgio",
    "MG/Santo Ant\u00f4nio do Jacinto",
    "BA/Terra Nova",
    "PA/Santa Izabel do Par\u00e1",
    "SP/S\u00e3o Joaquim da Barra",
    "MG/Ja\u00edba",
    "SC/Urussanga",
    "SP/Suzan\u00e1polis",
    "MG/Nova Serrana",
    "SP/Guzol\u00e2ndia",
    "RO/Rolim de Moura",
    "PR/Porto Amazonas",
    "PR/Pontal do Paran\u00e1",
    "PA/Uruar\u00e1",
    "PE/Bom Jardim",
    "SC/Jacinto Machado",
    "PI/Campo Grande do Piau\u00ed",
    "PI/Teresina",
    "MG/Pescador",
    "ES/Atilio Vivacqua",
    "PB/Vista Serrana",
    "GO/\u00c1guas Lindas de Goi\u00e1s",
    "RS/Viadutos",
    "PB/S\u00e3o Jo\u00e3o do Rio do Peixe",
    "PI/J\u00falio Borges",
    "RS/Cachoeirinha",
    "RN/Messias Targino",
    "MA/Mata Roma",
    "SP/Campos do Jord\u00e3o",
    "PE/Santa Filomena",
    "AM/Humait\u00e1",
    "SE/Indiaroba",
    "BA/Salvador",
    "PB/Nova Palmeira",
    "PR/Tup\u00e3ssi",
    "SP/Mairipor\u00e3",
    "PE/Catende",
    "SP/Jundia\u00ed",
    "MG/Fortuna de Minas",
    "PB/Cruz do Esp\u00edrito Santo",
    "MG/Rio Acima",
    "SP/Pirassununga",
    "BA/Aracatu",
    "GO/Catura\u00ed",
    "BA/Filad\u00e9lfia",
    "MG/Serranos",
    "BA/Gavi\u00e3o",
    "SP/Piedade",
    "MG/Amparo do Serra",
    "AL/Santa Luzia do Norte",
    "SP/Itatinga",
    "PE/Ouricuri",
    "SP/Cardoso",
    "BA/Ara\u00e7as",
    "PR/Assis Chateaubriand",
    "MG/Grupiara",
    "MG/Augusto de Lima",
    "PB/S\u00e3o Bento",
    "AL/S\u00e3o Jos\u00e9 da Laje",
    "AL/Inhapi",
    "MS/Dourados",
    "RS/Lagoa dos Tr\u00eas Cantos",
    "PR/Engenheiro Beltr\u00e3o",
    "SP/Barretos",
    "SP/Barbosa",
    "RS/Gaurama",
    "GO/Santa B\u00e1rbara de Goi\u00e1s",
    "RN/Jos\u00e9 da Penha",
    "PE/Ita\u00edba",
    "SP/Lup\u00e9rcio",
    "RS/Doutor Ricardo",
    "CE/Guaramiranga",
    "PI/Cocal de Telha",
    "PA/Itaituba",
    "MT/Nova Guarita",
    "CE/Monsenhor Tabosa",
    "AM/L\u00e1brea",
    "SC/Jabor\u00e1",
    "MG/Pedra Bonita",
    "RS/Itapuca",
    "PE/Ribeir\u00e3o",
    "MS/Corguinho",
    "RS/Maximiliano de Almeida",
    "PR/Curitiba",
    "SP/Cosm\u00f3polis",
    "RJ/Aperib\u00e9",
    "MT/V\u00e1rzea Grande",
    "RS/Morma\u00e7o",
    "AM/Urucurituba",
    "MG/S\u00e3o Pedro dos Ferros",
    "PI/Floresta do Piau\u00ed",
    "PI/S\u00e3o Jos\u00e9 do Divino",
    "BA/D\u00e1rio Meira",
    "PR/Tuneiras do Oeste",
    "PB/Juazeirinho",
    "PE/Escada",
    "PA/Bom Jesus do Tocantins",
    "PE/S\u00e3o Benedito do Sul",
    "RS/Flores da Cunha",
    "SC/Major Gercino",
    "PR/Itaipul\u00e2ndia",
    "SP/Santo Expedito",
    "MA/Alc\u00e2ntara",
    "SC/Itapiranga",
    "SP/Mogi das Cruzes",
    "RS/Rodeio Bonito",
    "PB/Cuit\u00e9 de Mamanguape",
    "PR/Jani\u00f3polis",
    "AM/Japur\u00e1",
    "PE/Palmares",
    "MT/Colniza",
    "PR/Novo Itacolomi",
    "SP/Bertioga",
    "CE/Acopiara",
    "PE/Oroc\u00f3",
    "PI/Tamboril do Piau\u00ed",
    "PB/Diamante",
    "SP/Bragan\u00e7a Paulista",
    "MA/S\u00e3o Bernardo",
    "AM/Boca do Acre",
    "SP/Brotas",
    "TO/Monte do Carmo",
    "BA/Santana",
    "MA/Governador Eug\u00eanio Barros",
    "BA/Rio do Ant\u00f4nio",
    "PA/Placas",
    "PI/Boqueir\u00e3o do Piau\u00ed",
    "MG/Sem-Peixe",
    "RJ/Valen\u00e7a",
    "GO/Santo Ant\u00f4nio de Goi\u00e1s",
    "SP/Barra Bonita",
    "TO/Gurupi",
    "MG/Nova Resende",
    "RN/Janu\u00e1rio Cicco",
    "PE/Terezinha",
    "PI/Cristal\u00e2ndia do Piau\u00ed",
    "RS/Taquaru\u00e7u do Sul",
    "PI/Esperantina",
    "SP/Rio das Pedras",
    "PA/Maracan\u00e3",
    "RS/Tapera",
    "SC/Morro da Fuma\u00e7a",
    "PE/Tamandar\u00e9",
    "MG/Pint\u00f3polis",
    "BA/Santa In\u00eas",
    "GO/Santa Rosa de Goi\u00e1s",
    "BA/Caetit\u00e9",
    "PR/Astorga",
    "PA/Dom Eliseu",
    "PA/Floresta do Araguaia",
    "RJ/Vassouras",
    "PB/Soss\u00eago",
    "PE/Surubim",
    "RS/Dois Irm\u00e3os das Miss\u00f5es",
    "MG/Engenheiro Caldas",
    "PE/Flores",
    "PE/Bel\u00e9m do S\u00e3o Francisco",
    "BA/Madre de Deus",
    "PR/Campo Bonito",
    "MG/S\u00e3o Sebasti\u00e3o do Rio Verde",
    "SC/S\u00e3o Martinho",
    "PB/S\u00e3o Jos\u00e9 de Piranhas",
    "MG/S\u00e3o Jo\u00e3o do Oriente",
    "MG/Serro",
    "MA/Carutapera",
    "MA/S\u00e3o Pedro da \u00c1gua Branca",
    "PR/Barbosa Ferraz",
    "PB/Salgado de S\u00e3o F\u00e9lix",
    "RS/Cerrito",
    "RO/Castanheiras",
    "BA/Maca\u00fabas",
    "SP/Itapu\u00ed",
    "MA/Maraj\u00e1 do Sena",
    "PE/Inaj\u00e1",
    "RS/Alegrete",
    "SC/Crici\u00fama",
    "MA/Santa Rita",
    "PR/Ipor\u00e3",
    "MG/Soledade de Minas",
    "PR/Nova Esperan\u00e7a do Sudoeste",
    "MG/Matutina",
    "RS/Nova Hartz",
    "MG/Barroso",
    "RO/Parecis",
    "MG/Itanhomi",
    "RS/Sert\u00e3o",
    "SP/Irapu\u00e3",
    "PB/Soledade",
    "RS/Chu\u00ed",
    "RS/Os\u00f3rio",
    "MG/S\u00e3o Jos\u00e9 da Lapa",
    "RS/Terra de Areia",
    "PI/Baixa Grande do Ribeiro",
    "SP/Teodoro Sampaio",
    "MG/Caxambu",
    "AC/Jord\u00e3o",
    "RS/Rondinha",
    "SC/Modelo",
    "MG/Carana\u00edba",
    "TO/Palmeirante",
    "BA/Camamu",
    "MT/Bar\u00e3o de Melga\u00e7o",
    "RN/Jundi\u00e1",
    "SC/S\u00e3o Francisco do Sul",
    "SP/Ourinhos",
    "SC/Turvo",
    "MG/S\u00e3o Domingos das Dores",
    "MG/Nacip Raydan",
    "PR/Santa Terezinha de Itaipu",
    "PB/Mariz\u00f3polis",
    "MT/Diamantino",
    "AM/Tef\u00e9",
    "MG/Fronteira dos Vales",
    "MG/Ubaporanga",
    "PI/Paes Landim",
    "MG/Varj\u00e3o de Minas",
    "MT/S\u00e3o Jos\u00e9 do Xingu",
    "PR/Maril\u00e2ndia do Sul",
    "PE/Casinhas",
    "RS/\u00c1gua Santa",
    "MG/Gurinhat\u00e3",
    "MA/Tasso Fragoso",
    "AL/Monteir\u00f3polis",
    "MG/Carmo da Cachoeira",
    "MA/S\u00e3o Bento",
    "MA/S\u00e3o Jos\u00e9 dos Bas\u00edlios",
    "MG/S\u00e3o Sebasti\u00e3o da Vargem Alegre",
    "MS/Amambai",
    "PB/Nova Floresta",
    "ES/Apiac\u00e1",
    "SP/Pedregulho",
    "PB/S\u00e3o Domingos do Cariri",
    "PB/Sum\u00e9",
    "SP/Tupi Paulista",
    "MA/Bom Jardim",
    "ES/Laranja da Terra",
    "MG/Taquara\u00e7u de Minas",
    "MG/Jequitib\u00e1",
    "MG/Gr\u00e3o Mogol",
    "RR/Cant\u00e1",
    "BA/Presidente Tancredo Neves",
    "ES/Castelo",
    "CE/Camocim",
    "PA/Palestina do Par\u00e1",
    "SC/Rio das Antas",
    "MS/Rio Verde de Mato Grosso",
    "MG/Estrela do Sul",
    "MG/Senador Cortes",
    "MG/Joan\u00e9sia",
    "SC/Sombrio",
    "PE/S\u00e3o Jos\u00e9 do Belmonte",
    "MG/Santana do Garamb\u00e9u",
    "BA/Muniz Ferreira",
    "SP/Serrana",
    "MG/Riachinho",
    "MG/Jord\u00e2nia",
    "RJ/S\u00e3o Jo\u00e3o da Barra",
    "MG/Santo Ant\u00f4nio do Monte",
    "ES/S\u00e3o Domingos do Norte",
    "PE/Itapissuma",
    "PE/Garanhuns",
    "SP/Maraca\u00ed",
    "MA/Raposa",
    "AL/S\u00e3o Miguel dos Milagres",
    "RS/Lagoa Vermelha",
    "SP/Santa Rosa de Viterbo",
    "BA/Aurelino Leal",
    "TO/Sandol\u00e2ndia",
    "MG/Novorizonte",
    "RS/Catu\u00edpe",
    "RJ/S\u00e3o Jos\u00e9 do Vale do Rio Preto",
    "RJ/Quissam\u00e3",
    "PB/Riach\u00e3o do Po\u00e7o",
    "PR/Piraquara",
    "RS/Novo Hamburgo",
    "BA/Cafarnaum",
    "PB/S\u00e3o Jos\u00e9 dos Ramos",
    "PR/Laranjeiras do Sul",
    "RO/Ariquemes",
    "MA/Presidente Dutra",
    "AM/Caapiranga",
    "PR/Quatro Barras",
    "MG/Berizal",
    "PA/Ulian\u00f3polis",
    "AL/Boca da Mata",
    "RS/Charrua",
    "SC/Ipor\u00e3 do Oeste",
    "SC/Ibirama",
    "PE/Camaragibe",
    "MS/Camapu\u00e3",
    "RS/Tupandi",
    "GO/Guara\u00edta",
    "PA/Parauapebas",
    "MA/Fernando Falc\u00e3o",
    "GO/Aruan\u00e3",
    "PR/Cruzmaltina",
    "MG/Senador Jos\u00e9 Bento",
    "PR/Pi\u00ean",
    "SP/Embu das Artes",
    "SE/Umba\u00faba",
    "BA/Manoel Vitorino",
    "RS/Xangri-l\u00e1",
    "CE/Cari\u00fas",
    "PB/Bonito de Santa F\u00e9",
    "TO/Araguacema",
    "PA/Jacund\u00e1",
    "PR/Castro",
    "PB/Sol\u00e2nea",
    "MS/Ant\u00f4nio Jo\u00e3o",
    "AM/Anam\u00e3",
    "PB/Catol\u00e9 do Rocha",
    "BA/Milagres",
    "PA/Santar\u00e9m Novo",
    "PR/Nova Tebas",
    "RJ/Japeri",
    "PB/Barra de Santa Rosa",
    "PR/Marip\u00e1",
    "PR/Mambor\u00ea",
    "PR/S\u00e3o Jos\u00e9 das Palmeiras",
    "SP/Capela do Alto",
    "PE/S\u00e3o Joaquim do Monte",
    "PA/Salvaterra",
    "MG/Nat\u00e9rcia",
    "CE/Crate\u00fas",
    "MT/Pedra Preta",
    "RJ/Angra dos Reis",
    "MG/Miradouro",
    "MS/Miranda",
    "SP/Sarutai\u00e1",
    "MG/S\u00e3o Gon\u00e7alo do Par\u00e1",
    "MG/Catuti",
    "BA/Paratinga",
    "MA/Bequim\u00e3o",
    "MS/Itaquira\u00ed",
    "ES/S\u00e3o Roque do Cana\u00e3",
    "SP/Lut\u00e9cia",
    "MG/Crucil\u00e2ndia",
    "MG/Itabirinha",
    "SP/Cerquilho",
    "BA/Una",
    "MG/Olaria",
    "CE/Pereiro",
    "GO/Turv\u00e2nia",
    "SC/Tai\u00f3",
    "PB/Assun\u00e7\u00e3o",
    "PI/Bocaina",
    "PB/Gado Bravo",
    "PR/Santa Tereza do Oeste",
    "PE/Trindade",
    "AL/Maragogi",
    "TO/Colm\u00e9ia",
    "RN/Maca\u00edba",
    "RN/Ielmo Marinho",
    "PB/Igaracy",
    "SP/Maced\u00f4nia",
    "RN/Ita\u00fa",
    "BA/Uru\u00e7uca",
    "SP/Monteiro Lobato",
    "PR/Conselheiro Mairinck",
    "MS/Deod\u00e1polis",
    "SP/Zacarias",
    "PR/Bom Sucesso do Sul",
    "BA/Coronel Jo\u00e3o S\u00e1",
    "AL/Campestre",
    "MG/Coronel Pacheco",
    "RJ/Comendador Levy Gasparian",
    "CE/Ic\u00f3",
    "BA/Andorinha",
    "MA/Cururupu",
    "PR/Barrac\u00e3o",
    "PA/Aurora do Par\u00e1",
    "SP/Santo Anast\u00e1cio",
    "SP/Tr\u00eas Fronteiras",
    "SC/S\u00e3o Jo\u00e3o do Itaperi\u00fa",
    "PA/Limoeiro do Ajuru",
    "SP/Louveira",
    "GO/Carmo do Rio Verde",
    "SP/Palmares Paulista",
    "BA/Camacan",
    "RS/Encruzilhada do Sul",
    "PR/Salto do Lontra",
    "SP/\u00d3leo",
    "PB/Ouro Velho",
    "MG/Cordisl\u00e2ndia",
    "MT/Tangar\u00e1 da Serra",
    "MT/Barra do Bugres",
    "RS/Peju\u00e7ara",
    "MG/Congonhal",
    "PA/Paragominas",
    "PR/Corb\u00e9lia",
    "RS/Santa Cruz do Sul",
    "PR/Rio Bom",
    "PE/Cal\u00e7ado",
    "PR/Cruzeiro do Oeste",
    "AL/Satuba",
    "RS/Sapiranga",
    "SP/Juquitiba",
    "PI/\u00c1gua Branca",
    "TO/Presidente Kennedy",
    "PI/Sussuapara",
    "CE/Forquilha",
    "BA/Pedr\u00e3o",
    "MG/Fama",
    "PR/Tel\u00eamaco Borba",
    "SC/Bombinhas",
    "PR/Santo Ant\u00f4nio da Platina",
    "GO/S\u00e3o Luiz do Norte",
    "PE/Arcoverde",
    "SP/Guapia\u00e7u",
    "RS/Andr\u00e9 da Rocha",
    "SP/S\u00e3o Lu\u00eds do Paraitinga",
    "PA/Anapu",
    "MG/Maravilhas",
    "PA/Belterra",
    "CE/Granjeiro",
    "SP/Itaju",
    "SP/Paranapanema",
    "RS/Humait\u00e1",
    "MG/Tim\u00f3teo",
    "TO/Santa Rosa do Tocantins",
    "MG/Silveir\u00e2nia",
    "SC/Uni\u00e3o do Oeste",
    "SP/Porangaba",
    "SP/Mogi Gua\u00e7u",
    "MG/Santana do Jacar\u00e9",
    "SP/Igara\u00e7u do Tiet\u00ea",
    "GO/Mutun\u00f3polis",
    "ES/Jo\u00e3o Neiva",
    "SP/Sant\u00f3polis do Aguape\u00ed",
    "MG/Uberaba",
    "PR/Realeza",
    "SP/Ita\u00f3ca",
    "AM/Apu\u00ed",
    "RS/Pinto Bandeira",
    "SP/Santo Ant\u00f4nio do Pinhal",
    "RN/N\u00edsia Floresta",
    "MG/S\u00e3o Vicente de Minas",
    "PE/Bonito",
    "PR/Arapoti",
    "RN/Nova Cruz",
    "BA/Ia\u00e7u",
    "CE/Jardim",
    "SP/Santana da Ponte Pensa",
    "SP/Santa Maria da Serra",
    "RS/Nova Candel\u00e1ria",
    "MG/Senhora do Porto",
    "MG/Montes Claros",
    "RJ/Rio Claro",
    "PR/Amp\u00e9re",
    "SP/S\u00e3o Bento do Sapuca\u00ed",
    "SE/Macambira",
    "SC/Tr\u00eas Barras",
    "GO/Guarani de Goi\u00e1s",
    "PR/Vitorino",
    "RS/Linha Nova",
    "RS/Tavares",
    "SC/Trombudo Central",
    "SC/Anchieta",
    "BA/Cansan\u00e7\u00e3o",
    "SP/Gua\u00edra",
    "RS/Vila Maria",
    "MA/Peri Mirim",
    "MG/Taparuba",
    "MG/Capin\u00f3polis",
    "MG/Urucuia",
    "MG/Tapira\u00ed",
    "MG/Erv\u00e1lia",
    "CE/Pacajus",
    "RS/Casca",
    "SP/Nova Europa",
    "MG/Francisco Badar\u00f3",
    "MA/S\u00e3o Raimundo das Mangabeiras",
    "MT/Juruena",
    "SC/Imbuia",
    "PE/Jaqueira",
    "CE/Ibaretama",
    "PA/S\u00e3o Geraldo do Araguaia",
    "BA/Santo Amaro",
    "MG/Matias Cardoso",
    "RO/Costa Marques",
    "MG/Cachoeira da Prata",
    "RO/Monte Negro",
    "RN/Brejinho",
    "SP/Bernardino de Campos",
    "RS/Redentora",
    "PA/Santo Ant\u00f4nio do Tau\u00e1",
    "SP/Caiu\u00e1",
    "BA/Paramirim",
    "RS/Riozinho",
    "RS/Bag\u00e9",
    "SE/Salgado",
    "MT/Pontes e Lacerda",
    "SC/Piratuba",
    "TO/Tocantin\u00f3polis",
    "SC/I\u00e7ara",
    "RS/Colorado",
    "PB/S\u00e3o Francisco",
    "RS/Fagundes Varela",
    "SC/Calmon",
    "SE/Cedro de S\u00e3o Jo\u00e3o",
    "AL/Mar Vermelho",
    "SC/Lebon R\u00e9gis",
    "TO/Abreul\u00e2ndia",
    "CE/Aurora",
    "AL/Olho d'\u00c1gua do Casado",
    "TO/S\u00e3o F\u00e9lix do Tocantins",
    "BA/S\u00e3o Jos\u00e9 da Vit\u00f3ria",
    "SP/\u00c1lvares Florence",
    "PB/Ibiara",
    "SP/Cafel\u00e2ndia",
    "ES/Baixo Guandu",
    "PR/Primeiro de Maio",
    "MG/Juiz de Fora",
    "MG/Belo Horizonte",
    "CE/Morrinhos",
    "PI/Joca Marques",
    "PR/Guarapuava",
    "RS/Novo Barreiro",
    "ES/Muqui",
    "RS/Vale do Sol",
    "PR/Umuarama",
    "SC/Porto Uni\u00e3o",
    "MA/Cantanhede",
    "SC/Vargem Bonita",
    "MG/Carneirinho",
    "MA/Senador Alexandre Costa",
    "MS/Ribas do Rio Pardo",
    "MG/Marip\u00e1 de Minas",
    "PE/Petrol\u00e2ndia",
    "GO/Crom\u00ednia",
    "MG/Virgol\u00e2ndia",
    "PB/Olho d'\u00c1gua",
    "PR/Lupion\u00f3polis",
    "PA/Juruti",
    "MG/Seritinga",
    "PE/Parnamirim",
    "AL/Jaramataia",
    "GO/Valpara\u00edso de Goi\u00e1s",
    "SC/Xanxer\u00ea",
    "PI/Pimenteiras",
    "SC/S\u00e3o Bernardino",
    "RN/Lu\u00eds Gomes",
    "PE/Paulista",
    "PI/S\u00e3o Jo\u00e3o da Varjota",
    "RS/Nova Bassano",
    "BA/Canavieiras",
    "MA/S\u00e3o Francisco do Brej\u00e3o",
    "BA/Eun\u00e1polis",
    "RS/Soledade",
    "MG/Ibiraci",
    "MG/Capela Nova",
    "GO/Rio Quente",
    "SC/Dona Emma",
    "PR/Jaguaria\u00edva",
    "MG/Diamantina",
    "MG/Comercinho",
    "MG/Iturama",
    "MG/Jos\u00e9 Gon\u00e7alves de Minas",
    "PE/Machados",
    "MG/Merc\u00eas",
    "RN/Passagem",
    "MG/Fortaleza de Minas",
    "MG/Estrela do Indai\u00e1",
    "PR/Ver\u00ea",
    "PR/Francisco Beltr\u00e3o",
    "PE/Dormentes",
    "MG/Varginha",
    "MG/Inha\u00fama",
    "CE/Senador S\u00e1",
    "MA/Ros\u00e1rio",
    "ES/Domingos Martins",
    "MG/Umburatiba",
    "MG/Cana Verde",
    "BA/Canarana",
    "BA/Iti\u00faba",
    "SC/Bom Jardim da Serra",
    "MA/Pindar\u00e9-Mirim",
    "RS/Bar\u00e3o de Cotegipe",
    "MG/Luisburgo",
    "SP/Guare\u00ed",
    "TO/Monte Santo do Tocantins",
    "PB/Lagoa",
    "CE/Independ\u00eancia",
    "PI/Pau D'Arco do Piau\u00ed",
    "PI/Cajazeiras do Piau\u00ed",
    "PB/Pil\u00f5ezinhos",
    "RS/Novo Machado",
    "MG/Bar\u00e3o de Monte Alto",
    "MG/Caranda\u00ed",
    "PR/Santo Ant\u00f4nio do Sudoeste",
    "SC/Rio Negrinho",
    "BA/S\u00e3o Sebasti\u00e3o do Pass\u00e9",
    "SE/Barra dos Coqueiros",
    "TO/Praia Norte",
    "BA/Mirangaba",
    "RN/Para\u00fa",
    "BA/Nova Cana\u00e3",
    "MT/Primavera do Leste",
    "RS/Palmitinho",
    "SP/Sebastian\u00f3polis do Sul",
    "PR/Nova Prata do Igua\u00e7u",
    "MG/Caputira",
    "SP/Santa Ernestina",
    "AL/Major Isidoro",
    "BA/Pindoba\u00e7u",
    "SC/Joa\u00e7aba",
    "PI/Marcol\u00e2ndia",
    "CE/Tururu",
    "MG/Tocantins",
    "RN/S\u00e3o Pedro",
    "BA/Pirip\u00e1",
    "PA/Capit\u00e3o Po\u00e7o",
    "PR/Congonhinhas",
    "BA/Matina",
    "PR/Tapejara",
    "BA/Aratu\u00edpe",
    "PI/Lagoa do Barro do Piau\u00ed",
    "PE/Calumbi",
    "MG/Ponte Nova",
    "MG/Piracema",
    "AL/Passo de Camaragibe",
    "MG/Montalv\u00e2nia",
    "ES/Itarana",
    "PI/Itaueira",
    "CE/Fortim",
    "BA/Nova Soure",
    "MG/Francisc\u00f3polis",
    "MS/Sonora",
    "BA/Andara\u00ed",
    "PI/Altos",
    "GO/Mimoso de Goi\u00e1s",
    "CE/Campos Sales",
    "MG/Galil\u00e9ia",
    "GO/Novo Brasil",
    "PR/Itaperu\u00e7u",
    "SE/Boquim",
    "GO/Nova Am\u00e9rica",
    "SP/Presidente Alves",
    "PI/Porto",
    "SP/Mon\u00e7\u00f5es",
    "PB/Curral Velho",
    "PB/Nova Olinda",
    "BA/Macurur\u00e9",
    "SP/Piracicaba",
    "MG/Heliodora",
    "PR/Matel\u00e2ndia",
    "MT/Nova Brasil\u00e2ndia",
    "BA/Rio do Pires",
    "MG/Capit\u00f3lio",
    "RS/S\u00e3o Francisco de Assis",
    "MG/Belmiro Braga",
    "AL/Flexeiras",
    "MA/S\u00e3o Roberto",
    "BA/Itaet\u00e9",
    "BA/Capim Grosso",
    "PI/Boa Hora",
    "PR/Brasil\u00e2ndia do Sul",
    "MG/Esmeraldas",
    "SP/Dirce Reis",
    "MA/Lu\u00eds Domingues",
    "RS/S\u00e3o Borja",
    "BA/Lajed\u00e3o",
    "MG/Bom Jesus do Amparo",
    "MG/Senhora dos Rem\u00e9dios",
    "MG/Santana dos Montes",
    "MG/Monte Alegre de Minas",
    "MG/Alvarenga",
    "RJ/Carmo",
    "MA/Buriticupu",
    "RJ/Duque de Caxias",
    "RO/Guajar\u00e1-Mirim",
    "RS/Marques de Souza",
    "SP/Agudos",
    "PR/Alto Piquiri",
    "MG/Campanha",
    "SC/Navegantes",
    "SP/Monte Castelo",
    "SC/Praia Grande",
    "PI/Curralinhos",
    "AP/Amap\u00e1",
    "GO/Itaguaru",
    "RS/Machadinho",
    "SP/Jumirim",
    "PI/Fartura do Piau\u00ed",
    "BA/Ribeira do Pombal",
    "CE/Iguatu",
    "SP/S\u00e3o Jo\u00e3o do Pau d'Alho",
    "PR/Rol\u00e2ndia",
    "PR/S\u00e3o Tom\u00e9",
    "MG/S\u00e3o Jo\u00e3o da Ponte",
    "SP/Panorama",
    "SP/Presidente Venceslau",
    "MG/Catuji",
    "PE/\u00c1gua Preta",
    "GO/Bom Jesus de Goi\u00e1s",
    "PR/S\u00e3o Jo\u00e3o do Triunfo",
    "PI/Barra D'Alc\u00e2ntara",
    "GO/Santa Terezinha de Goi\u00e1s",
    "SE/Santa Luzia do Itanhy",
    "RN/Janda\u00edra",
    "SE/Itabi",
    "SP/Bom Sucesso de Itarar\u00e9",
    "RO/Alta Floresta D'Oeste",
    "SP/Rancharia",
    "RN/Serrinha dos Pintos",
    "SC/Indaial",
    "RO/Cujubim",
    "RJ/Maric\u00e1",
    "BA/Santaluz",
    "MG/Cl\u00e1udio",
    "SP/Catigu\u00e1",
    "CE/Mucambo",
    "RN/S\u00e3o Jo\u00e3o do Sabugi",
    "RN/Japi",
    "PR/Ivat\u00e9",
    "CE/Erer\u00ea",
    "RO/Alvorada D'Oeste",
    "SP/Juqui\u00e1",
    "PB/Uira\u00fana",
    "SC/Gravatal",
    "TO/Araguatins",
    "PE/Nazar\u00e9 da Mata",
    "PA/Reden\u00e7\u00e3o",
    "PB/Teixeira",
    "BA/\u00c1gua Fria",
    "BA/Ichu",
    "MT/Tapurah",
    "MA/Serrano do Maranh\u00e3o",
    "PB/Barra de Santana",
    "BA/Rodelas",
    "MS/Rio Brilhante",
    "GO/Formosa",
    "RN/Ant\u00f4nio Martins",
    "TO/Arapoema",
    "PR/Lunardelli",
    "MG/Bras\u00edlia de Minas",
    "GO/Portel\u00e2ndia",
    "MG/Angel\u00e2ndia",
    "MA/Olinda Nova do Maranh\u00e3o",
    "SP/Leme",
    "PR/Campo Mour\u00e3o",
    "MG/Mirav\u00e2nia",
    "SP/Nuporanga",
    "MA/Governador Edison Lob\u00e3o",
    "RS/Tr\u00eas Coroas",
    "BA/Caturama",
    "PR/Marmeleiro",
    "RS/Caibat\u00e9",
    "BA/Cora\u00e7\u00e3o de Maria",
    "TO/Aragua\u00e7u",
    "RS/Restinga S\u00eaca",
    "RN/Pedro Avelino",
    "SP/Paraibuna",
    "PA/Garraf\u00e3o do Norte",
    "SP/Descalvado",
    "BA/Ibicara\u00ed",
    "PE/Bom Conselho",
    "MA/Alto Alegre do Pindar\u00e9",
    "PB/Alagoa Nova",
    "MG/Divisa Alegre",
    "RS/Mu\u00e7um",
    "CE/Itai\u00e7aba",
    "PB/Matinhas",
    "MA/Lago da Pedra",
    "BA/Ouri\u00e7angas",
    "SC/Pescaria Brava",
    "PR/Doutor Camargo",
    "TO/Itaguatins",
    "RR/Rorain\u00f3polis",
    "RS/Farroupilha",
    "MT/Tesouro",
    "PB/Tapero\u00e1",
    "MA/Estreito",
    "AL/Cajueiro",
    "MG/S\u00e3o Pedro do Sua\u00e7u\u00ed",
    "RS/Imb\u00e9",
    "SP/Salmour\u00e3o",
    "RN/S\u00e3o Fernando",
    "SC/Lauro Muller",
    "PR/Guamiranga",
    "SP/S\u00e3o Jo\u00e3o da Boa Vista",
    "BA/Serra do Ramalho",
    "GO/Alo\u00e2ndia",
    "RS/Santo Cristo",
    "SC/S\u00e3o Bento do Sul",
    "SC/Marema",
    "MG/Veredinha",
    "RS/Parob\u00e9",
    "BA/Santa Maria da Vit\u00f3ria",
    "PB/Santana dos Garrotes",
    "PI/Acau\u00e3",
    "CE/Altaneira",
    "RS/Independ\u00eancia",
    "MG/Juven\u00edlia",
    "RS/Alvorada",
    "MG/Padre Para\u00edso",
    "GO/Corumba\u00edba",
    "CE/Bela Cruz",
    "RN/Rodolfo Fernandes",
    "RS/Nova Petr\u00f3polis",
    "MT/Figueir\u00f3polis D'Oeste",
    "PR/Iguatu",
    "PA/Concei\u00e7\u00e3o do Araguaia",
    "RS/Lago\u00e3o",
    "SP/Caieiras",
    "SP/S\u00e3o Jo\u00e3o de Iracema",
    "RJ/Macuco",
    "MG/Mato Verde",
    "MT/Alto Taquari",
    "TO/Divin\u00f3polis do Tocantins",
    "SP/Len\u00e7\u00f3is Paulista",
    "SP/Boa Esperan\u00e7a do Sul",
    "SP/Oscar Bressane",
    "SC/Rio do Oeste",
    "SE/Ne\u00f3polis",
    "GO/Corumb\u00e1 de Goi\u00e1s",
    "MG/Iapu",
    "SC/Conc\u00f3rdia",
    "PE/Afogados da Ingazeira",
    "MA/Bela Vista do Maranh\u00e3o",
    "MG/Pingo-d'\u00c1gua",
    "MG/Pocrane",
    "PR/Farol",
    "PR/Santo Ant\u00f4nio do Para\u00edso",
    "RR/Boa Vista",
    "PE/Moreil\u00e2ndia",
    "SP/Po\u00e1",
    "RS/Vale Verde",
    "RS/Sant'Ana do Livramento",
    "RS/S\u00e3o Jos\u00e9 do Inhacor\u00e1",
    "PA/Tucum\u00e3",
    "BA/Nova Reden\u00e7\u00e3o",
    "MS/Nova Andradina",
    "PI/Col\u00f4nia do Gurgu\u00e9ia",
    "RS/Boa Vista das Miss\u00f5es",
    "MG/Campina Verde",
    "SP/Itapevi",
    "BA/Irec\u00ea",
    "MA/Central do Maranh\u00e3o",
    "SP/Lorena",
    "SE/Moita Bonita",
    "SE/General Maynard",
    "PA/Peixe-Boi",
    "SC/Bom Jesus",
    "RN/Serrinha",
    "SE/Nossa Senhora das Dores",
    "RN/S\u00edtio Novo",
    "RS/Cristal",
    "SC/Irati",
    "PA/Oriximin\u00e1",
    "PA/S\u00e3o Jo\u00e3o do Araguaia",
    "RS/Piratini",
    "SP/Engenheiro Coelho",
    "PI/Jaic\u00f3s",
    "MA/S\u00e3o Lu\u00eds",
    "PI/Monsenhor Gil",
    "PB/Massaranduba",
    "RS/Salto do Jacu\u00ed",
    "AL/S\u00e3o Sebasti\u00e3o",
    "CE/Boa Viagem",
    "GO/Jussara",
    "RS/Serafina Corr\u00eaa",
    "PE/Pombos",
    "SC/Ouro",
    "MG/Mata Verde",
    "SP/Nova Independ\u00eancia",
    "SC/Palma Sola",
    "MT/Peixoto de Azevedo",
    "SP/Promiss\u00e3o",
    "MG/C\u00f3rrego do Bom Jesus",
    "RS/Canela",
    "PR/Jesu\u00edtas",
    "SC/Monte Carlo",
    "PA/Bujaru",
    "TO/Aragominas",
    "RS/Mato Queimado",
    "MG/Santo Ant\u00f4nio do Itamb\u00e9",
    "MA/Axix\u00e1",
    "SP/Votuporanga",
    "SP/Iporanga",
    "GO/Brit\u00e2nia",
    "PR/Bituruna",
    "GO/Palmeiras de Goi\u00e1s",
    "SC/Santa Helena",
    "PE/Toritama",
    "MG/Chal\u00e9",
    "MG/Indaiabira",
    "GO/Montividiu",
    "PI/Curimat\u00e1",
    "MG/Ipatinga",
    "MG/Governador Valadares",
    "BA/Abar\u00e9",
    "SP/Guaratinguet\u00e1",
    "SE/Amparo de S\u00e3o Francisco",
    "RN/Jo\u00e3o C\u00e2mara",
    "PB/Caapor\u00e3",
    "SC/Flor do Sert\u00e3o",
    "MG/Tombos",
    "PA/Cumaru do Norte",
    "RJ/Natividade",
    "AM/Tapau\u00e1",
    "MG/Funil\u00e2ndia",
    "GO/Itarum\u00e3",
    "PR/Clevel\u00e2ndia",
    "PI/Tanque do Piau\u00ed",
    "MG/Frei Lagonegro",
    "MG/Divisa Nova",
    "RS/Palmeira das Miss\u00f5es",
    "SC/\u00c1gua Doce",
    "SP/Ipe\u00fana",
    "BA/Santa Cruz da Vit\u00f3ria",
    "PA/Curu\u00e7\u00e1",
    "GO/Santa F\u00e9 de Goi\u00e1s",
    "BA/Mundo Novo",
    "MG/Ferros",
    "AP/Vit\u00f3ria do Jari",
    "SP/Santa Cruz da Concei\u00e7\u00e3o",
    "MT/Vera",
    "RS/Herveiras",
    "PI/Avelino Lopes",
    "SP/Valinhos",
    "SP/Arei\u00f3polis",
    "SE/Areia Branca",
    "MS/Parana\u00edba",
    "MA/Lagoa Grande do Maranh\u00e3o",
    "MG/Carrancas",
    "PR/Corumbata\u00ed do Sul",
    "SC/Barra Velha",
    "MG/Tr\u00eas Marias",
    "MT/S\u00e3o Jos\u00e9 do Rio Claro",
    "SP/Hercul\u00e2ndia",
    "SP/Casa Branca",
    "SP/Santa Cruz do Rio Pardo",
    "GO/Aparecida de Goi\u00e2nia",
    "PB/Dami\u00e3o",
    "MG/Bar\u00e3o de Cocais",
    "BA/S\u00e3o Francisco do Conde",
    "AL/Roteiro",
    "MG/Atal\u00e9ia",
    "GO/Itapaci",
    "PI/Pedro II",
    "BA/Ca\u00e9m",
    "BA/Encruzilhada",
    "BA/Brotas de Maca\u00fabas",
    "SP/Caconde",
    "MS/Alcin\u00f3polis",
    "MG/Bom Repouso",
    "MA/Governador Luiz Rocha",
    "RS/Amaral Ferrador",
    "SC/Guabiruba",
    "RN/Pil\u00f5es",
    "PR/Nova F\u00e1tima",
    "PI/Corrente",
    "PB/Imaculada",
    "RJ/Pira\u00ed",
    "BA/Mucug\u00ea",
    "ES/Divino de S\u00e3o Louren\u00e7o",
    "MG/Tupaciguara",
    "PR/Formosa do Oeste",
    "GO/Turvel\u00e2ndia",
    "RS/Tapes",
    "SP/Pedran\u00f3polis",
    "PR/Santa Am\u00e9lia",
    "SC/S\u00e3o Domingos",
    "PR/Pato Bragado",
    "MS/Chapad\u00e3o do Sul",
    "PB/Alagoinha",
    "RS/Novo Cabrais",
    "TO/Porto Alegre do Tocantins",
    "MG/Douradoquara",
    "PE/Pedra",
    "TO/S\u00e3o Sebasti\u00e3o do Tocantins",
    "GO/Damol\u00e2ndia",
    "SP/Jaguari\u00fana",
    "MG/Cristiano Otoni",
    "MG/C\u00e1ssia",
    "MG/Belo Vale",
    "MG/Joa\u00edma",
    "RO/Governador Jorge Teixeira",
    "MG/Visconde do Rio Branco",
    "SP/Nantes",
    "RS/S\u00e3o Louren\u00e7o do Sul",
    "MG/Santa Cruz do Escalvado",
    "PR/Jundia\u00ed do Sul",
    "AL/Taquarana",
    "PE/Taquaritinga do Norte",
    "PR/Ramil\u00e2ndia",
    "SP/Cristais Paulista",
    "SP/Buri",
    "SP/Poloni",
    "RS/Jaguar\u00e3o",
    "MG/Cabo Verde",
    "BA/\u00c9rico Cardoso",
    "PR/Rio Negro",
    "RN/S\u00e3o Tom\u00e9",
    "PB/S\u00e3o Jos\u00e9 de Espinharas",
    "SC/Ibiam",
    "PI/Campo Alegre do Fidalgo",
    "GO/Padre Bernardo",
    "MT/Jauru",
    "SP/Tapiratiba",
    "BA/Itapitanga",
    "CE/Horizonte",
    "PI/Reden\u00e7\u00e3o do Gurgu\u00e9ia",
    "MA/Santa Helena",
    "MS/Aral Moreira",
    "PB/S\u00e3o Jos\u00e9 do Brejo do Cruz",
    "RS/Tuparendi",
    "PB/S\u00e3o Domingos",
    "MT/Torixor\u00e9u",
    "AL/Anadia",
    "PR/Arauc\u00e1ria",
    "MT/Terra Nova do Norte",
    "MG/Candeias",
    "MG/Icara\u00ed de Minas",
    "GO/Novo Planalto",
    "AP/Laranjal do Jari",
    "SC/Guaruj\u00e1 do Sul",
    "PE/Vic\u00eancia",
    "PR/Teixeira Soares",
    "RS/Santa Margarida do Sul",
    "PR/Fl\u00f3rida",
    "MG/Itamonte",
    "RN/Pau dos Ferros",
    "SC/Curitibanos",
    "MA/Guimar\u00e3es",
    "MG/Periquito",
    "PE/Goiana",
    "MA/Satubinha",
    "BA/Dom Macedo Costa",
    "GO/Goiandira",
    "SP/Barra do Turvo",
    "PR/Porto Vit\u00f3ria",
    "MG/Rio do Prado",
    "SP/Monte Alegre do Sul",
    "RS/S\u00e3o Paulo das Miss\u00f5es",
    "SP/Gast\u00e3o Vidigal",
    "PA/S\u00e3o Jo\u00e3o da Ponta",
    "GO/Uruta\u00ed",
    "RS/Taquari",
    "PA/Vit\u00f3ria do Xingu",
    "PR/Palotina",
    "RS/Boa Vista do Buric\u00e1",
    "SP/Biritiba-Mirim",
    "MG/Padre Carvalho",
    "MS/F\u00e1tima do Sul",
    "SC/S\u00e3o Pedro de Alc\u00e2ntara",
    "MG/Tocos do Moji",
    "RS/Santa Vit\u00f3ria do Palmar",
    "RN/Ar\u00eas",
    "GO/S\u00e3o Miguel do Araguaia",
    "MG/Itaobim",
    "ES/Pancas",
    "MA/Balsas",
    "PE/Belo Jardim",
    "PE/Lagoa do Ouro",
    "MG/S\u00e3o Jos\u00e9 do Mantimento",
    "PB/Curral de Cima",
    "GO/Campina\u00e7u",
    "AL/Olho d'\u00c1gua das Flores",
    "MT/Alto Araguaia",
    "SP/Holambra",
    "BA/Jussiape",
    "SC/Nova Veneza",
    "PI/Santa Cruz do Piau\u00ed",
    "PB/Santa Cec\u00edlia",
    "PB/Santa Teresinha",
    "SP/Ubirajara",
    "CE/Ibiapina",
    "MG/Gonzaga",
    "BA/Ribeira do Amparo",
    "MG/Fel\u00edcio dos Santos",
    "MG/Alterosa",
    "PR/Missal",
    "MG/Virgem da Lapa",
    "TO/Lagoa do Tocantins",
    "PR/Santa Izabel do Oeste",
    "CE/Santana do Acara\u00fa",
    "BA/Serra Dourada",
    "MA/Pedro do Ros\u00e1rio",
    "PE/Serra Talhada",
    "SP/Franca",
    "RO/Alto Para\u00edso",
    "SP/Tarabai",
    "SP/Jacare\u00ed",
    "SP/Colina",
    "PR/Perobal",
    "SC/Bela Vista do Toldo",
    "GO/Itau\u00e7u",
    "RJ/Miguel Pereira",
    "SP/Laranjal Paulista",
    "CE/Mulungu",
    "BA/Iramaia",
    "RN/Parazinho",
    "PB/Condado",
    "ES/Pedro Can\u00e1rio",
    "GO/Nova Aurora",
    "GO/Varj\u00e3o",
    "CE/Santa Quit\u00e9ria",
    "SP/Onda Verde",
    "PA/Almeirim",
    "CE/Reden\u00e7\u00e3o",
    "PR/Santa Helena",
    "AL/Atalaia",
    "PE/Santa Maria do Cambuc\u00e1",
    "RJ/Silva Jardim",
    "TO/Couto Magalh\u00e3es",
    "PB/Livramento",
    "PR/P\u00e9rola",
    "BA/Sa\u00fade",
    "BA/Concei\u00e7\u00e3o do Jacu\u00edpe",
    "MG/Patroc\u00ednio do Muria\u00e9",
    "TO/Ja\u00fa do Tocantins",
    "PA/Senador Jos\u00e9 Porf\u00edrio",
    "SC/Rancho Queimado",
    "SP/Fern\u00e3o",
    "BA/Aiquara",
    "PR/Jussara",
    "SC/Imaru\u00ed",
    "PI/Ribeira do Piau\u00ed",
    "RS/Panambi",
    "MG/Lassance",
    "SC/Porto Belo",
    "SP/Alvinl\u00e2ndia",
    "RS/Vila Nova do Sul",
    "SE/Telha",
    "ES/Vila Pav\u00e3o",
    "PR/Pato Branco",
    "RJ/Rio de Janeiro",
    "PB/Patos",
    "MG/M\u00e1rio Campos",
    "MS/Bodoquena",
    "SP/Jo\u00e3o Ramalho",
    "TO/Chapada de Areia",
    "MG/Riacho dos Machados",
    "BA/Cardeal da Silva",
    "PB/Santa Cruz",
    "AL/Vi\u00e7osa",
    "MG/Guiricema",
    "MG/Ub\u00e1",
    "SP/Itapura",
    "SP/Ocau\u00e7u",
    "AL/Porto de Pedras",
    "SP/Pinhalzinho",
    "SE/Brejo Grande",
    "PB/Alagoa Grande",
    "SC/Arroio Trinta",
    "SP/Ribeir\u00e3o do Sul",
    "SP/Ces\u00e1rio Lange",
    "MT/Rio Branco",
    "SP/Sales\u00f3polis",
    "MG/Senhora de Oliveira",
    "PA/Moju\u00ed dos Campos",
    "AM/Manaquiri",
    "MG/Janu\u00e1ria",
    "BA/S\u00edtio do Quinto",
    "SP/Junqueir\u00f3polis",
    "PR/Bandeirantes",
    "PR/Mandaguari",
    "RN/\u00c1gua Nova",
    "AL/Marechal Deodoro",
    "ES/Santa Leopoldina",
    "BA/Quijingue",
    "SP/Embu-Gua\u00e7u",
    "PR/Ariranha do Iva\u00ed",
    "SP/Cedral",
    "SP/Nova Castilho",
    "MG/Igaratinga",
    "BA/S\u00e3o Felipe",
    "MT/Luciara",
    "PE/Jatob\u00e1",
    "SC/Seara",
    "BA/Itarantim",
    "RS/Paulo Bento",
    "MA/A\u00e7ail\u00e2ndia",
    "GO/Bonfin\u00f3polis",
    "MS/Porto Murtinho",
    "BA/Campo Formoso",
    "BA/Caetanos",
    "MG/Medeiros",
    "PI/Pedro Laurentino",
    "MG/Pains",
    "RR/Caroebe",
    "PI/Matias Ol\u00edmpio",
    "MG/Bert\u00f3polis",
    "AL/S\u00e3o Miguel dos Campos",
    "PE/Lagoa dos Gatos",
    "GO/Pires do Rio",
    "BA/Apor\u00e1",
    "MG/Jesu\u00e2nia",
    "MG/Ibirit\u00e9",
    "SC/Bocaina do Sul",
    "SP/Torre de Pedra",
    "RO/Corumbiara",
    "PI/Regenera\u00e7\u00e3o",
    "MG/Itutinga",
    "PR/Figueira",
    "RS/Toropi",
    "SP/Pacaembu",
    "MG/Coromandel",
    "CE/Granja",
    "PE/Buenos Aires",
    "MG/Perd\u00f5es",
    "PR/Pitangueiras",
    "SP/Jacupiranga",
    "RN/Triunfo Potiguar",
    "RS/Nova Esperan\u00e7a do Sul",
    "SP/Itanha\u00e9m",
    "SP/Santa Albertina",
    "PA/Bel\u00e9m",
    "CE/Mauriti",
    "RS/Santo Augusto",
    "MA/Magalh\u00e3es de Almeida",
    "BA/Novo Triunfo",
    "CE/Pires Ferreira",
    "PR/Nova Esperan\u00e7a",
    "RS/Campos Borges",
    "MG/Concei\u00e7\u00e3o do Par\u00e1",
    "MG/Limeira do Oeste",
    "PB/Amparo",
    "RS/Frederico Westphalen",
    "PA/Novo Repartimento",
    "MG/Ch\u00e1cara",
    "PR/Guaraci",
    "PE/S\u00e3o Jo\u00e3o",
    "ES/Fund\u00e3o",
    "SP/Pomp\u00e9ia",
    "SP/Guararema",
    "CE/Aracoiaba",
    "GO/Campinorte",
    "BA/Itagua\u00e7u da Bahia",
    "RS/Novo Xingu",
    "RJ/Mendes",
    "SP/Lavrinhas",
    "BA/Jeremoabo",
    "RS/Santa Rosa",
    "AM/Anori",
    "BA/Ourol\u00e2ndia",
    "SC/Rio do Campo",
    "MA/Santa Filomena do Maranh\u00e3o",
    "TO/Itapiratins",
    "SP/Itupeva",
    "PI/Nazar\u00e9 do Piau\u00ed",
    "CE/Barbalha",
    "CE/Frecheirinha",
    "PR/Apucarana",
    "PR/Arapu\u00e3",
    "MS/Jaraguari",
    "MG/Itueta",
    "SC/Santa Rosa de Lima",
    "PE/Salgueiro",
    "GO/Alvorada do Norte",
    "CE/Barroquinha",
    "RS/Travesseiro",
    "GO/Campo Limpo de Goi\u00e1s",
    "BA/Anguera",
    "AM/Tonantins",
    "SP/S\u00e3o Caetano do Sul",
    "BA/Inhambupe",
    "MG/Alpercata",
    "SP/Charqueada",
    "SP/Ribeir\u00e3o dos \u00cdndios",
    "SP/Ribeira",
    "MG/Lagoa dos Patos",
    "MG/Santa Rita de Minas",
    "CE/Uruoca",
    "PR/Cambira",
    "SP/Altair",
    "MS/Selv\u00edria",
    "PR/Jaguapit\u00e3",
    "SC/Jupi\u00e1",
    "MG/Fernandes Tourinho",
    "AC/Santa Rosa do Purus",
    "CE/Arneiroz",
    "MG/Ibia\u00ed",
    "MT/Santa Rita do Trivelato",
    "RN/Parelhas",
    "PR/Godoy Moreira",
    "PA/Ananindeua",
    "MS/Lad\u00e1rio",
    "TO/Aragua\u00edna",
    "CE/Quixer\u00e9",
    "SC/Irani",
    "PE/S\u00e3o Bento do Una",
    "PI/Picos",
    "PR/Ubirat\u00e3",
    "SP/Iacanga",
    "PR/Xambr\u00ea",
    "PE/Brej\u00e3o",
    "SC/Botuver\u00e1",
    "MG/S\u00e3o Geraldo da Piedade",
    "BA/Planalto",
    "PB/Matur\u00e9ia",
    "GO/Goi\u00e1s",
    "SC/Cunha Por\u00e3",
    "RJ/Mag\u00e9",
    "PR/Manfrin\u00f3polis",
    "AP/Macap\u00e1",
    "PR/Imbituva",
    "MG/Pai Pedro",
    "SP/Borac\u00e9ia",
    "PA/Portel",
    "MG/Josen\u00f3polis",
    "MS/Coxim",
    "MG/Cachoeira de Minas",
    "PR/Itapejara d'Oeste",
    "SC/Mirim Doce",
    "PI/Bel\u00e9m do Piau\u00ed",
    "PE/Tracunha\u00e9m",
    "SP/Salto de Pirapora",
    "RN/Esp\u00edrito Santo",
    "MG/Ribeir\u00e3o das Neves",
    "GO/S\u00e3o Jo\u00e3o d'Alian\u00e7a",
    "SP/Registro",
    "RN/Rafael Fernandes",
    "PI/Jo\u00e3o Costa",
    "RS/Paim Filho",
    "MG/Imb\u00e9 de Minas",
    "TO/Oliveira de F\u00e1tima",
    "SC/Armaz\u00e9m",
    "BA/Jaguaripe",
    "RS/Gramado",
    "SP/Estrela d'Oeste",
    "SC/Caxambu do Sul",
    "RN/Governador Dix-Sept Rosado",
    "SC/Maracaj\u00e1",
    "RS/Morro Reuter",
    "PB/Areial",
    "TO/Peixe",
    "MT/Brasnorte",
    "BA/Cachoeira",
    "MG/S\u00e3o Francisco de Sales",
    "PR/Bela Vista do Para\u00edso",
    "CE/Meruoca",
    "MT/Serra Nova Dourada",
    "SE/Tomar do Geru",
    "PB/Parari",
    "SC/Salto Veloso",
    "PB/Guarabira",
    "MA/Godofredo Viana",
    "PB/Gurinh\u00e9m",
    "RS/Guabiju",
    "SP/Queiroz",
    "SC/Pinhalzinho",
    "RS/S\u00e3o Jer\u00f4nimo",
    "RS/Agudo",
    "RS/Caseiros",
    "MG/A\u00e7ucena",
    "PB/Logradouro",
    "MS/Tacuru",
    "AP/Pracu\u00faba",
    "RJ/Nil\u00f3polis",
    "PB/Queimadas",
    "PE/Vertentes",
    "ES/Manten\u00f3polis",
    "BA/Sobradinho",
    "SP/Cajuru",
    "MG/Felixl\u00e2ndia",
    "PR/S\u00e3o Manoel do Paran\u00e1",
    "SP/Campinas",
    "MG/S\u00e3o Thom\u00e9 das Letras",
    "SE/Itabaiana",
    "AL/Senador Rui Palmeira",
    "MG/Divin\u00e9sia",
    "SP/Tabapu\u00e3",
    "MA/Fortuna",
    "PR/Munhoz de Melo",
    "MG/Concei\u00e7\u00e3o da Barra de Minas",
    "PR/Alto Paran\u00e1",
    "CE/Banabui\u00fa",
    "PR/Presidente Castelo Branco",
    "PI/Parnagu\u00e1",
    "PI/Guaribas",
    "MT/Novo Santo Ant\u00f4nio",
    "PR/Rebou\u00e7as",
    "PR/Laranjal",
    "PA/Alenquer",
    "CE/Parambu",
    "PR/Palmeira",
    "MT/Porto dos Ga\u00fachos",
    "MG/Frutal",
    "TO/Itapor\u00e3 do Tocantins",
    "MG/Toledo",
    "SP/Arealva",
    "PI/Geminiano",
    "RS/Planalto",
    "GO/Nova Veneza",
    "MG/Sericita",
    "MG/Morro da Gar\u00e7a",
    "RS/Pinheirinho do Vale",
    "RS/Cruzeiro do Sul",
    "GO/Vila Prop\u00edcio",
    "PR/Catanduvas",
    "SP/Marin\u00f3polis",
    "SP/S\u00e3o Manuel",
    "SC/Nova Erechim",
    "MT/Aripuan\u00e3",
    "RS/Ponte Preta",
    "PR/Mirador",
    "AM/Autazes",
    "PR/Faxinal",
    "SE/Lagarto",
    "PR/Iretama",
    "AC/Marechal Thaumaturgo",
    "CE/Ubajara",
    "RS/Derrubadas",
    "RS/Jaboticaba",
    "BA/Gl\u00f3ria",
    "SP/Mogi Mirim",
    "PR/Sertaneja",
    "SP/Mendon\u00e7a",
    "BA/Malhada de Pedras",
    "SC/Catanduvas",
    "MG/Jacinto",
    "MA/Nina Rodrigues",
    "MG/Conselheiro Lafaiete",
    "SC/Itapo\u00e1",
    "MG/Br\u00e1s Pires",
    "SP/Mongagu\u00e1",
    "GO/Perol\u00e2ndia",
    "SP/Paulist\u00e2nia",
    "MG/Borda da Mata",
    "BA/Sebasti\u00e3o Laranjeiras",
    "SP/Itajobi",
    "BA/Ibicoara",
    "MG/Cordisburgo",
    "MS/Sete Quedas",
    "MG/Paragua\u00e7u",
    "SC/Aurora",
    "AL/Dois Riachos",
    "GO/Formoso",
    "PR/Coronel Vivida",
    "RN/Ipangua\u00e7u",
    "CE/Assar\u00e9",
    "RS/Erechim",
    "RO/Vilhena",
    "AL/Pia\u00e7abu\u00e7u",
    "PR/Seng\u00e9s",
    "PB/Bom Sucesso",
    "MG/Ibiracatu",
    "MA/Gra\u00e7a Aranha",
    "SE/Monte Alegre de Sergipe",
    "PR/S\u00e3o Carlos do Iva\u00ed",
    "RS/Buti\u00e1",
    "PR/Reserva",
    "SP/Restinga",
    "PI/Pio IX",
    "SP/S\u00e3o Jos\u00e9 do Rio Pardo",
    "BA/Jo\u00e3o Dourado",
    "PI/Canavieira",
    "SP/Porto Feliz",
    "TO/Carmol\u00e2ndia",
    "PR/Atalaia",
    "ES/Governador Lindenberg",
    "SP/Parisi",
    "PE/Cabo de Santo Agostinho",
    "MT/Porto Esperidi\u00e3o",
    "GO/Planaltina",
    "MG/Santa Margarida",
    "PB/Riach\u00e3o do Bacamarte",
    "PB/Carrapateira",
    "BA/Dom Bas\u00edlio",
    "SP/Sagres",
    "PB/Cabedelo",
    "ES/Boa Esperan\u00e7a",
    "MA/Feira Nova do Maranh\u00e3o",
    "GO/Santa Cruz de Goi\u00e1s",
    "BA/Seabra",
    "MA/Alto Parna\u00edba",
    "BA/Pau Brasil",
    "BA/Arataca",
    "CE/Varjota",
    "SP/Nova Cana\u00e3 Paulista",
    "SC/Ascurra",
    "GO/Vila Boa",
    "PR/Santa F\u00e9",
    "PR/P\u00e9rola d'Oeste",
    "MG/S\u00e3o Jo\u00e3o del Rei",
    "AL/S\u00e3o Lu\u00eds do Quitunde",
    "PA/S\u00e3o Domingos do Capim",
    "SC/Vidal Ramos",
    "AP/Cal\u00e7oene",
    "SP/Bocaina",
    "BA/Cotegipe",
    "BA/Lap\u00e3o",
    "PB/Areia de Bara\u00fanas",
    "GO/Cumari",
    "PR/Fernandes Pinheiro",
    "RJ/Laje do Muria\u00e9",
    "PI/Nova Santa Rita",
    "BA/Salinas da Margarida",
    "AM/Iranduba",
    "PE/Salo\u00e1",
    "PR/Curi\u00fava",
    "SP/Turi\u00faba",
    "SP/Artur Nogueira",
    "SP/S\u00e3o Jos\u00e9 do Rio Preto",
    "MA/Capinzal do Norte",
    "GO/Goiatuba",
    "SC/Agrol\u00e2ndia",
    "BA/Chorroch\u00f3",
    "PR/Goioxim",
    "BA/Capela do Alto Alegre",
    "PB/Bayeux",
    "RN/Patu",
    "MG/Luisl\u00e2ndia",
    "BA/Teol\u00e2ndia",
    "PR/Palmas",
    "CE/Poranga",
    "BA/Urandi",
    "RN/Lagoa de Velhos",
    "PA/S\u00e3o Domingos do Araguaia",
    "MG/Jenipapo de Minas",
    "SP/G\u00e1lia",
    "ES/Ecoporanga",
    "BA/Alagoinhas",
    "SP/Itaporanga",
    "MG/Caldas",
    "RS/Capit\u00e3o",
    "SP/Saltinho",
    "PI/Bom Princ\u00edpio do Piau\u00ed",
    "MG/Centralina",
    "MS/Ivinhema",
    "RN/Cear\u00e1-Mirim",
    "GO/Campos Belos",
    "SP/Itarar\u00e9",
    "TO/Itacaj\u00e1",
    "RS/Roque Gonzales",
    "SP/Itu",
    "SP/Morungaba",
    "GO/Ceres",
    "MG/Ressaquinha",
    "MG/Guimar\u00e2nia",
    "PR/Ribeir\u00e3o Claro",
    "SP/Buritama",
    "MT/Ita\u00faba",
    "MG/Ant\u00f4nio Prado de Minas",
    "AM/Benjamin Constant",
    "BA/Igua\u00ed",
    "PR/Porto Rico",
    "SC/Balne\u00e1rio Rinc\u00e3o",
    "RN/Bom Jesus",
    "PA/Curralinho",
    "MA/S\u00e3o Mateus do Maranh\u00e3o",
    "PB/Coremas",
    "PR/Salgado Filho",
    "MA/Coroat\u00e1",
    "PA/Porto de Moz",
    "SP/Aruj\u00e1",
    "SC/S\u00e3o Ludgero",
    "MG/Guaran\u00e9sia",
    "MA/Lima Campos",
    "RO/Ministro Andreazza",
    "PE/Pesqueira",
    "SP/Ita\u00ed",
    "MT/Santo Ant\u00f4nio do Leste",
    "MG/Bom Sucesso",
    "PB/Bel\u00e9m do Brejo do Cruz",
    "PR/Salto do Itarar\u00e9",
    "BA/Barra do Cho\u00e7a",
    "TO/Anan\u00e1s",
    "SP/\u00c1guas de Santa B\u00e1rbara",
    "SP/Tiet\u00ea",
    "MG/Ipui\u00fana",
    "GO/Buritin\u00f3polis",
    "MG/Lagamar",
    "BA/Ilh\u00e9us",
    "PB/\u00c1gua Branca",
    "MG/Dom Bosco",
    "RJ/Maca\u00e9",
    "BA/Concei\u00e7\u00e3o do Coit\u00e9",
    "SC/Presidente Nereu",
    "GO/Anhanguera",
    "PE/Bu\u00edque",
    "PB/Bom Jesus",
    "PR/S\u00e3o Sebasti\u00e3o da Amoreira",
    "SP/Monte Azul Paulista",
    "BA/Cruz das Almas",
    "PE/Limoeiro",
    "SP/Osasco",
    "BA/Senhor do Bonfim",
    "MG/Concei\u00e7\u00e3o do Rio Verde",
    "RJ/Resende",
    "MG/Cipot\u00e2nea",
    "GO/\u00c1gua Limpa",
    "TO/Santa Rita do Tocantins",
    "AM/Manacapuru",
    "ES/Vit\u00f3ria",
    "SP/Sud Mennucci",
    "MT/Ros\u00e1rio Oeste",
    "SC/Ipira",
    "MG/Itaverava",
    "SP/S\u00e3o Sebasti\u00e3o",
    "PI/Caridade do Piau\u00ed",
    "AM/Novo Aripuan\u00e3",
    "AM/Guajar\u00e1",
    "GO/Silv\u00e2nia",
    "MG/Tabuleiro",
    "SP/Trabiju",
    "GO/Moss\u00e2medes",
    "MA/Maranh\u00e3ozinho",
    "PA/Santa Maria das Barreiras",
    "ES/Mimoso do Sul",
    "SE/Propri\u00e1",
    "RN/Pedra Preta",
    "GO/Gameleira de Goi\u00e1s",
    "SP/Santa L\u00facia",
    "MG/Esp\u00edrito Santo do Dourado",
    "SP/Americana",
    "SC/Presidente Castello Branco",
    "SP/Pen\u00e1polis",
    "CE/Ipu",
    "PR/Braganey",
    "SC/Angelina",
    "CE/Nova Olinda",
    "RS/Muliterno",
    "RS/Arroio Grande",
    "SC/Gr\u00e3o Par\u00e1",
    "MG/S\u00e3o Jo\u00e3o do Manhua\u00e7u",
    "RS/Chiapetta",
    "RS/Ma\u00e7ambar\u00e1",
    "PR/Nova Ol\u00edmpia",
    "MS/Ang\u00e9lica",
    "BA/Cip\u00f3",
    "PE/Tuparetama",
    "SP/Euclides da Cunha Paulista",
    "GO/Professor Jamil",
    "PR/Sab\u00e1udia",
    "BA/Malhada",
    "PE/Fernando de Noronha",
    "RS/Coqueiros do Sul",
    "SP/Coronel Macedo",
    "PE/Barreiros",
    "RN/Passa e Fica",
    "PR/Ivaipor\u00e3",
    "MG/Gouveia",
    "MG/Goian\u00e1",
    "RS/Senador Salgado Filho",
    "BA/Tapiramut\u00e1",
    "SC/Monda\u00ed",
    "PB/Cuit\u00e9",
    "SP/Presidente Prudente",
    "BA/Ibiquera",
    "RN/Serra Caiada",
    "GO/Trindade",
    "MG/Berilo",
    "PA/Cana\u00e3 dos Caraj\u00e1s",
    "TO/Tupiratins",
    "CE/Corea\u00fa",
    "MG/Arinos",
    "BA/Anag\u00e9",
    "CE/S\u00e3o Benedito",
    "PB/Mamanguape",
    "PI/Vila Nova do Piau\u00ed",
    "RS/S\u00e3o Val\u00e9rio do Sul",
    "PR/Sarandi",
    "PR/Lindoeste",
    "PI/S\u00e3o Louren\u00e7o do Piau\u00ed",
    "PR/Mandagua\u00e7u",
    "BA/Potiragu\u00e1",
    "RS/Santa Maria do Herval",
    "PR/Luiziana",
    "PR/Ventania",
    "PB/Olivedos",
    "RO/Vale do Anari",
    "MS/Itapor\u00e3",
    "MG/Jequita\u00ed",
    "MG/Guaraciama",
    "CE/Itaitinga",
    "RS/S\u00e3o Jos\u00e9 do Ouro",
    "RS/Floriano Peixoto",
    "SC/Forquilhinha",
    "MA/Buriti",
    "RS/Lajeado",
    "PA/S\u00e3o Sebasti\u00e3o da Boa Vista",
    "CE/Capistrano",
    "PE/Terra Nova",
    "PE/Santa Maria da Boa Vista",
    "SC/Fraiburgo",
    "SP/Ja\u00fa",
    "RS/Veran\u00f3polis",
    "BA/Lajedo do Tabocal",
    "SP/Ubatuba",
    "RJ/Barra do Pira\u00ed",
    "RS/Braga",
    "SP/Praia Grande",
    "MG/Itabirito",
    "PB/Pedra Lavrada",
    "RO/Nova Brasil\u00e2ndia D'Oeste",
    "SP/S\u00e3o Jo\u00e3o das Duas Pontes",
    "MG/Lagoa Grande",
    "RN/Tenente Ananias",
    "BA/Palmas de Monte Alto",
    "MG/Mantena",
    "RS/Nova Alvorada",
    "AL/Delmiro Gouveia",
    "PR/Prado Ferreira",
    "PE/S\u00e3o Jos\u00e9 da Coroa Grande",
    "SP/Echapor\u00e3",
    "PI/Hugo Napole\u00e3o",
    "RS/Po\u00e7o das Antas",
    "AL/Santana do Munda\u00fa",
    "SP/Guarant\u00e3",
    "RN/Lajes Pintadas",
    "SP/Itirapu\u00e3",
    "PB/Cubati",
    "MT/Chapada dos Guimar\u00e3es",
    "SC/Maravilha",
    "GO/Uirapuru",
    "PA/Mocajuba",
    "SP/Atibaia",
    "MG/Lagoa Dourada",
    "MG/Espera Feliz",
    "MG/Pratinha",
    "SP/Piraju\u00ed",
    "RS/Pareci Novo",
    "ES/Santa Teresa",
    "MG/Pequeri",
    "TO/Muricil\u00e2ndia",
    "TO/Mauril\u00e2ndia do Tocantins",
    "RS/S\u00e3o Marcos",
    "RS/Boa Vista do Incra",
    "SP/Ara\u00e7atuba",
    "GO/Mundo Novo",
    "PI/Ant\u00f4nio Almeida",
    "RN/Tibau",
    "RS/S\u00e3o Vendelino",
    "TO/Rio Sono",
    "SP/Valentim Gentil",
    "MG/Queluzito",
    "SP/Lind\u00f3ia",
    "PA/Abaetetuba",
    "RS/Marau",
    "MG/Jaboticatubas",
    "PB/Mogeiro",
    "MT/Porto Alegre do Norte",
    "SP/Bofete",
    "PB/Santo Andr\u00e9",
    "AL/Novo Lino",
    "SC/Witmarsum",
    "MG/Rio Espera",
    "PI/Joaquim Pires",
    "PI/Francisco Santos",
    "MS/Eldorado",
    "BA/Iraquara",
    "BA/P\u00e9 de Serra",
    "TO/Pequizeiro",
    "RS/Alecrim",
    "PR/Flor da Serra do Sul",
    "MA/Viana",
    "RN/S\u00e3o Jos\u00e9 de Mipibu",
    "MG/Medina",
    "MG/Novo Oriente de Minas",
    "PI/Padre Marcos",
    "AL/Campo Alegre",
    "MG/Ouro Verde de Minas",
    "PR/Santa Mariana",
    "PR/Mau\u00e1 da Serra",
    "BA/Itamari",
    "CE/Saboeiro",
    "GO/Ipameri",
    "PA/Trair\u00e3o",
    "PR/Cascavel",
    "PR/Campo do Tenente",
    "SP/Col\u00f4mbia",
    "RS/Novo Tiradentes",
    "SP/Tuiuti",
    "PR/Itaguaj\u00e9",
    "PR/Marquinho",
    "MG/Luz",
    "PR/Itamb\u00e9",
    "TO/Talism\u00e3",
    "PI/Ipiranga do Piau\u00ed",
    "RS/Alto Feliz",
    "SE/Canhoba",
    "RO/Campo Novo de Rond\u00f4nia",
    "PB/Paulista",
    "PR/Alt\u00f4nia",
    "BA/Guanambi",
    "RN/S\u00e3o Paulo do Potengi",
    "MG/S\u00e3o Bento Abade",
    "PI/Santa Rosa do Piau\u00ed",
    "SP/Santo Ant\u00f4nio do Aracangu\u00e1",
    "MG/Igarap\u00e9",
    "SC/Timb\u00f3 Grande",
    "MG/Santo Ant\u00f4nio do Amparo",
    "SC/Laguna",
    "RS/Ivoti",
    "MA/Brejo de Areia",
    "RS/Carazinho",
    "TO/Brasil\u00e2ndia do Tocantins",
    "TO/Buriti do Tocantins",
    "BA/Wanderley",
    "GO/Santa Rita do Novo Destino",
    "PE/Camocim de S\u00e3o F\u00e9lix",
    "MT/Santo Afonso",
    "PR/Paranacity",
    "SC/Tigrinhos",
    "PE/Amaraji",
    "ES/Alto Rio Novo",
    "PE/Triunfo",
    "RJ/S\u00e3o Francisco de Itabapoana",
    "PB/Ten\u00f3rio",
    "SP/Adamantina",
    "MG/Juramento",
    "MA/Buriti Bravo",
    "CE/Teju\u00e7uoca",
    "PI/Fronteiras",
    "SP/Rubi\u00e1cea",
    "SP/Mirante do Paranapanema",
    "MG/Catas Altas da Noruega",
    "CE/Penaforte",
    "MG/Aguanil",
    "MA/Sucupira do Riach\u00e3o",
    "SP/Taubat\u00e9",
    "RS/Garruchos",
    "PR/Nova Santa B\u00e1rbara",
    "CE/Crato",
    "MT/Col\u00edder",
    "SC/Palho\u00e7a",
    "PI/Miguel Le\u00e3o",
    "PE/Iati",
    "PI/S\u00e3o Braz do Piau\u00ed",
    "SP/Emilian\u00f3polis",
    "PR/Turvo",
    "SP/Iacri",
    "ES/Pi\u00fama",
    "RN/Francisco Dantas",
    "GO/Panam\u00e1",
    "BA/Bom Jesus da Serra",
    "GO/Rio Verde",
    "RS/Itaqui",
    "SE/Arau\u00e1",
    "PR/Sertan\u00f3polis",
    "RN/Serra Negra do Norte",
    "BA/Itanagra",
    "AL/Porto Calvo",
    "PB/Aguiar",
    "BA/Cama\u00e7ari",
    "SC/Saltinho",
    "PI/Alto Long\u00e1",
    "RS/Sananduva",
    "RS/Passo Fundo",
    "MG/Bocai\u00fava",
    "MG/Matias Barbosa",
    "PI/Pavussu",
    "SP/Vargem Grande Paulista",
    "MT/Cl\u00e1udia",
    "SP/Ponga\u00ed",
    "PA/Santa B\u00e1rbara do Par\u00e1",
    "PR/S\u00e3o Jorge d'Oeste",
    "SC/Ipua\u00e7u",
    "MG/Belo Oriente",
    "SP/Mirassol",
    "MG/Nova Lima",
    "BA/Itaju\u00edpe",
    "MG/S\u00e3o Jo\u00e3o Nepomuceno",
    "RS/Campinas do Sul",
    "CE/S\u00e3o Gon\u00e7alo do Amarante",
    "MA/Nova Colinas",
    "MG/Bela Vista de Minas",
    "SC/Penha",
    "RS/Picada Caf\u00e9",
    "SC/Bom Retiro",
    "MG/Bonfim",
    "BA/Maiquinique",
    "RS/Segredo",
    "RS/Constantina",
    "BA/Itagimirim",
    "MG/Santa B\u00e1rbara",
    "SC/Ipumirim",
    "RN/Angicos",
    "CE/Aiuaba",
    "GO/Nova Gl\u00f3ria",
    "BA/Mirante",
    "RS/Camaqu\u00e3",
    "SP/Bariri",
    "RS/Bento Gon\u00e7alves",
    "GO/Amaralina",
    "MT/Nova Lacerda",
    "TO/Nova Rosal\u00e2ndia",
    "RN/Santa Cruz",
    "RS/S\u00e3o Jos\u00e9 das Miss\u00f5es",
    "MG/Passa-Vinte",
    "PE/Barra de Guabiraba",
    "RJ/Carapebus",
    "RS/Ipiranga do Sul",
    "SP/Santo Ant\u00f4nio da Alegria",
    "ES/Alfredo Chaves",
    "PA/Inhangapi",
    "PR/Guaratuba",
    "MT/Salto do C\u00e9u",
    "MG/Concei\u00e7\u00e3o das Pedras",
    "PB/Aparecida",
    "MG/Arapu\u00e1",
    "RN/S\u00e3o Vicente",
    "SP/Irapuru",
    "SE/Aquidab\u00e3",
    "MG/Guaraciaba",
    "MA/Cod\u00f3",
    "RN/Afonso Bezerra",
    "CE/Guai\u00faba",
    "SE/Frei Paulo",
    "RS/Morrinhos do Sul",
    "PR/\u00c2ngulo",
    "RR/S\u00e3o Jo\u00e3o da Baliza",
    "SC/Paulo Lopes",
    "RS/Pirap\u00f3",
    "CE/Jati",
    "BA/Irajuba",
    "MA/Josel\u00e2ndia",
    "BA/Itapebi",
    "GO/Barro Alto",
    "MG/S\u00e3o Jos\u00e9 da Safira",
    "PA/Nova Esperan\u00e7a do Piri\u00e1",
    "RS/Balne\u00e1rio Pinhal",
    "BA/F\u00e1tima",
    "BA/Jiquiri\u00e7\u00e1",
    "MA/S\u00e3o Jo\u00e3o do Car\u00fa",
    "GO/Porteir\u00e3o",
    "MT/Marcel\u00e2ndia",
    "GO/Aparecida do Rio Doce",
    "CE/Jijoca de Jericoacoara",
    "PI/Cocal",
    "SP/Iper\u00f3",
    "SE/Po\u00e7o Redondo",
    "RN/Canguaretama",
    "GO/Caiap\u00f4nia",
    "RJ/Sapucaia",
    "BA/S\u00e3o F\u00e9lix do Coribe",
    "CE/Alto Santo",
    "PR/Andir\u00e1",
    "PA/Tom\u00e9-A\u00e7u",
    "SC/Vitor Meireles",
    "PE/Carnaubeira da Penha",
    "SP/Rio Claro",
    "SC/Campo Belo do Sul",
    "MG/S\u00e3o Sebasti\u00e3o do Para\u00edso",
    "SC/Rio Rufino",
    "PR/Marechal C\u00e2ndido Rondon",
    "RN/Coronel Jo\u00e3o Pessoa",
    "MA/Milagres do Maranh\u00e3o",
    "MG/Alvin\u00f3polis",
    "AL/Ibateguara",
    "MG/Guanh\u00e3es",
    "BA/Teixeira de Freitas",
    "SC/Erval Velho",
    "PB/Juru",
    "PR/Le\u00f3polis",
    "GO/Moipor\u00e1",
    "MG/C\u00f3rrego Fundo",
    "CE/Paracuru",
    "PI/Gilbu\u00e9s",
    "BA/Planaltino",
    "GO/Inhumas",
    "PB/Pedras de Fogo",
    "PR/Diamante D'Oeste",
    "MT/Araguaiana",
    "CE/Cariria\u00e7u",
    "SP/Votorantim",
    "RS/Horizontina",
    "BA/V\u00e1rzea Nova",
    "PR/Centen\u00e1rio do Sul",
    "SC/S\u00e3o Jos\u00e9 do Cerrito",
    "SP/Catanduva",
    "BA/Itagib\u00e1",
    "MG/Chiador",
    "SC/Santiago do Sul",
    "CE/Quixeramobim",
    "BA/Itanh\u00e9m",
    "RJ/Barra Mansa",
    "MG/Sacramento",
    "PI/S\u00e3o Jo\u00e3o da Serra",
    "PB/Riach\u00e3o",
    "MG/Jo\u00e3o Monlevade",
    "MA/Primeira Cruz",
    "BA/Jaguarari",
    "MA/Bacabal",
    "TO/Goiatins",
    "MT/Conquista D'Oeste",
    "PE/Floresta",
    "MG/Concei\u00e7\u00e3o dos Ouros",
    "PE/Jo\u00e3o Alfredo",
    "PI/Porto Alegre do Piau\u00ed",
    "MG/Paula C\u00e2ndido",
    "MG/Rio Manso",
    "PI/S\u00e3o Raimundo Nonato",
    "PR/Pinhal de S\u00e3o Bento",
    "RS/Dilermando de Aguiar",
    "PR/Sulina",
    "MA/Esperantin\u00f3polis",
    "SP/Alum\u00ednio",
    "GO/Itabera\u00ed",
    "AL/Pariconha",
    "SC/Balne\u00e1rio Arroio do Silva",
    "RS/Boa Vista do Cadeado",
    "RO/Cacaul\u00e2ndia",
    "TO/Filad\u00e9lfia",
    "BA/Adustina",
    "SC/Ituporanga",
    "GO/Cachoeira Dourada",
    "RS/Salvador das Miss\u00f5es",
    "MG/Sim\u00e3o Pereira",
    "RN/Santana do Serid\u00f3",
    "MG/C\u00f3rrego Danta",
    "SE/Campo do Brito",
    "RR/Uiramut\u00e3",
    "RS/Bom Progresso",
    "RS/Campo Novo",
    "GO/Serran\u00f3polis",
    "MG/Carlos Chagas",
    "PR/Boa Esperan\u00e7a do Igua\u00e7u",
    "RS/Cruzaltense",
    "SP/Iep\u00ea",
    "PA/Primavera",
    "MG/Porto Firme",
    "SP/Boituva",
    "PI/Nossa Senhora de Nazar\u00e9",
    "BA/Araci",
    "RS/Cap\u00e3o do Le\u00e3o",
    "MG/Braz\u00f3polis",
    "AM/Beruri",
    "MG/Concei\u00e7\u00e3o do Mato Dentro",
    "SE/Pacatuba",
    "SC/Iomer\u00ea",
    "SE/Japaratuba",
    "ES/Maril\u00e2ndia",
    "GO/Porangatu",
    "SP/Ca\u00e7apava",
    "MG/Santos Dumont",
    "RS/Teut\u00f4nia",
    "SE/Tobias Barreto",
    "PE/Venturosa",
    "AP/Mazag\u00e3o",
    "RS/Guarani das Miss\u00f5es",
    "PA/Tucuru\u00ed",
    "SC/Jaragu\u00e1 do Sul",
    "RN/Ruy Barbosa",
    "RO/Itapu\u00e3 do Oeste",
    "RS/Carlos Gomes",
    "GO/Vicentin\u00f3polis",
    "RS/Mariana Pimentel",
    "SP/Diadema",
    "PE/Sair\u00e9",
    "SP/Flora Rica",
    "SP/Itapecerica da Serra",
    "PA/Bonito",
    "RS/N\u00e3o-Me-Toque",
    "RJ/S\u00e3o Gon\u00e7alo",
    "RS/Ubiretama",
    "SP/Piquete",
    "SP/Bra\u00fana",
    "SP/C\u00e2ndido Mota",
    "PR/Mallet",
    "PI/Parna\u00edba",
    "MG/Gon\u00e7alves",
    "PI/Curral Novo do Piau\u00ed",
    "SE/Santa Rosa de Lima",
    "PI/Passagem Franca do Piau\u00ed",
    "RS/Cruz Alta",
    "SP/Lourdes",
    "CE/General Sampaio",
    "MG/Bocaina de Minas",
    "SP/Sabino",
    "RS/Paverama",
    "BA/Esplanada",
    "GO/Anicuns",
    "CE/Aracati",
    "SE/Cristin\u00e1polis",
    "SE/Muribeca",
    "PB/Passagem",
    "MG/Aracitaba",
    "PE/Ch\u00e3 de Alegria",
    "PE/Canhotinho",
    "SP/Guatapar\u00e1",
    "SP/Guaruj\u00e1",
    "MG/Martinho Campos",
    "RS/S\u00e3o Nicolau",
    "GO/Trombas",
    "SC/Salete",
    "PR/Lapa",
    "MG/Felisburgo",
    "CE/Morada Nova",
    "GO/Uruana",
    "PA/Bai\u00e3o",
    "GO/Mozarl\u00e2ndia",
    "MT/Indiava\u00ed",
    "AL/Arapiraca",
    "GO/Baliza",
    "PE/Itaquitinga",
    "PR/Santana do Itarar\u00e9",
    "MG/Nova Uni\u00e3o",
    "BA/Nova Itarana",
    "MG/Lagoa Santa",
    "BA/Marac\u00e1s",
    "RS/Rolante",
    "SP/Cajobi",
    "TO/Centen\u00e1rio",
    "SP/Auriflama",
    "MG/Itamarandiba",
    "AM/Pauini",
    "MT/Sapezal",
    "MS/Ponta Por\u00e3",
    "SP/Sete Barras",
    "PE/Lagoa de Itaenga",
    "SP/Barueri",
    "SP/Anhumas",
    "MG/Tiros",
    "PA/Xinguara",
    "MA/Timbiras",
    "RS/J\u00falio de Castilhos",
    "SP/Franco da Rocha",
    "MG/Prat\u00e1polis",
    "PA/Rur\u00f3polis",
    "CE/Chor\u00f3",
    "PI/Dirceu Arcoverde",
    "PR/Paulo Frontin",
    "SP/Altin\u00f3polis",
    "PE/Salgadinho",
    "ES/Concei\u00e7\u00e3o da Barra",
    "SP/Miracatu",
    "PE/Jucati",
    "MT/Tabapor\u00e3",
    "SE/Itaporanga d'Ajuda",
    "MG/Pouso Alto",
    "BA/Itatim",
    "PR/Bom Sucesso",
    "SP/Botucatu",
    "MG/Ponto dos Volantes",
    "CE/Gra\u00e7a",
    "MG/Buen\u00f3polis",
    "BA/Jussari",
    "AL/Jacu\u00edpe",
    "MG/Moema",
    "PA/Benevides",
    "MT/Alta Floresta",
    "RS/Barra do Rio Azul",
    "SP/Pirapozinho",
    "PR/Ibipor\u00e3",
    "PE/Lajedo",
    "PB/Frei Martinho",
    "PB/Caldas Brand\u00e3o",
    "RJ/Cardoso Moreira",
    "CE/S\u00e3o Lu\u00eds do Curu",
    "RS/Passo do Sobrado",
    "SE/Graccho Cardoso",
    "MG/Nova Porteirinha",
    "MG/Mutum",
    "SC/Bandeirante",
    "RS/Santo Ant\u00f4nio das Miss\u00f5es",
    "MA/Bar\u00e3o de Graja\u00fa",
    "GO/Itapuranga",
    "SE/S\u00e3o Francisco",
    "AL/Jundi\u00e1",
    "SP/Dourado",
    "MG/\u00c1guas Formosas",
    "PR/Grandes Rios",
    "RJ/Quatis",
    "MG/Uruc\u00e2nia",
    "RS/Pinhal Grande",
    "RS/Engenho Velho",
    "TO/Tocant\u00ednia",
    "GO/Divin\u00f3polis de Goi\u00e1s",
    "MG/S\u00e3o Gotardo",
    "TO/Riachinho",
    "PB/S\u00e3o Jos\u00e9 do Sabugi",
    "PE/Cumaru",
    "RS/Inhacor\u00e1",
    "GO/Crix\u00e1s",
    "SP/Pardinho",
    "MG/Ara\u00e7a\u00ed",
    "PI/Campinas do Piau\u00ed",
    "BA/Jacaraci",
    "RS/David Canabarro",
    "PB/Sap\u00e9",
    "SC/Dion\u00edsio Cerqueira",
    "RS/Nova Prata",
    "PE/Itamb\u00e9",
    "SC/Lind\u00f3ia do Sul",
    "MT/Ju\u00edna",
    "PA/Acar\u00e1",
    "PR/Campina do Sim\u00e3o",
    "MA/\u00c1gua Doce do Maranh\u00e3o",
    "MA/Governador Nunes Freire",
    "AM/Canutama",
    "MG/Frei Gaspar",
    "AL/Feliz Deserto",
    "SC/Peritiba",
    "CE/Pacuj\u00e1",
    "PI/Prata do Piau\u00ed",
    "MA/Santo Amaro do Maranh\u00e3o",
    "AL/Maravilha",
    "RS/Esta\u00e7\u00e3o",
    "TO/Darcin\u00f3polis",
    "SP/Campos Novos Paulista",
    "PR/Planaltina do Paran\u00e1",
    "MG/Barbacena",
    "BA/Itabela",
    "MG/Guarda-Mor",
    "PR/Guaporema",
    "MG/Montezuma",
    "RS/Porto Alegre",
    "CE/Araripe",
    "PR/Agudos do Sul",
    "GO/Flores de Goi\u00e1s",
    "MA/Nova Olinda do Maranh\u00e3o",
    "PB/Emas",
    "MG/Chapada do Norte",
    "MG/Itanhandu",
    "MA/Benedito Leite",
    "RS/Uni\u00e3o da Serra",
    "TO/Figueir\u00f3polis",
    "RS/Ca\u00e7apava do Sul",
    "PE/Jurema",
    "PR/Mercedes",
    "BA/Morpar\u00e1",
    "SP/Arco-\u00cdris",
    "SP/Vera Cruz",
    "MG/Pav\u00e3o",
    "MA/Bel\u00e1gua",
    "GO/Jaupaci",
    "MG/Almenara",
    "MG/Piedade do Rio Grande",
    "MG/Guap\u00e9",
    "MA/Pirapemas",
    "PR/Borraz\u00f3polis",
    "PI/S\u00e3o Francisco de Assis do Piau\u00ed",
    "GO/Alex\u00e2nia",
    "CE/Ipueiras",
    "SP/Brejo Alegre",
    "TO/Alian\u00e7a do Tocantins",
    "RS/Imigrante",
    "PR/Cruz Machado",
    "PI/Santa Filomena",
    "MG/Turvol\u00e2ndia",
    "SE/Santo Amaro das Brotas",
    "MG/Vargem Alegre",
    "BA/Jussara",
    "RS/Bar\u00e3o",
    "MT/Nossa Senhora do Livramento",
    "PR/Pinh\u00e3o",
    "TO/Novo Acordo",
    "MG/Coluna",
    "RS/Fortaleza dos Valos",
    "MG/Faria Lemos",
    "PR/Diamante do Norte",
    "MG/Jaguara\u00e7u",
    "MG/Marli\u00e9ria",
    "MG/Desterro do Melo",
    "RN/S\u00e3o Miguel",
    "SP/Cruz\u00e1lia",
    "MA/Mat\u00f5es do Norte",
    "GO/Pontalina",
    "ES/Vila Velha",
    "PB/S\u00e3o Mamede",
    "RO/Nova Uni\u00e3o",
    "RS/Capivari do Sul",
    "BA/Mata de S\u00e3o Jo\u00e3o",
    "SP/Aramina",
    "PB/Duas Estradas",
    "BA/Mulungu do Morro",
    "RS/Centen\u00e1rio",
    "MA/Parnarama",
    "SC/Arabut\u00e3",
    "BA/Pedro Alexandre",
    "MG/Coronel Xavier Chaves",
    "SP/Socorro",
    "PR/Rio Azul",
    "MG/Boa Esperan\u00e7a",
    "MG/Mendes Pimentel",
    "MG/Perdig\u00e3o",
    "PI/Isa\u00edas Coelho",
    "SC/Videira",
    "GO/Inaciol\u00e2ndia",
    "SP/Mombuca",
    "PB/Tacima",
    "PR/Colorado",
    "RS/Triunfo",
    "MG/Rit\u00e1polis",
    "MG/S\u00e3o Sebasti\u00e3o do Maranh\u00e3o",
    "MT/Guarant\u00e3 do Norte",
    "SP/Ferraz de Vasconcelos",
    "MA/S\u00e3o Jo\u00e3o do Soter",
    "SP/S\u00e3o Pedro do Turvo",
    "PA/Santana do Araguaia",
    "SP/Cravinhos",
    "CE/Irau\u00e7uba",
    "BA/Prado",
    "RO/Cacoal",
    "MT/Itiquira",
    "MA/S\u00e3o F\u00e9lix de Balsas",
    "PR/S\u00e3o Pedro do Iva\u00ed",
    "SP/Sales Oliveira",
    "RN/Umarizal",
    "MG/Par\u00e1 de Minas",
    "SP/Rosana",
    "SP/Quintana",
    "PE/Tabira",
    "MG/Recreio",
    "RN/Alto do Rodrigues",
    "MG/Virgin\u00f3polis",
    "PR/Rio Branco do Iva\u00ed",
    "TO/Augustin\u00f3polis",
    "MG/Manhua\u00e7u",
    "PI/Alvorada do Gurgu\u00e9ia",
    "GO/Hidrolina",
    "PR/Foz do Igua\u00e7u",
    "PR/Coronel Domingos Soares",
    "TO/S\u00e3o Miguel do Tocantins",
    "MG/Serrania",
    "SP/Indaiatuba",
    "MG/Cambu\u00ed",
    "SP/Mat\u00e3o",
    "MG/Cristina",
    "SP/Marapoama",
    "MT/C\u00e1ceres",
    "MG/Itatiaiu\u00e7u",
    "SC/It\u00e1",
    "PR/Iva\u00ed",
    "SP/\u00c1guas da Prata",
    "GO/Leopoldo de Bulh\u00f5es",
    "RS/Jari",
    "SP/Sorocaba",
    "RO/Pimenta Bueno",
    "PI/Simpl\u00edcio Mendes",
    "BA/Jucuru\u00e7u",
    "MG/Bandeira",
    "SC/Orleans",
    "MG/Delfim Moreira",
    "PA/Nova Timboteua",
    "RS/Pedro Os\u00f3rio",
    "BA/Ibotirama",
    "SP/Tai\u00fava",
    "BA/Riach\u00e3o do Jacu\u00edpe",
    "BA/Ubaitaba",
    "RS/S\u00e3o Jos\u00e9 dos Ausentes",
    "AL/Tanque d'Arca",
    "SP/Planalto",
    "BA/Itamaraju",
    "RS/Santo Ant\u00f4nio do Palma",
    "SC/Rodeio",
    "RN/Acari",
    "MG/Carvalhos",
    "MA/Anajatuba",
    "RS/Coronel Bicaco",
    "MA/Governador Newton Bello",
    "SC/Descanso",
    "MG/S\u00e3o Louren\u00e7o",
    "PB/Esperan\u00e7a",
    "SP/Estiva Gerbi",
    "SP/Tabatinga",
    "PR/Loanda",
    "AL/Uni\u00e3o dos Palmares",
    "MG/Carvalh\u00f3polis",
    "RS/Cidreira",
    "CE/Russas",
    "RS/Boa Vista do Sul",
    "BA/Ruy Barbosa",
    "RS/Benjamin Constant do Sul",
    "MA/Cajari",
    "MG/Crist\u00e1lia",
    "SP/Terra Roxa",
    "RS/Quatro Irm\u00e3os",
    "AL/P\u00e3o de A\u00e7\u00facar",
    "CE/Icapu\u00ed",
    "PB/Puxinan\u00e3",
    "BA/Remanso",
    "MA/Santana do Maranh\u00e3o",
    "BA/Miguel Calmon",
    "PR/Quarto Centen\u00e1rio",
    "AM/Juru\u00e1",
    "RN/Pureza",
    "SE/Malhada dos Bois",
    "SP/Cosmorama",
    "SP/Peru\u00edbe",
    "BA/Barreiras",
    "SP/Igarat\u00e1",
    "MG/Estiva",
    "GO/Mamba\u00ed",
    "MG/Itacambira",
    "MG/Entre Rios de Minas",
    "BA/Cairu",
    "PI/Jos\u00e9 de Freitas",
    "MG/Camacho",
    "TO/Cristal\u00e2ndia",
    "BA/Marcion\u00edlio Souza",
    "PR/Quatro Pontes",
    "PR/Campo Magro",
    "AL/Oliven\u00e7a",
    "PA/Bagre",
    "TO/Natividade",
    "PR/Rio Branco do Sul",
    "MG/Senador Amaral",
    "MG/Po\u00e7o Fundo",
    "PR/Douradina",
    "SP/Sever\u00ednia",
    "SE/Carira",
    "MT/Nova Xavantina",
    "PR/Boa Ventura de S\u00e3o Roque",
    "RS/Coronel Barros",
    "SP/Taquaral",
    "BA/Itamb\u00e9",
    "ES/Ibitirama",
    "PR/Contenda",
    "MG/Cana\u00e3",
    "PA/Afu\u00e1",
    "PE/Recife",
    "AM/Boa Vista do Ramos",
    "AM/Carauari",
    "ES/Vila Val\u00e9rio",
    "SC/Mafra",
    "GO/Castel\u00e2ndia",
    "RO/Primavera de Rond\u00f4nia",
    "MG/Gameleiras",
    "SP/Bilac",
    "TO/Novo Jardim",
    "PI/Paquet\u00e1",
    "MG/Dores do Turvo",
    "PR/Santo Ant\u00f4nio do Caiu\u00e1",
    "PR/Cruzeiro do Sul",
    "TO/Carrasco Bonito",
    "PR/Ant\u00f4nio Olinto",
    "CE/Milh\u00e3",
    "GO/Cristalina",
    "PI/Currais",
    "CE/Carir\u00e9",
    "MG/Santa Rita do Itueto",
    "PR/Amapor\u00e3",
    "SP/Santo Ant\u00f4nio de Posse",
    "PR/Gua\u00edra",
    "PA/S\u00e3o Caetano de Odivelas",
    "PR/Miraselva",
    "RS/Jacutinga",
    "RJ/Arraial do Cabo",
    "MT/Comodoro",
    "MG/Ouro Branco",
    "AL/Penedo",
    "SC/Timb\u00f3",
    "PA/S\u00e3o Francisco do Par\u00e1",
    "PR/Ivatuba",
    "CE/Palm\u00e1cia",
    "PB/Rio Tinto",
    "MG/Pirapetinga",
    "CE/Guaraciaba do Norte",
    "SP/S\u00e3o Pedro",
    "MG/\u00c1gua Comprida",
    "MG/Ibertioga",
    "RS/Encantado",
    "MG/Can\u00e1polis",
    "RS/Trindade do Sul",
    "PA/Muan\u00e1",
    "MG/Carmo da Mata",
    "SC/Chapec\u00f3",
    "SC/Palmeira",
    "MA/Bacuri",
    "RS/Gravata\u00ed",
    "PR/Esperan\u00e7a Nova",
    "PA/Oeiras do Par\u00e1",
    "MG/Pitangui",
    "BA/S\u00e3o Jos\u00e9 do Jacu\u00edpe",
    "PR/Guapirama",
    "MG/Minduri",
    "BA/Itapicuru",
    "RS/Candel\u00e1ria",
    "SP/Guariba",
    "CE/Vi\u00e7osa do Cear\u00e1",
    "MG/Morada Nova de Minas",
    "MA/Loreto",
    "RS/Tunas",
    "ES/Anchieta",
    "MG/Volta Grande",
    "BA/Itap\u00e9",
    "PI/Morro Cabe\u00e7a no Tempo",
    "PB/Princesa Isabel",
    "SC/Bra\u00e7o do Norte",
    "MG/Tumiritinga",
    "RS/Esperan\u00e7a do Sul",
    "SC/Macieira",
    "AM/Rio Preto da Eva",
    "SC/Rio Fortuna",
    "RS/Santo Ant\u00f4nio do Planalto",
    "MG/Varzel\u00e2ndia",
    "PB/Natuba",
    "SE/Japoat\u00e3",
    "SP/Prat\u00e2nia",
    "SP/Igarapava",
    "GO/Senador Canedo",
    "SC/Entre Rios",
    "MG/S\u00e3o F\u00e9lix de Minas",
    "AM/Coari",
    "PE/Maraial",
    "SP/Viradouro",
    "PI/Novo Oriente do Piau\u00ed",
    "PB/Itabaiana",
    "SP/Neves Paulista",
    "MG/Juatuba",
    "RJ/S\u00e3o Pedro da Aldeia",
    "RS/Nova Boa Vista",
    "RJ/Serop\u00e9dica",
    "CE/Barreira",
    "RN/Timba\u00faba dos Batistas",
    "PI/Domingos Mour\u00e3o",
    "CE/Marco",
    "MG/Piranga",
    "RS/S\u00e3o Leopoldo",
    "RS/Tupanci do Sul",
    "RN/Goianinha",
    "PA/Nova Ipixuna",
    "MT/Santa Cruz do Xingu",
    "CE/Or\u00f3s",
    "MG/Mar de Espanha",
    "MA/Pa\u00e7o do Lumiar",
    "MG/Arceburgo",
    "CE/Chorozinho",
    "MT/Nortel\u00e2ndia",
    "PR/Foz do Jord\u00e3o",
    "RN/Monte Alegre",
    "PB/Cacimba de Dentro",
    "SE/Itabaianinha",
    "SC/Schroeder",
    "SP/Piracaia",
    "PI/Aroazes",
    "BA/Gongogi",
    "MG/Rodeiro",
    "MG/Ouro Fino",
    "MA/S\u00e3o Jo\u00e3o do Para\u00edso",
    "RS/Est\u00e2ncia Velha",
    "PE/Cupira",
    "MT/Campo Novo do Parecis",
    "PE/Orob\u00f3",
    "MA/Humberto de Campos",
    "PB/Pil\u00f5es",
    "AL/Feira Grande",
    "GO/Simol\u00e2ndia",
    "PB/Casserengue",
    "BA/S\u00e3o Miguel das Matas",
    "SP/Novais",
    "TO/Ipueiras",
    "PI/Cara\u00fabas do Piau\u00ed",
    "PI/Socorro do Piau\u00ed",
    "MG/Fronteira",
    "ES/Bom Jesus do Norte",
    "MT/Parana\u00edta",
    "BA/Tapero\u00e1",
    "RS/Crissiumal",
    "PI/Jerumenha",
    "RS/Presidente Lucena",
    "SC/S\u00e3o Jo\u00e3o do Oeste",
    "SC/Jaguaruna",
    "RS/Giru\u00e1",
    "MG/Caetan\u00f3polis",
    "MG/Carbonita",
    "RN/Natal",
    "RS/Rolador",
    "PR/Dois Vizinhos",
    "RN/Barcelona",
    "PR/Santa Isabel do Iva\u00ed",
    "MG/Guarani",
    "RS/Caxias do Sul",
    "PR/Jacarezinho",
    "PA/Bragan\u00e7a",
    "TO/Caseara",
    "PR/Diamante do Sul",
    "BA/Riacho de Santana",
    "MA/Olho d'\u00c1gua das Cunh\u00e3s",
    "AM/Parintins",
    "CE/Lavras da Mangabeira",
    "GO/Morrinhos",
    "CE/Mora\u00fajo",
    "CE/Trairi",
    "SP/Bor\u00e1",
    "PA/Santa Luzia do Par\u00e1",
    "SP/Macaubal",
    "SP/Serra Negra",
    "AL/Messias",
    "CE/Salitre",
    "MA/Santa Quit\u00e9ria do Maranh\u00e3o",
    "RN/Campo Redondo",
    "SP/Sumar\u00e9",
    "RN/Paran\u00e1",
    "BA/Riach\u00e3o das Neves",
    "MT/Planalto da Serra",
    "MG/Contagem",
    "SP/Lucian\u00f3polis",
    "MA/Turil\u00e2ndia",
    "RS/Ronda Alta",
    "SP/Iguape",
    "PE/Moreno",
    "AC/Brasil\u00e9ia",
    "BA/Rio Real",
    "BA/Palmeiras",
    "BA/Barra do Mendes",
    "AC/Capixaba",
    "PB/Dona In\u00eas",
    "AC/Rodrigues Alves",
    "GO/Orizona",
    "MG/Ipia\u00e7u",
    "MA/Vargem Grande",
    "CE/Catunda",
    "GO/Quirin\u00f3polis",
    "RN/Alexandria",
    "SP/Tup\u00e3",
    "MG/Formoso",
    "RS/Seberi",
    "PI/Novo Santo Ant\u00f4nio",
    "PI/Arraial",
    "SP/Fartura",
    "GO/Amorin\u00f3polis",
    "MT/Ga\u00facha do Norte",
    "PB/Brejo do Cruz",
    "RJ/Tr\u00eas Rios",
    "AP/Ferreira Gomes",
    "RS/Gua\u00edba",
    "RS/Cerro Grande do Sul",
    "BA/Novo Horizonte",
    "PA/Our\u00e9m",
    "MG/Setubinha",
    "PB/Pilar",
    "CE/Deputado Irapuan Pinheiro",
    "MS/Anast\u00e1cio",
    "RS/Coqueiro Baixo",
    "GO/Cristian\u00f3polis",
    "PR/Kalor\u00e9",
    "MG/Campos Gerais",
    "RN/Major Sales",
    "SP/Santa Cruz da Esperan\u00e7a",
    "AP/Itaubal",
    "SP/Gabriel Monteiro",
    "SC/Timb\u00e9 do Sul",
    "PR/Campo Largo",
    "TO/Bandeirantes do Tocantins",
    "BA/Boquira",
    "MT/Araguainha",
    "MG/Abaet\u00e9",
    "MG/Mariana",
    "PE/Granito",
    "CE/Umirim",
    "BA/Itaparica",
    "SP/Castilho",
    "SP/Alfredo Marcondes",
    "RS/Cambar\u00e1 do Sul",
    "MG/Sete Lagoas",
    "MG/Pedro Leopoldo",
    "MA/Jenipapo dos Vieiras",
    "PE/Cort\u00eas",
    "MT/Guiratinga",
    "MA/Pastos Bons",
    "PE/Santa Cruz da Baixa Verde",
    "SP/Roseira",
    "MG/S\u00e3o Domingos do Prata",
    "BA/Ibirataia",
    "RS/Ibiraiaras",
    "BA/Santa Br\u00edgida",
    "SP/Rin\u00f3polis",
    "SP/Itaquaquecetuba",
    "GO/Estrela do Norte",
    "MA/Chapadinha",
    "RO/Santa Luzia D'Oeste",
    "PB/Mari",
    "ES/Ponto Belo",
    "PA/S\u00e3o Jo\u00e3o de Pirabas",
    "MG/S\u00e3o Francisco",
    "RN/Lagoa de Pedras",
    "RS/Camargo",
    "BA/Itaquara",
    "MG/Sapuca\u00ed-Mirim",
    "PB/Serra Branca",
    "PB/Santa Rita",
    "SP/Salto Grande",
    "GO/Monte Alegre de Goi\u00e1s",
    "PI/Angical do Piau\u00ed",
    "SP/Canas",
    "MS/Campo Grande",
    "BA/Brumado",
    "SC/Treze T\u00edlias",
    "SP/Palestina",
    "PI/Batalha",
    "BA/Caldeir\u00e3o Grande",
    "PI/Assun\u00e7\u00e3o do Piau\u00ed",
    "MG/Abadia dos Dourados",
    "RO/Presidente M\u00e9dici",
    "MG/Santa Luzia",
    "SP/Osvaldo Cruz",
    "RS/Uruguaiana",
    "SP/Am\u00e9rico Brasiliense",
    "MA/Barra do Corda",
    "RS/Tr\u00eas Palmeiras",
    "PI/Murici dos Portelas",
    "RN/Senador El\u00f3i de Souza",
    "PI/Barras",
    "AM/S\u00e3o Paulo de Oliven\u00e7a",
    "GO/Cezarina",
    "AC/Bujari",
    "RN/Apodi",
    "SP/Flor\u00ednia",
    "MG/Martins Soares",
    "SC/Saudades",
    "MG/Glaucil\u00e2ndia",
    "SP/Itapira",
    "MA/Presidente Vargas",
    "TO/Miracema do Tocantins",
    "PB/Alcantil",
    "ES/S\u00e3o Mateus",
    "MT/Matup\u00e1",
    "RS/Montenegro",
    "SE/Nossa Senhora de Lourdes",
    "MA/S\u00e3o Francisco do Maranh\u00e3o",
    "SC/Laurentino",
    "RS/Ibirub\u00e1",
    "AC/Porto Walter",
    "RS/Doutor Maur\u00edcio Cardoso",
    "PR/Nova Santa Rosa",
    "SP/Ribeir\u00e3o Preto",
    "MG/Capetinga",
    "MG/Barra Longa",
    "SP/Pontes Gestal",
    "BA/Mansid\u00e3o",
    "MA/Mon\u00e7\u00e3o",
    "SP/Buritizal",
    "PB/Po\u00e7o Dantas",
    "MG/Passos",
    "AM/Alvar\u00e3es",
    "RN/Serra de S\u00e3o Bento",
    "SC/Ermo",
    "CE/Abaiara",
    "PB/Mana\u00edra",
    "PR/Marumbi",
    "PE/Ferreiros",
    "RJ/Itaocara",
    "BA/Mara\u00fa",
    "BA/Irar\u00e1",
    "GO/Nova Roma",
    "PA/Pi\u00e7arra",
    "RS/Cristal do Sul",
    "SP/Prad\u00f3polis",
    "MG/Pouso Alegre",
    "SP/Itobi",
    "MG/Lambari",
    "MG/Muzambinho",
    "GO/Campos Verdes",
    "MG/Areado",
    "RS/Gramado Xavier",
    "MG/Simon\u00e9sia",
    "SC/Celso Ramos",
    "SP/Eldorado",
    "PB/Sobrado",
    "MG/Estrela Dalva",
    "TO/Xambio\u00e1",
    "RS/Cap\u00e3o Bonito do Sul",
    "SP/Fernando Prestes",
    "SP/Guarani d'Oeste",
    "PA/Cachoeira do Arari",
    "GO/Aren\u00f3polis",
    "SP/Taciba",
    "SP/Anal\u00e2ndia",
    "MG/Tr\u00eas Cora\u00e7\u00f5es",
    "RS/Silveira Martins",
    "PB/Triunfo",
    "MG/Curral de Dentro",
    "SP/Santa B\u00e1rbara d'Oeste",
    "PE/Itapetim",
    "PI/Riacho Frio",
    "RJ/Itabora\u00ed",
    "PI/V\u00e1rzea Grande",
    "PR/Paranava\u00ed",
    "MG/Arantina",
    "MG/Concei\u00e7\u00e3o das Alagoas",
    "ES/Brejetuba",
    "PB/Picu\u00ed",
    "BA/Barra",
    "MG/Iguatama",
    "SP/It\u00e1polis",
    "PI/S\u00e3o Miguel da Baixa Grande",
    "SE/Porto da Folha",
    "MT/Castanheira",
    "MG/Bambu\u00ed",
    "RN/Bod\u00f3",
    "SP/Ipaussu",
    "PB/Montadas",
    "RS/Vicente Dutra",
    "BA/Macajuba",
    "RS/Nova Br\u00e9scia",
    "ES/I\u00fana",
    "SP/Torrinha",
    "MG/Una\u00ed",
    "RS/Miragua\u00ed",
    "BA/Oliveira dos Brejinhos",
    "PA/Soure",
    "RS/Ibarama",
    "RO/Pimenteiras do Oeste",
    "SP/J\u00falio Mesquita",
    "MG/Oliveira",
    "MG/Senador Modestino Gon\u00e7alves",
    "BA/Maetinga",
    "BA/V\u00e1rzea da Ro\u00e7a",
    "MG/Cachoeira de Paje\u00fa",
    "ES/Concei\u00e7\u00e3o do Castelo",
    "RS/S\u00e3o Jos\u00e9 do Herval",
    "BA/Itoror\u00f3",
    "GO/Abadi\u00e2nia",
    "SC/Guaramirim",
    "BA/Ibicu\u00ed",
    "MG/Ijaci",
    "MG/Santo Hip\u00f3lito",
    "PE/Capoeiras",
    "RN/Fernando Pedroza",
    "SP/Itariri",
    "RS/Marat\u00e1",
    "SC/Anit\u00e1polis",
    "PA/Melga\u00e7o",
    "GO/Ara\u00e7u",
    "PR/Santa L\u00facia",
    "PA/\u00c1gua Azul do Norte",
    "BA/Antas",
    "PE/Joaquim Nabuco",
    "RN/Vila Flor",
    "MA/Concei\u00e7\u00e3o do Lago-A\u00e7u",
    "SP/In\u00fabia Paulista",
    "PE/\u00c1guas Belas",
    "AM/Ipixuna",
    "AL/Lagoa da Canoa",
    "RS/Lajeado do Bugre",
    "PA/S\u00e3o F\u00e9lix do Xingu",
    "CE/Jaguaretama",
    "SC/Riqueza",
    "BA/Tanha\u00e7u",
    "CE/Tiangu\u00e1",
    "MG/Araguari",
    "PA/Irituia",
    "GO/Guarinos",
    "ES/Mucurici",
    "MG/Japara\u00edba",
    "AL/Porto Real do Col\u00e9gio",
    "GO/Luzi\u00e2nia",
    "SP/Uru",
    "MG/Nazareno",
    "MG/Presidente Juscelino",
    "MG/Vermelho Novo",
    "MG/Ol\u00edmpio Noronha",
    "MG/Pedra Azul",
    "CE/Caucaia",
    "PA/Anaj\u00e1s",
    "GO/Ipor\u00e1",
    "MA/Vitorino Freire",
    "SP/Dois C\u00f3rregos",
    "SP/Estrela do Norte",
    "SP/S\u00e3o Francisco",
    "MT/Nova Maril\u00e2ndia",
    "TO/Cachoeirinha",
    "PB/Malta",
    "SP/\u00c1lvaro de Carvalho",
    "RS/Vila L\u00e2ngaro",
    "PR/Terra Roxa",
    "GO/Pilar de Goi\u00e1s",
    "SP/Trememb\u00e9",
    "MG/Bra\u00fanas",
    "PR/Japira",
    "MA/Arari",
    "MG/Betim",
    "MG/Argirita",
    "RS/Torres",
    "PR/Nova Laranjeiras",
    "RS/Turu\u00e7u",
    "RR/Alto Alegre",
    "PA/Santa Cruz do Arari",
    "CE/Maranguape",
    "PB/Lastro",
    "PE/Jupi",
    "SC/Campo Er\u00ea",
    "SC/Benedito Novo",
    "PB/Lagoa Seca",
    "AC/Senador Guiomard",
    "CE/Barro",
    "MG/Turmalina",
    "MG/Uruana de Minas",
    "SP/Regente Feij\u00f3",
    "RN/Tibau do Sul",
    "BA/Valente",
    "PI/Brejo do Piau\u00ed",
    "MG/Passab\u00e9m",
    "MT/Nova Monte Verde",
    "RJ/S\u00e3o Fid\u00e9lis",
    "RS/Pont\u00e3o",
    "PI/S\u00e3o Gon\u00e7alo do Gurgu\u00e9ia",
    "RO/Porto Velho",
    "MG/Coimbra",
    "SC/Campos Novos",
    "TO/Aguiarn\u00f3polis",
    "AL/Ch\u00e3 Preta",
    "RN/Frutuoso Gomes",
    "RO/Theobroma",
    "MG/S\u00e3o Sebasti\u00e3o do Oeste",
    "MG/Mateus Leme",
    "PR/Quedas do Igua\u00e7u",
    "SP/Vista Alegre do Alto",
    "MG/Salinas",
    "BA/Lajedinho",
    "SP/Borebi",
    "CE/Pacatuba",
    "PR/Ibema",
    "PR/Pinhais",
    "SC/Blumenau",
    "MG/Sardo\u00e1",
    "MA/Lago dos Rodrigues",
    "PE/Tacaimb\u00f3",
    "SP/Asp\u00e1sia",
    "AM/Santa Isabel do Rio Negro",
    "MG/Guarar\u00e1",
    "MG/Vi\u00e7osa",
    "MG/Lajinha",
    "PA/Igarap\u00e9-Miri",
    "SE/Laranjeiras",
    "PR/Carl\u00f3polis",
    "MG/Alto Capara\u00f3",
    "MT/Lucas do Rio Verde",
    "SC/Palmitos",
    "TO/Araguan\u00e3",
    "GO/\u00c1gua Fria de Goi\u00e1s",
    "BA/Nordestina",
    "MG/Ara\u00e7ua\u00ed",
    "SP/S\u00e3o Carlos",
    "PE/Cachoeirinha",
    "PE/Paranatama",
    "SP/Arandu",
    "MT/Alto Gar\u00e7as",
    "BA/Pintadas",
    "RS/C\u00e2ndido God\u00f3i",
    "RS/Pinheiro Machado",
    "CE/Aquiraz",
    "PB/Cacimba de Areia",
    "BA/Am\u00e9lia Rodrigues",
    "SC/Coronel Martins",
    "PB/Mulungu",
    "PE/S\u00e3o Caitano",
    "RO/Ouro Preto do Oeste",
    "RS/Muitos Cap\u00f5es",
    "MG/Ita\u00fana",
    "PB/Coxixola",
    "SC/Alfredo Wagner",
    "MG/Campo do Meio",
    "MG/Uni\u00e3o de Minas",
    "PE/Tupanatinga",
    "MG/Vazante",
    "SP/Itapirapu\u00e3 Paulista",
    "SC/Massaranduba",
    "PB/S\u00e3o Jo\u00e3o do Cariri",
    "PB/Ba\u00eda da Trai\u00e7\u00e3o",
    "RJ/Casimiro de Abreu",
    "RS/Mata",
    "GO/Firmin\u00f3polis",
    "SP/Taquarituba",
    "PA/Ponta de Pedras",
    "TO/Dois Irm\u00e3os do Tocantins",
    "RN/S\u00e3o Rafael",
    "MG/S\u00e3o Jos\u00e9 da Barra",
    "SC/Guatamb\u00fa",
    "RO/Cabixi",
    "PB/Algod\u00e3o de Janda\u00edra",
    "PB/S\u00e3o Jos\u00e9 do Bonfim",
    "MG/S\u00e3o Pedro da Uni\u00e3o",
    "AC/Manoel Urbano",
    "MA/Mat\u00f5es",
    "PR/Jandaia do Sul",
    "AP/Santana",
    "RS/Cap\u00e3o da Canoa",
    "SP/Ur\u00e2nia",
    "SP/Serra Azul",
    "MG/Prados",
    "PE/Vit\u00f3ria de Santo Ant\u00e3o",
    "SP/Para\u00edso",
    "GO/S\u00e3o Jo\u00e3o da Para\u00fana",
    "BA/Nova Vi\u00e7osa",
    "SP/Nipo\u00e3",
    "PR/Entre Rios do Oeste",
    "RS/S\u00e3o Luiz Gonzaga",
    "RS/Pedras Altas",
    "PB/Camala\u00fa",
    "GO/Ner\u00f3polis",
    "SP/Ribeir\u00e3o Bonito",
    "SP/Itapeva",
    "ES/Cariacica",
    "MG/Mirabela",
    "CE/Canind\u00e9",
    "RN/Santo Ant\u00f4nio",
    "SP/Palmeira d'Oeste",
    "SP/Pedra Bela",
    "MG/Santa Cruz de Minas",
    "SP/Fl\u00f3rida Paulista",
    "PR/Rancho Alegre D'Oeste",
    "SP/Mau\u00e1",
    "SC/Frei Rog\u00e9rio",
    "PI/S\u00e3o Jos\u00e9 do Piau\u00ed",
    "MA/Imperatriz",
    "SP/Piratininga",
    "RS/Ivor\u00e1",
    "MG/Dona Eus\u00e9bia",
    "PR/Carambe\u00ed",
    "SP/Magda",
    "SC/Campo Alegre",
    "MG/Campo Azul",
    "PA/Castanhal",
    "RN/S\u00e3o Bento do Trair\u00ed",
    "PB/Juarez T\u00e1vora",
    "SP/Ituverava",
    "GO/Goian\u00e9sia",
    "TO/Paran\u00e3",
    "RJ/S\u00e3o Jos\u00e9 de Ub\u00e1",
    "PR/Cantagalo",
    "RS/Arroio do Padre",
    "RS/Anta Gorda",
    "PR/S\u00e3o Miguel do Igua\u00e7u",
    "RS/Ros\u00e1rio do Sul",
    "SP/Chavantes",
    "SP/Ic\u00e9m",
    "PR/Pai\u00e7andu",
    "MG/Divinol\u00e2ndia de Minas",
    "MG/S\u00e3o Sebasti\u00e3o do Rio Preto",
    "BA/Floresta Azul",
    "SP/Macatuba",
    "PE/Camutanga",
    "SE/S\u00e3o Domingos",
    "MA/Jo\u00e3o Lisboa",
    "SP/Miguel\u00f3polis",
    "MA/Presidente M\u00e9dici",
    "RS/Pinhal",
    "MG/Pirapora",
    "SP/Mineiros do Tiet\u00ea",
    "MA/Igarap\u00e9 Grande",
    "MG/Carm\u00e9sia",
    "MG/Fervedouro",
    "MS/Aquidauana",
    "SP/Vit\u00f3ria Brasil",
    "PB/Campina Grande",
    "SP/Itapetininga",
    "PR/Bocai\u00fava do Sul",
    "SP/Luizi\u00e2nia",
    "MT/Cuiab\u00e1",
    "PI/Manoel Em\u00eddio",
    "PR/Itambarac\u00e1",
    "GO/Vian\u00f3polis",
    "PB/Conde",
    "BA/S\u00e1tiro Dias",
    "SP/Rio Grande da Serra",
    "SP/Lav\u00ednia",
    "SC/Tijucas",
    "ES/Ibira\u00e7u",
    "PE/Xex\u00e9u",
    "MG/Santa Maria do Sua\u00e7u\u00ed",
    "RS/Severiano de Almeida",
    "RO/Novo Horizonte do Oeste",
    "MG/Inhapim",
    "SP/Cap\u00e3o Bonito",
    "PB/Serra Redonda",
    "MG/Pot\u00e9",
]
